Class: Pingram::A2pRegistration

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/a2p_registration.rb

Overview

Public response type for A2P registration - excludes internal Telnyx IDs

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ A2pRegistration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/pingram/models/a2p_registration.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::A2pRegistration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::A2pRegistration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  else
    self.scenario_id = nil
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  else
    self.business_type = nil
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  else
    self.legal_name = nil
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  else
    self.website = nil
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'full_address')
    self.full_address = attributes[:'full_address']
  else
    self.full_address = nil
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  else
    self.compliance_contact_email = nil
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  else
    self.compliance_contact_phone = nil
  end

  if attributes.key?(:'brand_status')
    self.brand_status = attributes[:'brand_status']
  else
    self.brand_status = nil
  end

  if attributes.key?(:'campaign_status')
    self.campaign_status = attributes[:'campaign_status']
  else
    self.campaign_status = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



19
20
21
# File 'lib/pingram/models/a2p_registration.rb', line 19

def 
  @account_id
end

#brand_statusObject

Returns the value of attribute brand_status.



39
40
41
# File 'lib/pingram/models/a2p_registration.rb', line 39

def brand_status
  @brand_status
end

#business_typeObject

Returns the value of attribute business_type.



23
24
25
# File 'lib/pingram/models/a2p_registration.rb', line 23

def business_type
  @business_type
end

#campaign_statusObject

Returns the value of attribute campaign_status.



41
42
43
# File 'lib/pingram/models/a2p_registration.rb', line 41

def campaign_status
  @campaign_status
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



35
36
37
# File 'lib/pingram/models/a2p_registration.rb', line 35

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



37
38
39
# File 'lib/pingram/models/a2p_registration.rb', line 37

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



31
32
33
# File 'lib/pingram/models/a2p_registration.rb', line 31

def country
  @country
end

#created_atObject

Returns the value of attribute created_at.



43
44
45
# File 'lib/pingram/models/a2p_registration.rb', line 43

def created_at
  @created_at
end

#full_addressObject

Returns the value of attribute full_address.



33
34
35
# File 'lib/pingram/models/a2p_registration.rb', line 33

def full_address
  @full_address
end

Returns the value of attribute legal_name.



25
26
27
# File 'lib/pingram/models/a2p_registration.rb', line 25

def legal_name
  @legal_name
end

#scenario_idObject

Returns the value of attribute scenario_id.



21
22
23
# File 'lib/pingram/models/a2p_registration.rb', line 21

def scenario_id
  @scenario_id
end

#tax_idObject

Returns the value of attribute tax_id.



27
28
29
# File 'lib/pingram/models/a2p_registration.rb', line 27

def tax_id
  @tax_id
end

#updated_atObject

Returns the value of attribute updated_at.



45
46
47
# File 'lib/pingram/models/a2p_registration.rb', line 45

def updated_at
  @updated_at
end

#websiteObject

Returns the value of attribute website.



29
30
31
# File 'lib/pingram/models/a2p_registration.rb', line 29

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



90
91
92
# File 'lib/pingram/models/a2p_registration.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/pingram/models/a2p_registration.rb', line 95

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/pingram/models/a2p_registration.rb', line 70

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'full_address' => :'fullAddress',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone',
    :'brand_status' => :'brandStatus',
    :'campaign_status' => :'campaignStatus',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/pingram/models/a2p_registration.rb', line 474

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/pingram/models/a2p_registration.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/pingram/models/a2p_registration.rb', line 100

def self.openapi_types
  {
    :'account_id' => :'String',
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'full_address' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String',
    :'brand_status' => :'String',
    :'campaign_status' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/pingram/models/a2p_registration.rb', line 440

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      full_address == o.full_address &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone &&
      brand_status == o.brand_status &&
      campaign_status == o.campaign_status &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


461
462
463
# File 'lib/pingram/models/a2p_registration.rb', line 461

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



467
468
469
# File 'lib/pingram/models/a2p_registration.rb', line 467

def hash
  [, scenario_id, business_type, legal_name, tax_id, website, country, full_address, compliance_contact_email, compliance_contact_phone, brand_status, campaign_status, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/pingram/models/a2p_registration.rb', line 226

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @scenario_id.nil?
    invalid_properties.push('invalid value for "scenario_id", scenario_id cannot be nil.')
  end

  if @business_type.nil?
    invalid_properties.push('invalid value for "business_type", business_type cannot be nil.')
  end

  if @legal_name.nil?
    invalid_properties.push('invalid value for "legal_name", legal_name cannot be nil.')
  end

  if @website.nil?
    invalid_properties.push('invalid value for "website", website cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @full_address.nil?
    invalid_properties.push('invalid value for "full_address", full_address cannot be nil.')
  end

  if @compliance_contact_email.nil?
    invalid_properties.push('invalid value for "compliance_contact_email", compliance_contact_email cannot be nil.')
  end

  if @compliance_contact_phone.nil?
    invalid_properties.push('invalid value for "compliance_contact_phone", compliance_contact_phone cannot be nil.')
  end

  if @brand_status.nil?
    invalid_properties.push('invalid value for "brand_status", brand_status cannot be nil.')
  end

  if @campaign_status.nil?
    invalid_properties.push('invalid value for "campaign_status", campaign_status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/pingram/models/a2p_registration.rb', line 496

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/pingram/models/a2p_registration.rb', line 286

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @scenario_id.nil?
  return false if @business_type.nil?
  return false if @legal_name.nil?
  return false if @website.nil?
  return false if @country.nil?
  return false if @full_address.nil?
  return false if @compliance_contact_email.nil?
  return false if @compliance_contact_phone.nil?
  return false if @brand_status.nil?
  brand_status_validator = EnumAttributeValidator.new('String', ["not_started", "in_progress", "pending_review", "approved", "rejected", "info_needed"])
  return false unless brand_status_validator.valid?(@brand_status)
  return false if @campaign_status.nil?
  campaign_status_validator = EnumAttributeValidator.new('String', ["not_started", "in_progress", "pending_review", "approved", "rejected", "info_needed"])
  return false unless campaign_status_validator.valid?(@campaign_status)
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end