Class: Pingram::A2pRegistrationUpdateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/a2p_registration_update_request.rb

Overview

Request body for PUT /registrations/a2p

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ A2pRegistrationUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::A2pRegistrationUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::A2pRegistrationUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'full_address')
    self.full_address = attributes[:'full_address']
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  end
end

Instance Attribute Details

#business_typeObject

Returns the value of attribute business_type.



21
22
23
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 21

def business_type
  @business_type
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



33
34
35
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 33

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



35
36
37
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 35

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



29
30
31
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 29

def country
  @country
end

#full_addressObject

Returns the value of attribute full_address.



31
32
33
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 31

def full_address
  @full_address
end

Returns the value of attribute legal_name.



23
24
25
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 23

def legal_name
  @legal_name
end

#scenario_idObject

Returns the value of attribute scenario_id.



19
20
21
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 19

def scenario_id
  @scenario_id
end

#tax_idObject

Returns the value of attribute tax_id.



25
26
27
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 25

def tax_id
  @tax_id
end

#websiteObject

Returns the value of attribute website.



27
28
29
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 27

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 38

def self.attribute_map
  {
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'full_address' => :'fullAddress',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 182

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 63

def self.openapi_types
  {
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'full_address' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      full_address == o.full_address &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


169
170
171
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 169

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



175
176
177
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 175

def hash
  [scenario_id, business_type, legal_name, tax_id, website, country, full_address, compliance_contact_email, compliance_contact_phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
# File 'lib/pingram/models/a2p_registration_update_request.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end