Class: Pingram::AccountAddressesResponseAddressesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::AccountAddressesResponseAddressesInner
- Defined in:
- lib/pingram/models/account_addresses_response_addresses_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#domain ⇒ Object
Returns the value of attribute domain.
-
#full_address ⇒ Object
Returns the value of attribute full_address.
-
#prefix ⇒ Object
Returns the value of attribute prefix.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountAddressesResponseAddressesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountAddressesResponseAddressesInner
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::AccountAddressesResponseAddressesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::AccountAddressesResponseAddressesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_address') self.full_address = attributes[:'full_address'] else self.full_address = nil end if attributes.key?(:'prefix') self.prefix = attributes[:'prefix'] else self.prefix = nil end if attributes.key?(:'domain') self.domain = attributes[:'domain'] else self.domain = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
28 29 30 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 28 def created_at @created_at end |
#display_name ⇒ Object
Returns the value of attribute display_name.
26 27 28 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 26 def display_name @display_name end |
#domain ⇒ Object
Returns the value of attribute domain.
22 23 24 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 22 def domain @domain end |
#full_address ⇒ Object
Returns the value of attribute full_address.
18 19 20 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 18 def full_address @full_address end |
#prefix ⇒ Object
Returns the value of attribute prefix.
20 21 22 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 20 def prefix @prefix end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 24 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 53 def self.attribute_map { :'full_address' => :'fullAddress', :'prefix' => :'prefix', :'domain' => :'domain', :'type' => :'type', :'display_name' => :'displayName', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 263 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 75 def self.openapi_types { :'full_address' => :'String', :'prefix' => :'String', :'domain' => :'String', :'type' => :'String', :'display_name' => :'String', :'created_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && full_address == o.full_address && prefix == o.prefix && domain == o.domain && type == o.type && display_name == o.display_name && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 256 def hash [full_address, prefix, domain, type, display_name, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @full_address.nil? invalid_properties.push('invalid value for "full_address", full_address cannot be nil.') end if @prefix.nil? invalid_properties.push('invalid value for "prefix", prefix cannot be nil.') end if @domain.nil? invalid_properties.push('invalid value for "domain", domain cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/pingram/models/account_addresses_response_addresses_inner.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @full_address.nil? return false if @prefix.nil? return false if @domain.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["builtin", "custom"]) return false unless type_validator.valid?(@type) return false if @created_at.nil? true end |