Class: Pingram::AccountsApi
- Inherits:
-
Object
- Object
- Pingram::AccountsApi
- Defined in:
- lib/pingram/api/accounts_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#accounts_create_account(create_account_request, opts = {}) ⇒ CreateAccountResponse
Create an additional account for the authenticated user.
-
#accounts_create_account_with_http_info(create_account_request, opts = {}) ⇒ Array<(CreateAccountResponse, Integer, Hash)>
Create an additional account for the authenticated user.
-
#accounts_list_accounts(opts = {}) ⇒ ListAccountsResponse
List accounts the authenticated user can access.
-
#accounts_list_accounts_with_http_info(opts = {}) ⇒ Array<(ListAccountsResponse, Integer, Hash)>
List accounts the authenticated user can access.
-
#initialize(api_client = ApiClient.default) ⇒ AccountsApi
constructor
A new instance of AccountsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AccountsApi
Returns a new instance of AccountsApi.
19 20 21 |
# File 'lib/pingram/api/accounts_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/accounts_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#accounts_create_account(create_account_request, opts = {}) ⇒ CreateAccountResponse
Create an additional account for the authenticated user
26 27 28 29 |
# File 'lib/pingram/api/accounts_api.rb', line 26 def accounts_create_account(create_account_request, opts = {}) data, _status_code, _headers = accounts_create_account_with_http_info(create_account_request, opts) data end |
#accounts_create_account_with_http_info(create_account_request, opts = {}) ⇒ Array<(CreateAccountResponse, Integer, Hash)>
Create an additional account for the authenticated user
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/accounts_api.rb', line 35 def accounts_create_account_with_http_info(create_account_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountsApi.accounts_create_account ...' end # verify the required parameter 'create_account_request' is set if @api_client.config.client_side_validation && create_account_request.nil? fail ArgumentError, "Missing the required parameter 'create_account_request' when calling AccountsApi.accounts_create_account" end # resource path local_var_path = '/accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_account_request) # return_type return_type = opts[:debug_return_type] || 'CreateAccountResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountsApi.accounts_create_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#accounts_create_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#accounts_list_accounts(opts = {}) ⇒ ListAccountsResponse
List accounts the authenticated user can access
91 92 93 94 |
# File 'lib/pingram/api/accounts_api.rb', line 91 def accounts_list_accounts(opts = {}) data, _status_code, _headers = accounts_list_accounts_with_http_info(opts) data end |
#accounts_list_accounts_with_http_info(opts = {}) ⇒ Array<(ListAccountsResponse, Integer, Hash)>
List accounts the authenticated user can access
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/api/accounts_api.rb', line 99 def accounts_list_accounts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountsApi.accounts_list_accounts ...' end # resource path local_var_path = '/accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListAccountsResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountsApi.accounts_list_accounts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#accounts_list_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |