Class: Pingram::AddressesApi
- Inherits:
-
Object
- Object
- Pingram::AddressesApi
- Defined in:
- lib/pingram/api/addresses_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#addresses_create_address(create_address_request, opts = {}) ⇒ AddressResponse
Create a new email address for inbound/outbound purposes.
-
#addresses_create_address_with_http_info(create_address_request, opts = {}) ⇒ Array<(AddressResponse, Integer, Hash)>
Create a new email address for inbound/outbound purposes.
-
#addresses_list_addresses(opts = {}) ⇒ AccountAddressesResponse
Lists all email addresses the account has configured to send and receive emails.
-
#addresses_list_addresses_with_http_info(opts = {}) ⇒ Array<(AccountAddressesResponse, Integer, Hash)>
Lists all email addresses the account has configured to send and receive emails.
-
#addresses_update_address(update_address_request, opts = {}) ⇒ AddressResponse
Update an existing address.
-
#addresses_update_address_with_http_info(update_address_request, opts = {}) ⇒ Array<(AddressResponse, Integer, Hash)>
Update an existing address.
-
#initialize(api_client = ApiClient.default) ⇒ AddressesApi
constructor
A new instance of AddressesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AddressesApi
Returns a new instance of AddressesApi.
19 20 21 |
# File 'lib/pingram/api/addresses_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/addresses_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#addresses_create_address(create_address_request, opts = {}) ⇒ AddressResponse
Create a new email address for inbound/outbound purposes. Each account can have one builtin address and many custom addresses. Custom addresses must belong to configured domains.
26 27 28 29 |
# File 'lib/pingram/api/addresses_api.rb', line 26 def addresses_create_address(create_address_request, opts = {}) data, _status_code, _headers = addresses_create_address_with_http_info(create_address_request, opts) data end |
#addresses_create_address_with_http_info(create_address_request, opts = {}) ⇒ Array<(AddressResponse, Integer, Hash)>
Create a new email address for inbound/outbound purposes. Each account can have one builtin address and many custom addresses. Custom addresses must belong to configured domains.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/addresses_api.rb', line 35 def addresses_create_address_with_http_info(create_address_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.addresses_create_address ...' end # verify the required parameter 'create_address_request' is set if @api_client.config.client_side_validation && create_address_request.nil? fail ArgumentError, "Missing the required parameter 'create_address_request' when calling AddressesApi.addresses_create_address" end # resource path local_var_path = '/addresses' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_address_request) # return_type return_type = opts[:debug_return_type] || 'AddressResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AddressesApi.addresses_create_address", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#addresses_create_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#addresses_list_addresses(opts = {}) ⇒ AccountAddressesResponse
Lists all email addresses the account has configured to send and receive emails. Custom addresses must belong to configured domains.
91 92 93 94 |
# File 'lib/pingram/api/addresses_api.rb', line 91 def addresses_list_addresses(opts = {}) data, _status_code, _headers = addresses_list_addresses_with_http_info(opts) data end |
#addresses_list_addresses_with_http_info(opts = {}) ⇒ Array<(AccountAddressesResponse, Integer, Hash)>
Lists all email addresses the account has configured to send and receive emails. Custom addresses must belong to configured domains.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/api/addresses_api.rb', line 99 def addresses_list_addresses_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.addresses_list_addresses ...' end # resource path local_var_path = '/addresses' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AccountAddressesResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AddressesApi.addresses_list_addresses", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#addresses_list_addresses\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#addresses_update_address(update_address_request, opts = {}) ⇒ AddressResponse
Update an existing address
147 148 149 150 |
# File 'lib/pingram/api/addresses_api.rb', line 147 def addresses_update_address(update_address_request, opts = {}) data, _status_code, _headers = addresses_update_address_with_http_info(update_address_request, opts) data end |
#addresses_update_address_with_http_info(update_address_request, opts = {}) ⇒ Array<(AddressResponse, Integer, Hash)>
Update an existing address
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/pingram/api/addresses_api.rb', line 156 def addresses_update_address_with_http_info(update_address_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.addresses_update_address ...' end # verify the required parameter 'update_address_request' is set if @api_client.config.client_side_validation && update_address_request.nil? fail ArgumentError, "Missing the required parameter 'update_address_request' when calling AddressesApi.addresses_update_address" end # resource path local_var_path = '/addresses' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_address_request) # return_type return_type = opts[:debug_return_type] || 'AddressResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AddressesApi.addresses_update_address", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#addresses_update_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |