Class: Pingram::BindNumberResponseAgent

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/bind_number_response_agent.rb

Overview

Agent record returned by GET /voice/agents.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BindNumberResponseAgent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/pingram/models/bind_number_response_agent.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::BindNumberResponseAgent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::BindNumberResponseAgent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'agent_id')
    self.agent_id = attributes[:'agent_id']
  else
    self.agent_id = nil
  end

  if attributes.key?(:'deployment')
    self.deployment = attributes[:'deployment']
  else
    self.deployment = nil
  end

  if attributes.key?(:'spec')
    self.spec = attributes[:'spec']
  else
    self.spec = nil
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  else
    self.phone_numbers = nil
  end

  if attributes.key?(:'worker_presence')
    self.worker_presence = attributes[:'worker_presence']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#agent_idObject

Returns the value of attribute agent_id.



19
20
21
# File 'lib/pingram/models/bind_number_response_agent.rb', line 19

def agent_id
  @agent_id
end

#created_atObject

Returns the value of attribute created_at.



29
30
31
# File 'lib/pingram/models/bind_number_response_agent.rb', line 29

def created_at
  @created_at
end

#deploymentObject

Returns the value of attribute deployment.



21
22
23
# File 'lib/pingram/models/bind_number_response_agent.rb', line 21

def deployment
  @deployment
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



25
26
27
# File 'lib/pingram/models/bind_number_response_agent.rb', line 25

def phone_numbers
  @phone_numbers
end

#specObject

Returns the value of attribute spec.



23
24
25
# File 'lib/pingram/models/bind_number_response_agent.rb', line 23

def spec
  @spec
end

#updated_atObject

Returns the value of attribute updated_at.



31
32
33
# File 'lib/pingram/models/bind_number_response_agent.rb', line 31

def updated_at
  @updated_at
end

#worker_presenceObject

Returns the value of attribute worker_presence.



27
28
29
# File 'lib/pingram/models/bind_number_response_agent.rb', line 27

def worker_presence
  @worker_presence
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/pingram/models/bind_number_response_agent.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/pingram/models/bind_number_response_agent.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/pingram/models/bind_number_response_agent.rb', line 56

def self.attribute_map
  {
    :'agent_id' => :'agentId',
    :'deployment' => :'deployment',
    :'spec' => :'spec',
    :'phone_numbers' => :'phoneNumbers',
    :'worker_presence' => :'workerPresence',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/pingram/models/bind_number_response_agent.rb', line 304

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/pingram/models/bind_number_response_agent.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
# File 'lib/pingram/models/bind_number_response_agent.rb', line 79

def self.openapi_types
  {
    :'agent_id' => :'String',
    :'deployment' => :'String',
    :'spec' => :'BindNumberResponseAgentSpec',
    :'phone_numbers' => :'Array<String>',
    :'worker_presence' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



277
278
279
280
281
282
283
284
285
286
287
# File 'lib/pingram/models/bind_number_response_agent.rb', line 277

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      agent_id == o.agent_id &&
      deployment == o.deployment &&
      spec == o.spec &&
      phone_numbers == o.phone_numbers &&
      worker_presence == o.worker_presence &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


291
292
293
# File 'lib/pingram/models/bind_number_response_agent.rb', line 291

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



297
298
299
# File 'lib/pingram/models/bind_number_response_agent.rb', line 297

def hash
  [agent_id, deployment, spec, phone_numbers, worker_presence, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/pingram/models/bind_number_response_agent.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @agent_id.nil?
    invalid_properties.push('invalid value for "agent_id", agent_id cannot be nil.')
  end

  if @deployment.nil?
    invalid_properties.push('invalid value for "deployment", deployment cannot be nil.')
  end

  if @spec.nil?
    invalid_properties.push('invalid value for "spec", spec cannot be nil.')
  end

  if @phone_numbers.nil?
    invalid_properties.push('invalid value for "phone_numbers", phone_numbers cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/pingram/models/bind_number_response_agent.rb', line 326

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/pingram/models/bind_number_response_agent.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @agent_id.nil?
  return false if @deployment.nil?
  deployment_validator = EnumAttributeValidator.new('String', ["hosted", "ejected"])
  return false unless deployment_validator.valid?(@deployment)
  return false if @spec.nil?
  return false if @phone_numbers.nil?
  worker_presence_validator = EnumAttributeValidator.new('String', ["online", "offline"])
  return false unless worker_presence_validator.valid?(@worker_presence)
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end