Class: Pingram::BindNumberResponseAgentSpec

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/bind_number_response_agent_spec.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BindNumberResponseAgentSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::BindNumberResponseAgentSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::BindNumberResponseAgentSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'instructions')
    self.instructions = attributes[:'instructions']
  else
    self.instructions = nil
  end

  if attributes.key?(:'inbound')
    self.inbound = attributes[:'inbound']
  else
    self.inbound = nil
  end

  if attributes.key?(:'outbound')
    self.outbound = attributes[:'outbound']
  else
    self.outbound = nil
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  else
    self.model = nil
  end

  if attributes.key?(:'tools')
    if (value = attributes[:'tools']).is_a?(Array)
      self.tools = value
    end
  else
    self.tools = nil
  end

  if attributes.key?(:'variables')
    if (value = attributes[:'variables']).is_a?(Array)
      self.variables = value
    end
  else
    self.variables = nil
  end

  if attributes.key?(:'conversation')
    self.conversation = attributes[:'conversation']
  else
    self.conversation = nil
  end

  if attributes.key?(:'compliance')
    self.compliance = attributes[:'compliance']
  else
    self.compliance = nil
  end
end

Instance Attribute Details

#complianceObject

Returns the value of attribute compliance.



34
35
36
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 34

def compliance
  @compliance
end

#conversationObject

Returns the value of attribute conversation.



32
33
34
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 32

def conversation
  @conversation
end

#inboundObject

Returns the value of attribute inbound.



22
23
24
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 22

def inbound
  @inbound
end

#instructionsObject

Returns the value of attribute instructions.



20
21
22
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 20

def instructions
  @instructions
end

#modelObject

Returns the value of attribute model.



26
27
28
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 26

def model
  @model
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 18

def name
  @name
end

#outboundObject

Returns the value of attribute outbound.



24
25
26
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 24

def outbound
  @outbound
end

#toolsObject

Returns the value of attribute tools.



28
29
30
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 28

def tools
  @tools
end

#variablesObject

Returns the value of attribute variables.



30
31
32
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 30

def variables
  @variables
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 37

def self.attribute_map
  {
    :'name' => :'name',
    :'instructions' => :'instructions',
    :'inbound' => :'inbound',
    :'outbound' => :'outbound',
    :'model' => :'model',
    :'tools' => :'tools',
    :'variables' => :'variables',
    :'conversation' => :'conversation',
    :'compliance' => :'compliance'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 338

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 62

def self.openapi_types
  {
    :'name' => :'String',
    :'instructions' => :'String',
    :'inbound' => :'BindNumberResponseAgentSpecInbound',
    :'outbound' => :'BindNumberResponseAgentSpecOutbound',
    :'model' => :'BindNumberResponseAgentSpecModel',
    :'tools' => :'Array<BindNumberResponseAgentSpecToolsInner>',
    :'variables' => :'Array<BindNumberResponseAgentSpecVariablesInner>',
    :'conversation' => :'BindNumberResponseAgentSpecConversation',
    :'compliance' => :'BindNumberResponseAgentSpecCompliance'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      instructions == o.instructions &&
      inbound == o.inbound &&
      outbound == o.outbound &&
      model == o.model &&
      tools == o.tools &&
      variables == o.variables &&
      conversation == o.conversation &&
      compliance == o.compliance
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


325
326
327
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 325

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



331
332
333
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 331

def hash
  [name, instructions, inbound, outbound, model, tools, variables, conversation, compliance].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @instructions.nil?
    invalid_properties.push('invalid value for "instructions", instructions cannot be nil.')
  end

  if @inbound.nil?
    invalid_properties.push('invalid value for "inbound", inbound cannot be nil.')
  end

  if @outbound.nil?
    invalid_properties.push('invalid value for "outbound", outbound cannot be nil.')
  end

  if @model.nil?
    invalid_properties.push('invalid value for "model", model cannot be nil.')
  end

  if @tools.nil?
    invalid_properties.push('invalid value for "tools", tools cannot be nil.')
  end

  if @variables.nil?
    invalid_properties.push('invalid value for "variables", variables cannot be nil.')
  end

  if @conversation.nil?
    invalid_properties.push('invalid value for "conversation", conversation cannot be nil.')
  end

  if @compliance.nil?
    invalid_properties.push('invalid value for "compliance", compliance cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pingram/models/bind_number_response_agent_spec.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @instructions.nil?
  return false if @inbound.nil?
  return false if @outbound.nil?
  return false if @model.nil?
  return false if @tools.nil?
  return false if @variables.nil?
  return false if @conversation.nil?
  return false if @compliance.nil?
  true
end