Class: Pingram::ComponentsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/components_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ComponentsApi

Returns a new instance of ComponentsApi.



19
20
21
# File 'lib/pingram/api/components_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/components_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#components_create_component(email_component_post_request, opts = {}) ⇒ EmailComponentResponse

Create a new component

Parameters:

Returns:



26
27
28
29
# File 'lib/pingram/api/components_api.rb', line 26

def components_create_component(email_component_post_request, opts = {})
  data, _status_code, _headers = components_create_component_with_http_info(email_component_post_request, opts)
  data
end

#components_create_component_with_http_info(email_component_post_request, opts = {}) ⇒ Array<(EmailComponentResponse, Integer, Hash)>

Create a new component

Parameters:

Returns:

  • (Array<(EmailComponentResponse, Integer, Hash)>)

    EmailComponentResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pingram/api/components_api.rb', line 35

def components_create_component_with_http_info(email_component_post_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ComponentsApi.components_create_component ...'
  end
  # verify the required parameter 'email_component_post_request' is set
  if @api_client.config.client_side_validation && email_component_post_request.nil?
    fail ArgumentError, "Missing the required parameter 'email_component_post_request' when calling ComponentsApi.components_create_component"
  end
  # resource path
  local_var_path = '/components'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(email_component_post_request)

  # return_type
  return_type = opts[:debug_return_type] || 'EmailComponentResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"ComponentsApi.components_create_component",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ComponentsApi#components_create_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#components_delete_component(component_id, opts = {}) ⇒ nil

Delete a component

Parameters:

  • component_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


92
93
94
95
# File 'lib/pingram/api/components_api.rb', line 92

def components_delete_component(component_id, opts = {})
  components_delete_component_with_http_info(component_id, opts)
  nil
end

#components_delete_component_with_http_info(component_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a component

Parameters:

  • component_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/pingram/api/components_api.rb', line 101

def components_delete_component_with_http_info(component_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ComponentsApi.components_delete_component ...'
  end
  # verify the required parameter 'component_id' is set
  if @api_client.config.client_side_validation && component_id.nil?
    fail ArgumentError, "Missing the required parameter 'component_id' when calling ComponentsApi.components_delete_component"
  end
  # resource path
  local_var_path = '/components/{componentId}'.sub('{' + 'componentId' + '}', CGI.escape(component_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"ComponentsApi.components_delete_component",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ComponentsApi#components_delete_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#components_get_component(component_id, opts = {}) ⇒ EmailComponentResponse

Get a specific component by ID

Parameters:

  • component_id (String)

    Component ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



153
154
155
156
# File 'lib/pingram/api/components_api.rb', line 153

def components_get_component(component_id, opts = {})
  data, _status_code, _headers = components_get_component_with_http_info(component_id, opts)
  data
end

#components_get_component_with_http_info(component_id, opts = {}) ⇒ Array<(EmailComponentResponse, Integer, Hash)>

Get a specific component by ID

Parameters:

  • component_id (String)

    Component ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(EmailComponentResponse, Integer, Hash)>)

    EmailComponentResponse data, response status code and response headers



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/pingram/api/components_api.rb', line 162

def components_get_component_with_http_info(component_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ComponentsApi.components_get_component ...'
  end
  # verify the required parameter 'component_id' is set
  if @api_client.config.client_side_validation && component_id.nil?
    fail ArgumentError, "Missing the required parameter 'component_id' when calling ComponentsApi.components_get_component"
  end
  # resource path
  local_var_path = '/components/{componentId}'.sub('{' + 'componentId' + '}', CGI.escape(component_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EmailComponentResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"ComponentsApi.components_get_component",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ComponentsApi#components_get_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#components_list_components(channel, opts = {}) ⇒ Array<GetEmailComponentsResponseInner>

List email components

Parameters:

  • channel (String)

    Channel type (EMAIL, SMS, etc.)

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



214
215
216
217
# File 'lib/pingram/api/components_api.rb', line 214

def components_list_components(channel, opts = {})
  data, _status_code, _headers = components_list_components_with_http_info(channel, opts)
  data
end

#components_list_components_parsed(opts = {}) ⇒ Array<Object>

List all account components with the internal JSON parsed

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<Object>)


274
275
276
277
# File 'lib/pingram/api/components_api.rb', line 274

def components_list_components_parsed(opts = {})
  data, _status_code, _headers = components_list_components_parsed_with_http_info(opts)
  data
end

#components_list_components_parsed_with_http_info(opts = {}) ⇒ Array<(Array<Object>, Integer, Hash)>

List all account components with the internal JSON parsed

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<Object>, Integer, Hash)>)

    Array data, response status code and response headers

    
    
    282
    283
    284
    285
    286
    287
    288
    289
    290
    291
    292
    293
    294
    295
    296
    297
    298
    299
    300
    301
    302
    303
    304
    305
    306
    307
    308
    309
    310
    311
    312
    313
    314
    315
    316
    317
    318
    319
    320
    321
    322
    323
    324
    # File 'lib/pingram/api/components_api.rb', line 282
    
    def components_list_components_parsed_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ComponentsApi.components_list_components_parsed ...'
      end
      # resource path
      local_var_path = '/components/public'
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'Array<Object>'
    
      # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
      auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']
    
      new_options = opts.merge(
        :operation => :"ComponentsApi.components_list_components_parsed",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ComponentsApi#components_list_components_parsed\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #components_list_components_with_http_info(channel, opts = {}) ⇒ Array<(Array<GetEmailComponentsResponseInner>, Integer, Hash)>

    List email components

    Parameters:

    • channel (String)

      Channel type (EMAIL, SMS, etc.)

    • opts (Hash) (defaults to: {})

      the optional parameters

    Returns:

    
    
    223
    224
    225
    226
    227
    228
    229
    230
    231
    232
    233
    234
    235
    236
    237
    238
    239
    240
    241
    242
    243
    244
    245
    246
    247
    248
    249
    250
    251
    252
    253
    254
    255
    256
    257
    258
    259
    260
    261
    262
    263
    264
    265
    266
    267
    268
    269
    # File 'lib/pingram/api/components_api.rb', line 223
    
    def components_list_components_with_http_info(channel, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ComponentsApi.components_list_components ...'
      end
      # verify the required parameter 'channel' is set
      if @api_client.config.client_side_validation && channel.nil?
        fail ArgumentError, "Missing the required parameter 'channel' when calling ComponentsApi.components_list_components"
      end
      # resource path
      local_var_path = '/components'.sub('{' + 'channel' + '}', CGI.escape(channel.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'Array<GetEmailComponentsResponseInner>'
    
      # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
      auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']
    
      new_options = opts.merge(
        :operation => :"ComponentsApi.components_list_components",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ComponentsApi#components_list_components\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #components_patch_component(component_id, email_component_patch_request, opts = {}) ⇒ EmailComponentResponse

    Update a component's properties

    Parameters:

    • component_id (String)

      Component ID

    • email_component_patch_request (EmailComponentPatchRequest)
    • opts (Hash) (defaults to: {})

      the optional parameters

    Returns:

    
    
    331
    332
    333
    334
    # File 'lib/pingram/api/components_api.rb', line 331
    
    def components_patch_component(component_id, email_component_patch_request, opts = {})
      data, _status_code, _headers = components_patch_component_with_http_info(component_id, email_component_patch_request, opts)
      data
    end

    #components_patch_component_with_http_info(component_id, email_component_patch_request, opts = {}) ⇒ Array<(EmailComponentResponse, Integer, Hash)>

    Update a component's properties

    Parameters:

    • component_id (String)

      Component ID

    • email_component_patch_request (EmailComponentPatchRequest)
    • opts (Hash) (defaults to: {})

      the optional parameters

    Returns:

    • (Array<(EmailComponentResponse, Integer, Hash)>)

      EmailComponentResponse data, response status code and response headers

    
    
    341
    342
    343
    344
    345
    346
    347
    348
    349
    350
    351
    352
    353
    354
    355
    356
    357
    358
    359
    360
    361
    362
    363
    364
    365
    366
    367
    368
    369
    370
    371
    372
    373
    374
    375
    376
    377
    378
    379
    380
    381
    382
    383
    384
    385
    386
    387
    388
    389
    390
    391
    392
    393
    394
    395
    396
    # File 'lib/pingram/api/components_api.rb', line 341
    
    def components_patch_component_with_http_info(component_id, email_component_patch_request, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ComponentsApi.components_patch_component ...'
      end
      # verify the required parameter 'component_id' is set
      if @api_client.config.client_side_validation && component_id.nil?
        fail ArgumentError, "Missing the required parameter 'component_id' when calling ComponentsApi.components_patch_component"
      end
      # verify the required parameter 'email_component_patch_request' is set
      if @api_client.config.client_side_validation && email_component_patch_request.nil?
        fail ArgumentError, "Missing the required parameter 'email_component_patch_request' when calling ComponentsApi.components_patch_component"
      end
      # resource path
      local_var_path = '/components/{componentId}'.sub('{' + 'componentId' + '}', CGI.escape(component_id.to_s))
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
      # HTTP header 'Content-Type'
      content_type = @api_client.select_header_content_type(['application/json'])
      if !content_type.nil?
          header_params['Content-Type'] = content_type
      end
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body] || @api_client.object_to_http_body(email_component_patch_request)
    
      # return_type
      return_type = opts[:debug_return_type] || 'EmailComponentResponse'
    
      # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
      auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']
    
      new_options = opts.merge(
        :operation => :"ComponentsApi.components_patch_component",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ComponentsApi#components_patch_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end