Class: Pingram::CreateLibraryResponse

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/create_library_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateLibraryResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/pingram/models/create_library_response.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::CreateLibraryResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::CreateLibraryResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'use_case')
    self.use_case = attributes[:'use_case']
  else
    self.use_case = nil
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  else
    self.filename = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'upload_url')
    self.upload_url = attributes[:'upload_url']
  else
    self.upload_url = nil
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  else
    self.content_type = nil
  end
end

Instance Attribute Details

#content_type ⇒ Object

Returns the value of attribute content_type.



32
33
34
# File 'lib/pingram/models/create_library_response.rb', line 32

def content_type
  @content_type
end

#filename ⇒ Object

Returns the value of attribute filename.



22
23
24
# File 'lib/pingram/models/create_library_response.rb', line 22

def filename
  @filename
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/pingram/models/create_library_response.rb', line 18

def id
  @id
end

#key ⇒ Object

Returns the value of attribute key.



24
25
26
# File 'lib/pingram/models/create_library_response.rb', line 24

def key
  @key
end

#upload_url ⇒ Object

Time-limited upload URL. PUT the file bytes with the same Content-Type.



30
31
32
# File 'lib/pingram/models/create_library_response.rb', line 30

def upload_url
  @upload_url
end

#url ⇒ Object

Public URL to use in emails after the file is uploaded to uploadUrl.



27
28
29
# File 'lib/pingram/models/create_library_response.rb', line 27

def url
  @url
end

#use_case ⇒ Object

Returns the value of attribute use_case.



20
21
22
# File 'lib/pingram/models/create_library_response.rb', line 20

def use_case
  @use_case
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



70
71
72
# File 'lib/pingram/models/create_library_response.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/pingram/models/create_library_response.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/pingram/models/create_library_response.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'use_case' => :'useCase',
    :'filename' => :'filename',
    :'key' => :'key',
    :'url' => :'url',
    :'upload_url' => :'uploadUrl',
    :'content_type' => :'contentType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/pingram/models/create_library_response.rb', line 308

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



93
94
95
96
# File 'lib/pingram/models/create_library_response.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/pingram/models/create_library_response.rb', line 80

def self.openapi_types
  {
    :'id' => :'String',
    :'use_case' => :'String',
    :'filename' => :'String',
    :'key' => :'String',
    :'url' => :'String',
    :'upload_url' => :'String',
    :'content_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



281
282
283
284
285
286
287
288
289
290
291
# File 'lib/pingram/models/create_library_response.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      use_case == o.use_case &&
      filename == o.filename &&
      key == o.key &&
      url == o.url &&
      upload_url == o.upload_url &&
      content_type == o.content_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


295
296
297
# File 'lib/pingram/models/create_library_response.rb', line 295

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



301
302
303
# File 'lib/pingram/models/create_library_response.rb', line 301

def hash
  [id, use_case, filename, key, url, upload_url, content_type].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/pingram/models/create_library_response.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @use_case.nil?
    invalid_properties.push('invalid value for "use_case", use_case cannot be nil.')
  end

  if @filename.nil?
    invalid_properties.push('invalid value for "filename", filename cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @upload_url.nil?
    invalid_properties.push('invalid value for "upload_url", upload_url cannot be nil.')
  end

  if @content_type.nil?
    invalid_properties.push('invalid value for "content_type", content_type cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/pingram/models/create_library_response.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/pingram/models/create_library_response.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @use_case.nil?
  use_case_validator = EnumAttributeValidator.new('String', ["media", "logos"])
  return false unless use_case_validator.valid?(@use_case)
  return false if @filename.nil?
  return false if @key.nil?
  return false if @url.nil?
  return false if @upload_url.nil?
  return false if @content_type.nil?
  true
end