Class: Pingram::CreatePersonalAccessTokenResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/create_personal_access_token_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreatePersonalAccessTokenResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::CreatePersonalAccessTokenResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::CreatePersonalAccessTokenResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'token_prefix')
    self.token_prefix = attributes[:'token_prefix']
  else
    self.token_prefix = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end

  if attributes.key?(:'revoked')
    self.revoked = attributes[:'revoked']
  else
    self.revoked = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



24
25
26
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 24

def created_at
  @created_at
end

#expires_atObject

Returns the value of attribute expires_at.



26
27
28
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 26

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 18

def id
  @id
end

#last_used_atObject

Returns the value of attribute last_used_at.



28
29
30
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 28

def last_used_at
  @last_used_at
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 20

def name
  @name
end

#revokedObject

Returns the value of attribute revoked.



30
31
32
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 30

def revoked
  @revoked
end

#tokenObject

Full token — returned only on create. Store it securely; it cannot be retrieved again.



33
34
35
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 33

def token
  @token
end

#token_prefixObject

Returns the value of attribute token_prefix.



22
23
24
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 22

def token_prefix
  @token_prefix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'token_prefix' => :'tokenPrefix',
    :'created_at' => :'createdAt',
    :'expires_at' => :'expiresAt',
    :'last_used_at' => :'lastUsedAt',
    :'revoked' => :'revoked',
    :'token' => :'token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'token_prefix' => :'String',
    :'created_at' => :'String',
    :'expires_at' => :'String',
    :'last_used_at' => :'String',
    :'revoked' => :'Boolean',
    :'token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      token_prefix == o.token_prefix &&
      created_at == o.created_at &&
      expires_at == o.expires_at &&
      last_used_at == o.last_used_at &&
      revoked == o.revoked &&
      token == o.token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 268

def hash
  [id, name, token_prefix, created_at, expires_at, last_used_at, revoked, token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @token_prefix.nil?
    invalid_properties.push('invalid value for "token_prefix", token_prefix cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @revoked.nil?
    invalid_properties.push('invalid value for "revoked", revoked cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
183
# File 'lib/pingram/models/create_personal_access_token_response.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @token_prefix.nil?
  return false if @created_at.nil?
  return false if @revoked.nil?
  return false if @token.nil?
  true
end