Class: Pingram::DefaultApi
- Inherits:
-
Object
- Object
- Pingram::DefaultApi
- Defined in:
- lib/pingram/api/default_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#call_send(sender_post_body, opts = {}) ⇒ SenderPostResponse
Send a notification (email, SMS, etc.) to one user.
-
#call_send_with_http_info(sender_post_body, opts = {}) ⇒ Array<(SenderPostResponse, Integer, Hash)>
Send a notification (email, SMS, etc.) to one user.
-
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
constructor
A new instance of DefaultApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
Returns a new instance of DefaultApi.
19 20 21 |
# File 'lib/pingram/api/default_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/default_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#call_send(sender_post_body, opts = {}) ⇒ SenderPostResponse
Send a notification (email, SMS, etc.) to one user. Requires a notification type which categorizes this messages for future reporting, and channel-specific payloads such as email or sms. Recipient is specified with the to parameter. Returns a trackingId for error or delivery lookup through our Logs.
26 27 28 29 |
# File 'lib/pingram/api/default_api.rb', line 26 def call_send(sender_post_body, opts = {}) data, _status_code, _headers = call_send_with_http_info(sender_post_body, opts) data end |
#call_send_with_http_info(sender_post_body, opts = {}) ⇒ Array<(SenderPostResponse, Integer, Hash)>
Send a notification (email, SMS, etc.) to one user. Requires a notification `type` which categorizes this messages for future reporting, and channel-specific payloads such as `email` or `sms`. Recipient is specified with the `to` parameter. Returns a `trackingId` for error or delivery lookup through our Logs.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/default_api.rb', line 35 def call_send_with_http_info(sender_post_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.call_send ...' end # verify the required parameter 'sender_post_body' is set if @api_client.config.client_side_validation && sender_post_body.nil? fail ArgumentError, "Missing the required parameter 'sender_post_body' when calling DefaultApi.call_send" end # resource path local_var_path = '/send' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(sender_post_body) # return_type return_type = opts[:debug_return_type] || 'SenderPostResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"DefaultApi.call_send", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#call_send\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |