Class: Pingram::EmailComponentResponseReferencedByInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/email_component_response_referenced_by_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EmailComponentResponseReferencedByInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::EmailComponentResponseReferencedByInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::EmailComponentResponseReferencedByInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  else
    self.notification_id = nil
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  else
    self.channel = nil
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end
end

Instance Attribute Details

#channelObject

Returns the value of attribute channel.



20
21
22
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 20

def channel
  @channel
end

#notification_idObject

Returns the value of attribute notification_id.



18
19
20
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 18

def notification_id
  @notification_id
end

#template_idObject

Returns the value of attribute template_id.



22
23
24
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 22

def template_id
  @template_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 47

def self.attribute_map
  {
    :'notification_id' => :'notificationId',
    :'channel' => :'channel',
    :'template_id' => :'templateId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 66

def self.openapi_types
  {
    :'notification_id' => :'String',
    :'channel' => :'ChannelsEnum',
    :'template_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



177
178
179
180
181
182
183
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      notification_id == o.notification_id &&
      channel == o.channel &&
      template_id == o.template_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 193

def hash
  [notification_id, channel, template_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @channel.nil?
    invalid_properties.push('invalid value for "channel", channel cannot be nil.')
  end

  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
# File 'lib/pingram/models/email_component_response_referenced_by_inner.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @notification_id.nil?
  return false if @channel.nil?
  return false if @template_id.nil?
  true
end