Class: Pingram::EnvironmentPatchRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/environment_patch_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EnvironmentPatchRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/pingram/models/environment_patch_request.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::EnvironmentPatchRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::EnvironmentPatchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'reset_secret')
    self.reset_secret = attributes[:'reset_secret']
  end

  if attributes.key?(:'disable_sending')
    if (value = attributes[:'disable_sending']).is_a?(Array)
      self.disable_sending = value
    end
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'secure_mode')
    self.secure_mode = attributes[:'secure_mode']
  end
end

Instance Attribute Details

#disable_sendingObject

Returns the value of attribute disable_sending.



20
21
22
# File 'lib/pingram/models/environment_patch_request.rb', line 20

def disable_sending
  @disable_sending
end

#reset_secretObject

Returns the value of attribute reset_secret.



18
19
20
# File 'lib/pingram/models/environment_patch_request.rb', line 18

def reset_secret
  @reset_secret
end

#secure_modeObject

Returns the value of attribute secure_mode.



24
25
26
# File 'lib/pingram/models/environment_patch_request.rb', line 24

def secure_mode
  @secure_mode
end

#titleObject

Returns the value of attribute title.



22
23
24
# File 'lib/pingram/models/environment_patch_request.rb', line 22

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/pingram/models/environment_patch_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/pingram/models/environment_patch_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/pingram/models/environment_patch_request.rb', line 27

def self.attribute_map
  {
    :'reset_secret' => :'resetSecret',
    :'disable_sending' => :'disableSending',
    :'title' => :'title',
    :'secure_mode' => :'secureMode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pingram/models/environment_patch_request.rb', line 138

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/pingram/models/environment_patch_request.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/pingram/models/environment_patch_request.rb', line 47

def self.openapi_types
  {
    :'reset_secret' => :'Boolean',
    :'disable_sending' => :'Array<ChannelsEnum>',
    :'title' => :'String',
    :'secure_mode' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



114
115
116
117
118
119
120
121
# File 'lib/pingram/models/environment_patch_request.rb', line 114

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      reset_secret == o.reset_secret &&
      disable_sending == o.disable_sending &&
      title == o.title &&
      secure_mode == o.secure_mode
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/pingram/models/environment_patch_request.rb', line 125

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



131
132
133
# File 'lib/pingram/models/environment_patch_request.rb', line 131

def hash
  [reset_secret, disable_sending, title, secure_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
# File 'lib/pingram/models/environment_patch_request.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pingram/models/environment_patch_request.rb', line 160

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



107
108
109
110
# File 'lib/pingram/models/environment_patch_request.rb', line 107

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end