Class: Pingram::GetInappNotificationsResponseNotificationsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetInappNotificationsResponseNotificationsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetInappNotificationsResponseNotificationsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetInappNotificationsResponseNotificationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  else
    self.notification_id = nil
  end

  if attributes.key?(:'sub_notification_id')
    self.sub_notification_id = attributes[:'sub_notification_id']
  end

  if attributes.key?(:'seen')
    self.seen = attributes[:'seen']
  else
    self.seen = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'delivery_options')
    self.delivery_options = attributes[:'delivery_options']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'parameters')
    if (value = attributes[:'parameters']).is_a?(Hash)
      self.parameters = value
    end
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'opened')
    self.opened = attributes[:'opened']
  end

  if attributes.key?(:'clicked')
    self.clicked = attributes[:'clicked']
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end

  if attributes.key?(:'actioned1')
    self.actioned1 = attributes[:'actioned1']
  end

  if attributes.key?(:'actioned2')
    self.actioned2 = attributes[:'actioned2']
  end

  if attributes.key?(:'replies')
    if (value = attributes[:'replies']).is_a?(Array)
      self.replies = value
    end
  end

  if attributes.key?(:'exp_date')
    self.exp_date = attributes[:'exp_date']
  end
end

Instance Attribute Details

#actioned1Object

Returns the value of attribute actioned1.



46
47
48
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 46

def actioned1
  @actioned1
end

#actioned2Object

Returns the value of attribute actioned2.



48
49
50
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 48

def actioned2
  @actioned2
end

#archivedObject

Returns the value of attribute archived.



44
45
46
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 44

def archived
  @archived
end

#clickedObject

Returns the value of attribute clicked.



42
43
44
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 42

def clicked
  @clicked
end

#dateObject

Returns the value of attribute date.



38
39
40
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 38

def date
  @date
end

#delivery_optionsObject

Returns the value of attribute delivery_options.



32
33
34
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 32

def delivery_options
  @delivery_options
end

#exp_dateObject

Returns the value of attribute exp_date.



52
53
54
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 52

def exp_date
  @exp_date
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 18

def id
  @id
end

#image_urlObject

Returns the value of attribute image_url.



30
31
32
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 30

def image_url
  @image_url
end

#notification_idObject

Returns the value of attribute notification_id.



20
21
22
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 20

def notification_id
  @notification_id
end

#openedObject

Returns the value of attribute opened.



40
41
42
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 40

def opened
  @opened
end

#parametersObject

Returns the value of attribute parameters.



36
37
38
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 36

def parameters
  @parameters
end

#redirect_urlObject

Returns the value of attribute redirect_url.



28
29
30
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 28

def redirect_url
  @redirect_url
end

#repliesObject

Returns the value of attribute replies.



50
51
52
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 50

def replies
  @replies
end

#seenObject

Returns the value of attribute seen.



24
25
26
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 24

def seen
  @seen
end

#sub_notification_idObject

Returns the value of attribute sub_notification_id.



22
23
24
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 22

def sub_notification_id
  @sub_notification_id
end

#templateObject

Returns the value of attribute template.



34
35
36
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 34

def template
  @template
end

#titleObject

Returns the value of attribute title.



26
27
28
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 26

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'notification_id' => :'notificationId',
    :'sub_notification_id' => :'subNotificationId',
    :'seen' => :'seen',
    :'title' => :'title',
    :'redirect_url' => :'redirectURL',
    :'image_url' => :'imageURL',
    :'delivery_options' => :'deliveryOptions',
    :'template' => :'template',
    :'parameters' => :'parameters',
    :'date' => :'date',
    :'opened' => :'opened',
    :'clicked' => :'clicked',
    :'archived' => :'archived',
    :'actioned1' => :'actioned1',
    :'actioned2' => :'actioned2',
    :'replies' => :'replies',
    :'exp_date' => :'expDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 351

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'notification_id' => :'String',
    :'sub_notification_id' => :'String',
    :'seen' => :'Boolean',
    :'title' => :'String',
    :'redirect_url' => :'String',
    :'image_url' => :'String',
    :'delivery_options' => :'GetInappNotificationsResponseNotificationsInnerDeliveryOptions',
    :'template' => :'GetInappNotificationsResponseNotificationsInnerTemplate',
    :'parameters' => :'Hash<String, Object>',
    :'date' => :'String',
    :'opened' => :'String',
    :'clicked' => :'String',
    :'archived' => :'String',
    :'actioned1' => :'String',
    :'actioned2' => :'String',
    :'replies' => :'Array<GetInappNotificationsResponseNotificationsInnerRepliesInner>',
    :'exp_date' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 313

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      notification_id == o.notification_id &&
      sub_notification_id == o.sub_notification_id &&
      seen == o.seen &&
      title == o.title &&
      redirect_url == o.redirect_url &&
      image_url == o.image_url &&
      delivery_options == o.delivery_options &&
      template == o.template &&
      parameters == o.parameters &&
      date == o.date &&
      opened == o.opened &&
      clicked == o.clicked &&
      archived == o.archived &&
      actioned1 == o.actioned1 &&
      actioned2 == o.actioned2 &&
      replies == o.replies &&
      exp_date == o.exp_date
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 338

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



344
345
346
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 344

def hash
  [id, notification_id, sub_notification_id, seen, title, redirect_url, image_url, delivery_options, template, parameters, date, opened, clicked, archived, actioned1, actioned2, replies, exp_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @seen.nil?
    invalid_properties.push('invalid value for "seen", seen cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 373

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



251
252
253
254
255
256
257
258
259
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner.rb', line 251

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @notification_id.nil?
  return false if @seen.nil?
  return false if @title.nil?
  return false if @date.nil?
  true
end