Class: Pingram::GetInappNotificationsResponseNotificationsInnerTemplateAnyOf
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::GetInappNotificationsResponseNotificationsInnerTemplateAnyOf
- Defined in:
- lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#default ⇒ Object
Returns the value of attribute default.
-
#env_id ⇒ Object
Returns the value of attribute env_id.
-
#is_default_for ⇒ Object
Returns the value of attribute is_default_for.
-
#notification_id ⇒ Object
Returns the value of attribute notification_id.
-
#template_id ⇒ Object
Returns the value of attribute template_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInappNotificationsResponseNotificationsInnerTemplateAnyOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetInappNotificationsResponseNotificationsInnerTemplateAnyOf
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetInappNotificationsResponseNotificationsInnerTemplateAnyOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetInappNotificationsResponseNotificationsInnerTemplateAnyOf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'env_id') self.env_id = attributes[:'env_id'] else self.env_id = nil end if attributes.key?(:'notification_id') self.notification_id = attributes[:'notification_id'] else self.notification_id = nil end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] else self.template_id = nil end if attributes.key?(:'channel') self.channel = attributes[:'channel'] else self.channel = nil end if attributes.key?(:'default') self.default = attributes[:'default'] else self.default = nil end if attributes.key?(:'is_default_for') if (value = attributes[:'is_default_for']).is_a?(Hash) self.is_default_for = value end end end |
Instance Attribute Details
#channel ⇒ Object
Returns the value of attribute channel.
24 25 26 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 24 def channel @channel end |
#default ⇒ Object
Returns the value of attribute default.
26 27 28 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 26 def default @default end |
#env_id ⇒ Object
Returns the value of attribute env_id.
18 19 20 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 18 def env_id @env_id end |
#is_default_for ⇒ Object
Returns the value of attribute is_default_for.
28 29 30 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 28 def is_default_for @is_default_for end |
#notification_id ⇒ Object
Returns the value of attribute notification_id.
20 21 22 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 20 def notification_id @notification_id end |
#template_id ⇒ Object
Returns the value of attribute template_id.
22 23 24 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 22 def template_id @template_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 53 def self.attribute_map { :'env_id' => :'envId', :'notification_id' => :'notificationId', :'template_id' => :'templateId', :'channel' => :'channel', :'default' => :'default', :'is_default_for' => :'isDefaultFor' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 263 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 75 def self.openapi_types { :'env_id' => :'String', :'notification_id' => :'String', :'template_id' => :'String', :'channel' => :'ChannelsEnum', :'default' => :'Boolean', :'is_default_for' => :'Hash<String, Boolean>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && env_id == o.env_id && notification_id == o.notification_id && template_id == o.template_id && channel == o.channel && default == o.default && is_default_for == o.is_default_for end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 256 def hash [env_id, notification_id, template_id, channel, default, is_default_for].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @env_id.nil? invalid_properties.push('invalid value for "env_id", env_id cannot be nil.') end if @notification_id.nil? invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.') end if @template_id.nil? invalid_properties.push('invalid value for "template_id", template_id cannot be nil.') end if @channel.nil? invalid_properties.push('invalid value for "channel", channel cannot be nil.') end if @default.nil? invalid_properties.push('invalid value for "default", default cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 183 |
# File 'lib/pingram/models/get_inapp_notifications_response_notifications_inner_template_any_of.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @env_id.nil? return false if @notification_id.nil? return false if @template_id.nil? return false if @channel.nil? return false if @default.nil? true end |