Class: Pingram::GetKeysResponseKeysInner

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/get_keys_response_keys_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetKeysResponseKeysInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetKeysResponseKeysInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetKeysResponseKeysInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'key_type')
    self.key_type = attributes[:'key_type']
  else
    self.key_type = nil
  end

  if attributes.key?(:'environment_id')
    self.environment_id = attributes[:'environment_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'revoked')
    self.revoked = attributes[:'revoked']
  else
    self.revoked = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end
end

Instance Attribute Details

#account_idObject

The account ID that owns this key



31
32
33
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 31

def 
  @account_id
end

#created_atObject

ISO 8601 timestamp when the key was created



40
41
42
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 40

def created_at
  @created_at
end

#environment_idObject

Environment ID if the key is scoped to a specific environment



28
29
30
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 28

def environment_id
  @environment_id
end

#idObject

Unique identifier for the key (jti)



19
20
21
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 19

def id
  @id
end

#keyObject

The full key string with prefix (shown for reference but should be stored securely by user)



22
23
24
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 22

def key
  @key
end

#key_typeObject

Type of API key



25
26
27
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 25

def key_type
  @key_type
end

#last_used_atObject

ISO 8601 timestamp of when the key was last used (if tracked)



43
44
45
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 43

def last_used_at
  @last_used_at
end

#nameObject

Human-readable name/description for the key



34
35
36
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 34

def name
  @name
end

#revokedObject

Whether the key has been revoked



37
38
39
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 37

def revoked
  @revoked
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 68

def self.attribute_map
  {
    :'id' => :'id',
    :'key' => :'key',
    :'key_type' => :'keyType',
    :'environment_id' => :'environmentId',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'revoked' => :'revoked',
    :'created_at' => :'createdAt',
    :'last_used_at' => :'lastUsedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 333

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 93

def self.openapi_types
  {
    :'id' => :'String',
    :'key' => :'String',
    :'key_type' => :'String',
    :'environment_id' => :'String',
    :'account_id' => :'String',
    :'name' => :'String',
    :'revoked' => :'Boolean',
    :'created_at' => :'String',
    :'last_used_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      key == o.key &&
      key_type == o.key_type &&
      environment_id == o.environment_id &&
       == o. &&
      name == o.name &&
      revoked == o.revoked &&
      created_at == o.created_at &&
      last_used_at == o.last_used_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 320

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



326
327
328
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 326

def hash
  [id, key, key_type, environment_id, , name, revoked, created_at, last_used_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @key_type.nil?
    invalid_properties.push('invalid value for "key_type", key_type cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @revoked.nil?
    invalid_properties.push('invalid value for "revoked", revoked cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 355

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/pingram/models/get_keys_response_keys_inner.rb', line 218

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @key.nil?
  return false if @key_type.nil?
  key_type_validator = EnumAttributeValidator.new('String', ["secret", "public"])
  return false unless key_type_validator.valid?(@key_type)
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @revoked.nil?
  return false if @created_at.nil?
  true
end