Class: Pingram::GetLogsResponseMessagesInnerAttachmentsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::GetLogsResponseMessagesInnerAttachmentsInner
- Defined in:
- lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb
Instance Attribute Summary collapse
-
#content_id ⇒ Object
Returns the value of attribute content_id.
-
#content_type ⇒ Object
Returns the value of attribute content_type.
-
#filename ⇒ Object
Returns the value of attribute filename.
-
#size ⇒ Object
Returns the value of attribute size.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetLogsResponseMessagesInnerAttachmentsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetLogsResponseMessagesInnerAttachmentsInner
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetLogsResponseMessagesInnerAttachmentsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetLogsResponseMessagesInnerAttachmentsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'filename') self.filename = attributes[:'filename'] else self.filename = nil end if attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] else self.content_type = nil end if attributes.key?(:'size') self.size = attributes[:'size'] else self.size = nil end if attributes.key?(:'content_id') self.content_id = attributes[:'content_id'] end end |
Instance Attribute Details
#content_id ⇒ Object
Returns the value of attribute content_id.
24 25 26 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 24 def content_id @content_id end |
#content_type ⇒ Object
Returns the value of attribute content_type.
20 21 22 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 20 def content_type @content_type end |
#filename ⇒ Object
Returns the value of attribute filename.
18 19 20 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 18 def filename @filename end |
#size ⇒ Object
Returns the value of attribute size.
22 23 24 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 22 def size @size end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 27 def self.attribute_map { :'filename' => :'filename', :'content_type' => :'contentType', :'size' => :'size', :'content_id' => :'contentId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 187 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 47 def self.openapi_types { :'filename' => :'String', :'content_type' => :'String', :'size' => :'Float', :'content_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 163 def ==(o) return true if self.equal?(o) self.class == o.class && filename == o.filename && content_type == o.content_type && size == o.size && content_id == o.content_id end |
#eql?(o) ⇒ Boolean
174 175 176 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 174 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 180 def hash [filename, content_type, size, content_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @filename.nil? invalid_properties.push('invalid value for "filename", filename cannot be nil.') end if @content_type.nil? invalid_properties.push('invalid value for "content_type", content_type cannot be nil.') end if @size.nil? invalid_properties.push('invalid value for "size", size cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 128 129 |
# File 'lib/pingram/models/get_logs_response_messages_inner_attachments_inner.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @filename.nil? return false if @content_type.nil? return false if @size.nil? true end |