Class: Pingram::GetMembersResponseInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::GetMembersResponseInner
- Defined in:
- lib/pingram/models/get_members_response_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#email ⇒ Object
Returns the value of attribute email.
-
#enabled_mfas ⇒ Object
Returns the value of attribute enabled_mfas.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetMembersResponseInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetMembersResponseInner
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetMembersResponseInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetMembersResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] else self.organization_id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'enabled_mfas') if (value = attributes[:'enabled_mfas']).is_a?(Array) self.enabled_mfas = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
20 21 22 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 20 def account_id @account_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
24 25 26 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 24 def created_at @created_at end |
#email ⇒ Object
Returns the value of attribute email.
26 27 28 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 26 def email @email end |
#enabled_mfas ⇒ Object
Returns the value of attribute enabled_mfas.
30 31 32 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 30 def enabled_mfas @enabled_mfas end |
#groups ⇒ Object
Returns the value of attribute groups.
28 29 30 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 28 def groups @groups end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
18 19 20 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 18 def organization_id @organization_id end |
#user_id ⇒ Object
Returns the value of attribute user_id.
22 23 24 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 22 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 55 def self.attribute_map { :'organization_id' => :'organizationId', :'account_id' => :'accountId', :'user_id' => :'userId', :'created_at' => :'createdAt', :'email' => :'email', :'groups' => :'groups', :'enabled_mfas' => :'enabledMFAs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 257 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 78 def self.openapi_types { :'organization_id' => :'String', :'account_id' => :'String', :'user_id' => :'String', :'created_at' => :'String', :'email' => :'String', :'groups' => :'Array<String>', :'enabled_mfas' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 230 def ==(o) return true if self.equal?(o) self.class == o.class && organization_id == o.organization_id && account_id == o.account_id && user_id == o.user_id && created_at == o.created_at && email == o.email && groups == o.groups && enabled_mfas == o.enabled_mfas end |
#eql?(o) ⇒ Boolean
244 245 246 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 244 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
250 251 252 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 250 def hash [organization_id, account_id, user_id, created_at, email, groups, enabled_mfas].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @organization_id.nil? invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 279 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 |
# File 'lib/pingram/models/get_members_response_inner.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @organization_id.nil? return false if @account_id.nil? return false if @user_id.nil? return false if @created_at.nil? true end |