Class: Pingram::GetMetricsResponseInner

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/get_metrics_response_inner.rb

Overview

<p>A GetMetricData call returns an array of MetricDataResult structures. Each of these structures includes the data points for that metric, along with the timestamps of those data points and other identifying information.</p>

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetMetricsResponseInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetMetricsResponseInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetMetricsResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'timestamps')
    if (value = attributes[:'timestamps']).is_a?(Array)
      self.timestamps = value
    end
  end

  if attributes.key?(:'values')
    if (value = attributes[:'values']).is_a?(Array)
      self.values = value
    end
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end
end

Instance Attribute Details

#idObject

<p>The short name you specified to represent this metric.</p>



20
21
22
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 20

def id
  @id
end

#labelObject

<p>The human-readable label associated with the data.</p>



23
24
25
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 23

def label
  @label
end

#messagesObject

<p>A list of messages with additional information about the data returned.</p>



34
35
36
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 34

def messages
  @messages
end

#status_codeObject

Returns the value of attribute status_code.



31
32
33
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 31

def status_code
  @status_code
end

#timestampsObject

<p>The timestamps for the data points, formatted in Unix timestamp format. The number of timestamps always matches the number of values and the value for Timestamps is Values.</p>



26
27
28
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 26

def timestamps
  @timestamps
end

#valuesObject

<p>The data points for the metric corresponding to Timestamps. The number of values always matches the number of timestamps and the timestamp for Values is Timestamps.</p>



29
30
31
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 29

def values
  @values
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 59

def self.attribute_map
  {
    :'id' => :'Id',
    :'label' => :'Label',
    :'timestamps' => :'Timestamps',
    :'values' => :'Values',
    :'status_code' => :'StatusCode',
    :'messages' => :'Messages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'label' => :'String',
    :'timestamps' => :'Array<Time>',
    :'values' => :'Array<Float>',
    :'status_code' => :'String',
    :'messages' => :'Array<GetMetricsResponseInnerMessagesInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
183
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      label == o.label &&
      timestamps == o.timestamps &&
      values == o.values &&
      status_code == o.status_code &&
      messages == o.messages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 193

def hash
  [id, label, timestamps, values, status_code, messages].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
# File 'lib/pingram/models/get_metrics_response_inner.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_code_validator = EnumAttributeValidator.new('String', ["Complete", "Forbidden", "InternalError", "PartialData"])
  return false unless status_code_validator.valid?(@status_code)
  true
end