Class: Pingram::GetNotificationsResponseInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_notifications_response_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetNotificationsResponseInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetNotificationsResponseInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetNotificationsResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'env_id')
    self.env_id = attributes[:'env_id']
  else
    self.env_id = nil
  end

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  else
    self.notification_id = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'channels')
    if (value = attributes[:'channels']).is_a?(Array)
      self.channels = value
    end
  else
    self.channels = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'deduplication')
    self.deduplication = attributes[:'deduplication']
  end

  if attributes.key?(:'throttling')
    self.throttling = attributes[:'throttling']
  end

  if attributes.key?(:'retention')
    self.retention = attributes[:'retention']
  end

  if attributes.key?(:'options')
    self.options = attributes[:'options']
  end

  if attributes.key?(:'templates')
    if (value = attributes[:'templates']).is_a?(Array)
      self.templates = value
    end
  end
end

Instance Attribute Details

#channelsObject

Returns the value of attribute channels.



24
25
26
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 24

def channels
  @channels
end

#deduplicationObject

Returns the value of attribute deduplication.



28
29
30
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 28

def deduplication
  @deduplication
end

#enabledObject

Returns the value of attribute enabled.



26
27
28
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 26

def enabled
  @enabled
end

#env_idObject

Returns the value of attribute env_id.



18
19
20
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 18

def env_id
  @env_id
end

#notification_idObject

Returns the value of attribute notification_id.



20
21
22
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 20

def notification_id
  @notification_id
end

#optionsObject

Returns the value of attribute options.



34
35
36
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 34

def options
  @options
end

#retentionObject

Returns the value of attribute retention.



32
33
34
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 32

def retention
  @retention
end

#templatesObject

Returns the value of attribute templates.



36
37
38
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 36

def templates
  @templates
end

#throttlingObject

Returns the value of attribute throttling.



30
31
32
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 30

def throttling
  @throttling
end

#titleObject

Returns the value of attribute title.



22
23
24
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 22

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 39

def self.attribute_map
  {
    :'env_id' => :'envId',
    :'notification_id' => :'notificationId',
    :'title' => :'title',
    :'channels' => :'channels',
    :'enabled' => :'enabled',
    :'deduplication' => :'deduplication',
    :'throttling' => :'throttling',
    :'retention' => :'retention',
    :'options' => :'options',
    :'templates' => :'templates'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 65

def self.openapi_types
  {
    :'env_id' => :'String',
    :'notification_id' => :'String',
    :'title' => :'String',
    :'channels' => :'Array<ChannelsEnum>',
    :'enabled' => :'Boolean',
    :'deduplication' => :'GetNotificationsResponseInnerDeduplication',
    :'throttling' => :'GetNotificationsResponseInnerThrottling',
    :'retention' => :'Float',
    :'options' => :'GetNotificationsResponseInnerOptions',
    :'templates' => :'Array<GetNotificationsResponseInnerTemplatesInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      env_id == o.env_id &&
      notification_id == o.notification_id &&
      title == o.title &&
      channels == o.channels &&
      enabled == o.enabled &&
      deduplication == o.deduplication &&
      throttling == o.throttling &&
      retention == o.retention &&
      options == o.options &&
      templates == o.templates
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 272

def hash
  [env_id, notification_id, title, channels, enabled, deduplication, throttling, retention, options, templates].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @env_id.nil?
    invalid_properties.push('invalid value for "env_id", env_id cannot be nil.')
  end

  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @channels.nil?
    invalid_properties.push('invalid value for "channels", channels cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
191
192
193
194
195
# File 'lib/pingram/models/get_notifications_response_inner.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @env_id.nil?
  return false if @notification_id.nil?
  return false if @title.nil?
  return false if @channels.nil?
  return false if @enabled.nil?
  true
end