Class: Pingram::GetNotificationsResponseInnerOptionsEMAIL
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::GetNotificationsResponseInnerOptionsEMAIL
- Defined in:
- lib/pingram/models/get_notifications_response_inner_options_email.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#daily ⇒ Object
Returns the value of attribute daily.
-
#default_delivery_option ⇒ Object
Returns the value of attribute default_delivery_option.
-
#hourly ⇒ Object
Returns the value of attribute hourly.
-
#instant ⇒ Object
Returns the value of attribute instant.
-
#monthly ⇒ Object
Returns the value of attribute monthly.
-
#off ⇒ Object
Returns the value of attribute off.
-
#weekly ⇒ Object
Returns the value of attribute weekly.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetNotificationsResponseInnerOptionsEMAIL
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetNotificationsResponseInnerOptionsEMAIL
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetNotificationsResponseInnerOptionsEMAIL` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetNotificationsResponseInnerOptionsEMAIL`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'default_delivery_option') self.default_delivery_option = attributes[:'default_delivery_option'] else self.default_delivery_option = nil end if attributes.key?(:'off') self.off = attributes[:'off'] end if attributes.key?(:'instant') self.instant = attributes[:'instant'] end if attributes.key?(:'hourly') self.hourly = attributes[:'hourly'] end if attributes.key?(:'daily') self.daily = attributes[:'daily'] end if attributes.key?(:'weekly') self.weekly = attributes[:'weekly'] end if attributes.key?(:'monthly') self.monthly = attributes[:'monthly'] end end |
Instance Attribute Details
#daily ⇒ Object
Returns the value of attribute daily.
26 27 28 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 26 def daily @daily end |
#default_delivery_option ⇒ Object
Returns the value of attribute default_delivery_option.
18 19 20 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 18 def default_delivery_option @default_delivery_option end |
#hourly ⇒ Object
Returns the value of attribute hourly.
24 25 26 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 24 def hourly @hourly end |
#instant ⇒ Object
Returns the value of attribute instant.
22 23 24 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 22 def instant @instant end |
#monthly ⇒ Object
Returns the value of attribute monthly.
30 31 32 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 30 def monthly @monthly end |
#off ⇒ Object
Returns the value of attribute off.
20 21 22 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 20 def off @off end |
#weekly ⇒ Object
Returns the value of attribute weekly.
28 29 30 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 28 def weekly @weekly end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 55 def self.attribute_map { :'default_delivery_option' => :'defaultDeliveryOption', :'off' => :'off', :'instant' => :'instant', :'hourly' => :'hourly', :'daily' => :'daily', :'weekly' => :'weekly', :'monthly' => :'monthly' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 78 def self.openapi_types { :'default_delivery_option' => :'String', :'off' => :'GetInappNotificationsResponseNotificationsInnerDeliveryOptionsOff', :'instant' => :'GetInappNotificationsResponseNotificationsInnerDeliveryOptionsOff', :'hourly' => :'GetInappNotificationsResponseNotificationsInnerDeliveryOptionsOff', :'daily' => :'GetNotificationsResponseInnerOptionsEMAILDaily', :'weekly' => :'GetNotificationsResponseInnerOptionsEMAILWeekly', :'monthly' => :'GetNotificationsResponseInnerOptionsEMAILMonthly' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && default_delivery_option == o.default_delivery_option && off == o.off && instant == o.instant && hourly == o.hourly && daily == o.daily && weekly == o.weekly && monthly == o.monthly end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 197 def hash [default_delivery_option, off, instant, hourly, daily, weekly, monthly].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @default_delivery_option.nil? invalid_properties.push('invalid value for "default_delivery_option", default_delivery_option cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 |
# File 'lib/pingram/models/get_notifications_response_inner_options_email.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @default_delivery_option.nil? default_delivery_option_validator = EnumAttributeValidator.new('String', ["off", "instant", "hourly", "daily", "weekly", "monthly"]) return false unless default_delivery_option_validator.valid?(@default_delivery_option) true end |