Class: Pingram::GetTemplatesListResponseInnerAnyOf2

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_templates_list_response_inner_any_of2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetTemplatesListResponseInnerAnyOf2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetTemplatesListResponseInnerAnyOf2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetTemplatesListResponseInnerAnyOf2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'env_id')
    self.env_id = attributes[:'env_id']
  else
    self.env_id = nil
  end

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  else
    self.notification_id = nil
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  else
    self.channel = nil
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  else
    self.default = nil
  end

  if attributes.key?(:'is_default_for')
    if (value = attributes[:'is_default_for']).is_a?(Hash)
      self.is_default_for = value
    end
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'media_urls')
    if (value = attributes[:'media_urls']).is_a?(Array)
      self.media_urls = value
    end
  end
end

Instance Attribute Details

#channelObject

Returns the value of attribute channel.



24
25
26
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 24

def channel
  @channel
end

#defaultObject

Returns the value of attribute default.



26
27
28
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 26

def default
  @default
end

#env_idObject

Returns the value of attribute env_id.



18
19
20
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 18

def env_id
  @env_id
end

#is_default_forObject

Returns the value of attribute is_default_for.



28
29
30
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 28

def is_default_for
  @is_default_for
end

#media_urlsObject

Set when sending MMS (outbound).



33
34
35
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 33

def media_urls
  @media_urls
end

#notification_idObject

Returns the value of attribute notification_id.



20
21
22
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 20

def notification_id
  @notification_id
end

#template_idObject

Returns the value of attribute template_id.



22
23
24
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 22

def template_id
  @template_id
end

#textObject

Returns the value of attribute text.



30
31
32
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 30

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 58

def self.attribute_map
  {
    :'env_id' => :'envId',
    :'notification_id' => :'notificationId',
    :'template_id' => :'templateId',
    :'channel' => :'channel',
    :'default' => :'default',
    :'is_default_for' => :'isDefaultFor',
    :'text' => :'text',
    :'media_urls' => :'mediaUrls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 301

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 82

def self.openapi_types
  {
    :'env_id' => :'String',
    :'notification_id' => :'String',
    :'template_id' => :'String',
    :'channel' => :'ChannelsEnum',
    :'default' => :'Boolean',
    :'is_default_for' => :'Hash<String, Boolean>',
    :'text' => :'String',
    :'media_urls' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      env_id == o.env_id &&
      notification_id == o.notification_id &&
      template_id == o.template_id &&
      channel == o.channel &&
      default == o.default &&
      is_default_for == o.is_default_for &&
      text == o.text &&
      media_urls == o.media_urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 288

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



294
295
296
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 294

def hash
  [env_id, notification_id, template_id, channel, default, is_default_for, text, media_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @env_id.nil?
    invalid_properties.push('invalid value for "env_id", env_id cannot be nil.')
  end

  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @channel.nil?
    invalid_properties.push('invalid value for "channel", channel cannot be nil.')
  end

  if @default.nil?
    invalid_properties.push('invalid value for "default", default cannot be nil.')
  end

  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
208
209
# File 'lib/pingram/models/get_templates_list_response_inner_any_of2.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @env_id.nil?
  return false if @notification_id.nil?
  return false if @template_id.nil?
  return false if @channel.nil?
  return false if @default.nil?
  return false if @text.nil?
  true
end