Class: Pingram::GetTemplatesListResponseInnerAnyOf4

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_templates_list_response_inner_any_of4.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetTemplatesListResponseInnerAnyOf4

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetTemplatesListResponseInnerAnyOf4` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetTemplatesListResponseInnerAnyOf4`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'env_id')
    self.env_id = attributes[:'env_id']
  else
    self.env_id = nil
  end

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  else
    self.notification_id = nil
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  else
    self.channel = nil
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  else
    self.default = nil
  end

  if attributes.key?(:'is_default_for')
    if (value = attributes[:'is_default_for']).is_a?(Hash)
      self.is_default_for = value
    end
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end
end

Instance Attribute Details

#channelObject

Returns the value of attribute channel.



24
25
26
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 24

def channel
  @channel
end

#defaultObject

Returns the value of attribute default.



26
27
28
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 26

def default
  @default
end

#env_idObject

Returns the value of attribute env_id.



18
19
20
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 18

def env_id
  @env_id
end

#iconObject

Returns the value of attribute icon.



34
35
36
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 34

def icon
  @icon
end

#is_default_forObject

Returns the value of attribute is_default_for.



28
29
30
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 28

def is_default_for
  @is_default_for
end

#messageObject

Returns the value of attribute message.



32
33
34
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 32

def message
  @message
end

#notification_idObject

Returns the value of attribute notification_id.



20
21
22
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 20

def notification_id
  @notification_id
end

#template_idObject

Returns the value of attribute template_id.



22
23
24
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 22

def template_id
  @template_id
end

#titleObject

Returns the value of attribute title.



30
31
32
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 30

def title
  @title
end

#urlObject

Returns the value of attribute url.



36
37
38
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 36

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 61

def self.attribute_map
  {
    :'env_id' => :'envId',
    :'notification_id' => :'notificationId',
    :'template_id' => :'templateId',
    :'channel' => :'channel',
    :'default' => :'default',
    :'is_default_for' => :'isDefaultFor',
    :'title' => :'title',
    :'message' => :'message',
    :'icon' => :'icon',
    :'url' => :'url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 333

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 87

def self.openapi_types
  {
    :'env_id' => :'String',
    :'notification_id' => :'String',
    :'template_id' => :'String',
    :'channel' => :'ChannelsEnum',
    :'default' => :'Boolean',
    :'is_default_for' => :'Hash<String, Boolean>',
    :'title' => :'String',
    :'message' => :'String',
    :'icon' => :'String',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 303

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      env_id == o.env_id &&
      notification_id == o.notification_id &&
      template_id == o.template_id &&
      channel == o.channel &&
      default == o.default &&
      is_default_for == o.is_default_for &&
      title == o.title &&
      message == o.message &&
      icon == o.icon &&
      url == o.url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 320

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



326
327
328
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 326

def hash
  [env_id, notification_id, template_id, channel, default, is_default_for, title, message, icon, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @env_id.nil?
    invalid_properties.push('invalid value for "env_id", env_id cannot be nil.')
  end

  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @channel.nil?
    invalid_properties.push('invalid value for "channel", channel cannot be nil.')
  end

  if @default.nil?
    invalid_properties.push('invalid value for "default", default cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 355

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
223
224
225
226
227
228
229
# File 'lib/pingram/models/get_templates_list_response_inner_any_of4.rb', line 219

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @env_id.nil?
  return false if @notification_id.nil?
  return false if @template_id.nil?
  return false if @channel.nil?
  return false if @default.nil?
  return false if @title.nil?
  return false if @message.nil?
  true
end