Class: Pingram::GetTemplatesListResponseInnerAnyOf5

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_templates_list_response_inner_any_of5.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetTemplatesListResponseInnerAnyOf5

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetTemplatesListResponseInnerAnyOf5` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetTemplatesListResponseInnerAnyOf5`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'env_id')
    self.env_id = attributes[:'env_id']
  else
    self.env_id = nil
  end

  if attributes.key?(:'notification_id')
    self.notification_id = attributes[:'notification_id']
  else
    self.notification_id = nil
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  else
    self.channel = nil
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  else
    self.default = nil
  end

  if attributes.key?(:'is_default_for')
    if (value = attributes[:'is_default_for']).is_a?(Hash)
      self.is_default_for = value
    end
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'blocks')
    if (value = attributes[:'blocks']).is_a?(Array)
      self.blocks = value
    end
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'thread_ts')
    self.thread_ts = attributes[:'thread_ts']
  end

  if attributes.key?(:'reply_broadcast')
    self.reply_broadcast = attributes[:'reply_broadcast']
  end

  if attributes.key?(:'parse')
    self.parse = attributes[:'parse']
  end

  if attributes.key?(:'link_names')
    self.link_names = attributes[:'link_names']
  end

  if attributes.key?(:'mrkdwn')
    self.mrkdwn = attributes[:'mrkdwn']
  end

  if attributes.key?(:'unfurl_links')
    self.unfurl_links = attributes[:'unfurl_links']
  end

  if attributes.key?(:'unfurl_media')
    self.unfurl_media = attributes[:'unfurl_media']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#blocksObject

Returns the value of attribute blocks.



32
33
34
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 32

def blocks
  @blocks
end

#channelObject

Returns the value of attribute channel.



24
25
26
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 24

def channel
  @channel
end

#defaultObject

Returns the value of attribute default.



26
27
28
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 26

def default
  @default
end

#env_idObject

Returns the value of attribute env_id.



18
19
20
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 18

def env_id
  @env_id
end

#iconObject

Returns the value of attribute icon.



36
37
38
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 36

def icon
  @icon
end

#is_default_forObject

Returns the value of attribute is_default_for.



28
29
30
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 28

def is_default_for
  @is_default_for
end

Returns the value of attribute link_names.



44
45
46
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 44

def link_names
  @link_names
end

#metadataObject

Returns the value of attribute metadata.



52
53
54
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 52

def 
  @metadata
end

#mrkdwnObject

Returns the value of attribute mrkdwn.



46
47
48
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 46

def mrkdwn
  @mrkdwn
end

#notification_idObject

Returns the value of attribute notification_id.



20
21
22
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 20

def notification_id
  @notification_id
end

#parseObject

Returns the value of attribute parse.



42
43
44
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 42

def parse
  @parse
end

#reply_broadcastObject

Returns the value of attribute reply_broadcast.



40
41
42
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 40

def reply_broadcast
  @reply_broadcast
end

#template_idObject

Returns the value of attribute template_id.



22
23
24
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 22

def template_id
  @template_id
end

#textObject

Returns the value of attribute text.



30
31
32
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 30

def text
  @text
end

#thread_tsObject

Returns the value of attribute thread_ts.



38
39
40
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 38

def thread_ts
  @thread_ts
end

Returns the value of attribute unfurl_links.



48
49
50
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 48

def unfurl_links
  @unfurl_links
end

#unfurl_mediaObject

Returns the value of attribute unfurl_media.



50
51
52
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 50

def unfurl_media
  @unfurl_media
end

#usernameObject

Returns the value of attribute username.



34
35
36
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 34

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



101
102
103
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 101

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 106

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 77

def self.attribute_map
  {
    :'env_id' => :'envId',
    :'notification_id' => :'notificationId',
    :'template_id' => :'templateId',
    :'channel' => :'channel',
    :'default' => :'default',
    :'is_default_for' => :'isDefaultFor',
    :'text' => :'text',
    :'blocks' => :'blocks',
    :'username' => :'username',
    :'icon' => :'icon',
    :'thread_ts' => :'thread_ts',
    :'reply_broadcast' => :'reply_broadcast',
    :'parse' => :'parse',
    :'link_names' => :'link_names',
    :'mrkdwn' => :'mrkdwn',
    :'unfurl_links' => :'unfurl_links',
    :'unfurl_media' => :'unfurl_media',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 402

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 135

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 111

def self.openapi_types
  {
    :'env_id' => :'String',
    :'notification_id' => :'String',
    :'template_id' => :'String',
    :'channel' => :'ChannelsEnum',
    :'default' => :'Boolean',
    :'is_default_for' => :'Hash<String, Boolean>',
    :'text' => :'String',
    :'blocks' => :'Array<Hash<String, Object>>',
    :'username' => :'String',
    :'icon' => :'String',
    :'thread_ts' => :'String',
    :'reply_broadcast' => :'Boolean',
    :'parse' => :'String',
    :'link_names' => :'Boolean',
    :'mrkdwn' => :'Boolean',
    :'unfurl_links' => :'Boolean',
    :'unfurl_media' => :'Boolean',
    :'metadata' => :'GetTemplatesListResponseInnerAnyOf5Metadata'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 364

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      env_id == o.env_id &&
      notification_id == o.notification_id &&
      template_id == o.template_id &&
      channel == o.channel &&
      default == o.default &&
      is_default_for == o.is_default_for &&
      text == o.text &&
      blocks == o.blocks &&
      username == o.username &&
      icon == o.icon &&
      thread_ts == o.thread_ts &&
      reply_broadcast == o.reply_broadcast &&
      parse == o.parse &&
      link_names == o.link_names &&
      mrkdwn == o.mrkdwn &&
      unfurl_links == o.unfurl_links &&
      unfurl_media == o.unfurl_media &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


389
390
391
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 389

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



395
396
397
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 395

def hash
  [env_id, notification_id, template_id, channel, default, is_default_for, text, blocks, username, icon, thread_ts, reply_broadcast, parse, link_names, mrkdwn, unfurl_links, unfurl_media, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 247

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @env_id.nil?
    invalid_properties.push('invalid value for "env_id", env_id cannot be nil.')
  end

  if @notification_id.nil?
    invalid_properties.push('invalid value for "notification_id", notification_id cannot be nil.')
  end

  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @channel.nil?
    invalid_properties.push('invalid value for "channel", channel cannot be nil.')
  end

  if @default.nil?
    invalid_properties.push('invalid value for "default", default cannot be nil.')
  end

  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 424

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5.rb', line 279

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @env_id.nil?
  return false if @notification_id.nil?
  return false if @template_id.nil?
  return false if @channel.nil?
  return false if @default.nil?
  return false if @text.nil?
  parse_validator = EnumAttributeValidator.new('String', ["full", "none"])
  return false unless parse_validator.valid?(@parse)
  true
end