Class: Pingram::GetUsersResponseUsersInnerPushTokensInnerDevice

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetUsersResponseUsersInnerPushTokensInnerDevice

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetUsersResponseUsersInnerPushTokensInnerDevice` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetUsersResponseUsersInnerPushTokensInnerDevice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'app_id')
    self.app_id = attributes[:'app_id']
  end

  if attributes.key?(:'ad_id')
    self.ad_id = attributes[:'ad_id']
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  else
    self.device_id = nil
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'manufacturer')
    self.manufacturer = attributes[:'manufacturer']
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end
end

Instance Attribute Details

#ad_idObject

Returns the value of attribute ad_id.



20
21
22
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 20

def ad_id
  @ad_id
end

#app_idObject

Returns the value of attribute app_id.



18
19
20
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 18

def app_id
  @app_id
end

#device_idObject

Returns the value of attribute device_id.



22
23
24
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 22

def device_id
  @device_id
end

#manufacturerObject

Returns the value of attribute manufacturer.



26
27
28
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 26

def manufacturer
  @manufacturer
end

#modelObject

Returns the value of attribute model.



28
29
30
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 28

def model
  @model
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 24

def platform
  @platform
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 31

def self.attribute_map
  {
    :'app_id' => :'app_id',
    :'ad_id' => :'ad_id',
    :'device_id' => :'device_id',
    :'platform' => :'platform',
    :'manufacturer' => :'manufacturer',
    :'model' => :'model'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 53

def self.openapi_types
  {
    :'app_id' => :'String',
    :'ad_id' => :'String',
    :'device_id' => :'String',
    :'platform' => :'String',
    :'manufacturer' => :'String',
    :'model' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



145
146
147
148
149
150
151
152
153
154
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 145

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      app_id == o.app_id &&
      ad_id == o.ad_id &&
      device_id == o.device_id &&
      platform == o.platform &&
      manufacturer == o.manufacturer &&
      model == o.model
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


158
159
160
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



164
165
166
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 164

def hash
  [app_id, ad_id, device_id, platform, manufacturer, model].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
120
121
122
123
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @device_id.nil?
    invalid_properties.push('invalid value for "device_id", device_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



127
128
129
130
131
# File 'lib/pingram/models/get_users_response_users_inner_push_tokens_inner_device.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @device_id.nil?
  true
end