Class: Pingram::GetUsersResponseUsersInnerSlackTokenAuthedUser

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetUsersResponseUsersInnerSlackTokenAuthedUser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetUsersResponseUsersInnerSlackTokenAuthedUser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetUsersResponseUsersInnerSlackTokenAuthedUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  end

  if attributes.key?(:'expires_in')
    self.expires_in = attributes[:'expires_in']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'refresh_token')
    self.refresh_token = attributes[:'refresh_token']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'token_type')
    self.token_type = attributes[:'token_type']
  end
end

Instance Attribute Details

#access_tokenObject

Returns the value of attribute access_token.



18
19
20
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 18

def access_token
  @access_token
end

#expires_inObject

Returns the value of attribute expires_in.



20
21
22
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 20

def expires_in
  @expires_in
end

#idObject

Returns the value of attribute id.



22
23
24
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 22

def id
  @id
end

#refresh_tokenObject

Returns the value of attribute refresh_token.



24
25
26
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 24

def refresh_token
  @refresh_token
end

#scopeObject

Returns the value of attribute scope.



26
27
28
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 26

def scope
  @scope
end

#token_typeObject

Returns the value of attribute token_type.



28
29
30
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 28

def token_type
  @token_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 31

def self.attribute_map
  {
    :'access_token' => :'access_token',
    :'expires_in' => :'expires_in',
    :'id' => :'id',
    :'refresh_token' => :'refresh_token',
    :'scope' => :'scope',
    :'token_type' => :'token_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 154

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 53

def self.openapi_types
  {
    :'access_token' => :'String',
    :'expires_in' => :'Float',
    :'id' => :'String',
    :'refresh_token' => :'String',
    :'scope' => :'String',
    :'token_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



128
129
130
131
132
133
134
135
136
137
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 128

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_token == o.access_token &&
      expires_in == o.expires_in &&
      id == o.id &&
      refresh_token == o.refresh_token &&
      scope == o.scope &&
      token_type == o.token_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


141
142
143
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 141

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



147
148
149
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 147

def hash
  [access_token, expires_in, id, refresh_token, scope, token_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



121
122
123
124
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_authed_user.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end