Class: Pingram::GetUsersResponseUsersInnerSlackTokenResponseMetadata

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetUsersResponseUsersInnerSlackTokenResponseMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetUsersResponseUsersInnerSlackTokenResponseMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetUsersResponseUsersInnerSlackTokenResponseMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'warnings')
    if (value = attributes[:'warnings']).is_a?(Array)
      self.warnings = value
    end
  end

  if attributes.key?(:'next_cursor')
    self.next_cursor = attributes[:'next_cursor']
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  end

  if attributes.key?(:'accepted_scopes')
    if (value = attributes[:'accepted_scopes']).is_a?(Array)
      self.accepted_scopes = value
    end
  end

  if attributes.key?(:'retry_after')
    self.retry_after = attributes[:'retry_after']
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end
end

Instance Attribute Details

#accepted_scopesObject

Returns the value of attribute accepted_scopes.



24
25
26
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 24

def accepted_scopes
  @accepted_scopes
end

#messagesObject

Returns the value of attribute messages.



28
29
30
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 28

def messages
  @messages
end

#next_cursorObject

Returns the value of attribute next_cursor.



20
21
22
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 20

def next_cursor
  @next_cursor
end

#retry_afterObject

Returns the value of attribute retry_after.



26
27
28
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 26

def retry_after
  @retry_after
end

#scopesObject

Returns the value of attribute scopes.



22
23
24
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 22

def scopes
  @scopes
end

#warningsObject

Returns the value of attribute warnings.



18
19
20
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 18

def warnings
  @warnings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 31

def self.attribute_map
  {
    :'warnings' => :'warnings',
    :'next_cursor' => :'next_cursor',
    :'scopes' => :'scopes',
    :'accepted_scopes' => :'acceptedScopes',
    :'retry_after' => :'retryAfter',
    :'messages' => :'messages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 53

def self.openapi_types
  {
    :'warnings' => :'Array<String>',
    :'next_cursor' => :'String',
    :'scopes' => :'Array<String>',
    :'accepted_scopes' => :'Array<String>',
    :'retry_after' => :'Float',
    :'messages' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
143
144
145
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      warnings == o.warnings &&
      next_cursor == o.next_cursor &&
      scopes == o.scopes &&
      accepted_scopes == o.accepted_scopes &&
      retry_after == o.retry_after &&
      messages == o.messages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


149
150
151
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 149

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



155
156
157
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 155

def hash
  [warnings, next_cursor, scopes, accepted_scopes, retry_after, messages].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
# File 'lib/pingram/models/get_users_response_users_inner_slack_token_response_metadata.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end