Class: Pingram::GetVoiceCallResponseCall

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/get_voice_call_response_call.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetVoiceCallResponseCall

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetVoiceCallResponseCall` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetVoiceCallResponseCall`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  else
    self.tracking_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'agent_id')
    self.agent_id = attributes[:'agent_id']
  end

  if attributes.key?(:'agent_name')
    self.agent_name = attributes[:'agent_name']
  else
    self.agent_name = nil
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  else
    self.direction = nil
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  else
    self.from = nil
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  else
    self.started_at = nil
  end

  if attributes.key?(:'duration_seconds')
    self.duration_seconds = attributes[:'duration_seconds']
  else
    self.duration_seconds = nil
  end

  if attributes.key?(:'outcome')
    self.outcome = attributes[:'outcome']
  end

  if attributes.key?(:'end_reason')
    self.end_reason = attributes[:'end_reason']
  end

  if attributes.key?(:'end_detail')
    self.end_detail = attributes[:'end_detail']
  end

  if attributes.key?(:'timeline')
    if (value = attributes[:'timeline']).is_a?(Array)
      self.timeline = value
    end
  else
    self.timeline = nil
  end

  if attributes.key?(:'recording_url')
    self.recording_url = attributes[:'recording_url']
  end

  if attributes.key?(:'variables')
    if (value = attributes[:'variables']).is_a?(Hash)
      self.variables = value
    end
  end

  if attributes.key?(:'cost')
    self.cost = attributes[:'cost']
  end
end

Instance Attribute Details

#agent_idObject

Omitted for playground calls made before the agent was saved.



23
24
25
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 23

def agent_id
  @agent_id
end

#agent_nameObject

Returns the value of attribute agent_name.



25
26
27
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 25

def agent_name
  @agent_name
end

#costObject

Returns the value of attribute cost.



54
55
56
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 54

def cost
  @cost
end

#directionObject

Returns the value of attribute direction.



27
28
29
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 27

def direction
  @direction
end

#duration_secondsObject

Returns the value of attribute duration_seconds.



37
38
39
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 37

def duration_seconds
  @duration_seconds
end

#end_detailObject

Short human-readable detail (e.g. provider error message).



45
46
47
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 45

def end_detail
  @end_detail
end

#end_reasonObject

Machine-readable reason the call ended — persisted on every call record.



42
43
44
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 42

def end_reason
  @end_reason
end

#fromObject

Returns the value of attribute from.



31
32
33
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 31

def from
  @from
end

#outcomeObject

Returns the value of attribute outcome.



39
40
41
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 39

def outcome
  @outcome
end

#recording_urlObject

Returns the value of attribute recording_url.



50
51
52
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 50

def recording_url
  @recording_url
end

#sourceObject

Returns the value of attribute source.



29
30
31
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 29

def source
  @source
end

#started_atObject

Returns the value of attribute started_at.



35
36
37
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 35

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 20

def status
  @status
end

#timelineObject

Full chronological timeline (transcript + ops events).



48
49
50
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 48

def timeline
  @timeline
end

#toObject

Returns the value of attribute to.



33
34
35
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 33

def to
  @to
end

#tracking_idObject

Returns the value of attribute tracking_id.



18
19
20
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 18

def tracking_id
  @tracking_id
end

#variablesObject

Returns the value of attribute variables.



52
53
54
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 52

def variables
  @variables
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



102
103
104
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 102

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 107

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 79

def self.attribute_map
  {
    :'tracking_id' => :'trackingId',
    :'status' => :'status',
    :'agent_id' => :'agentId',
    :'agent_name' => :'agentName',
    :'direction' => :'direction',
    :'source' => :'source',
    :'from' => :'from',
    :'to' => :'to',
    :'started_at' => :'startedAt',
    :'duration_seconds' => :'durationSeconds',
    :'outcome' => :'outcome',
    :'end_reason' => :'endReason',
    :'end_detail' => :'endDetail',
    :'timeline' => :'timeline',
    :'recording_url' => :'recordingUrl',
    :'variables' => :'variables',
    :'cost' => :'cost'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 483

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 135

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 112

def self.openapi_types
  {
    :'tracking_id' => :'String',
    :'status' => :'String',
    :'agent_id' => :'String',
    :'agent_name' => :'String',
    :'direction' => :'String',
    :'source' => :'String',
    :'from' => :'String',
    :'to' => :'String',
    :'started_at' => :'String',
    :'duration_seconds' => :'Float',
    :'outcome' => :'String',
    :'end_reason' => :'String',
    :'end_detail' => :'String',
    :'timeline' => :'Array<GetVoiceCallResponseCallTimelineInner>',
    :'recording_url' => :'String',
    :'variables' => :'Hash<String, String>',
    :'cost' => :'GetVoiceCallResponseCallCost'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 446

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tracking_id == o.tracking_id &&
      status == o.status &&
      agent_id == o.agent_id &&
      agent_name == o.agent_name &&
      direction == o.direction &&
      source == o.source &&
      from == o.from &&
      to == o.to &&
      started_at == o.started_at &&
      duration_seconds == o.duration_seconds &&
      outcome == o.outcome &&
      end_reason == o.end_reason &&
      end_detail == o.end_detail &&
      timeline == o.timeline &&
      recording_url == o.recording_url &&
      variables == o.variables &&
      cost == o.cost
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


470
471
472
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 470

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



476
477
478
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 476

def hash
  [tracking_id, status, agent_id, agent_name, direction, source, from, to, started_at, duration_seconds, outcome, end_reason, end_detail, timeline, recording_url, variables, cost].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 251

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @tracking_id.nil?
    invalid_properties.push('invalid value for "tracking_id", tracking_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @agent_name.nil?
    invalid_properties.push('invalid value for "agent_name", agent_name cannot be nil.')
  end

  if @direction.nil?
    invalid_properties.push('invalid value for "direction", direction cannot be nil.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @from.nil?
    invalid_properties.push('invalid value for "from", from cannot be nil.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @started_at.nil?
    invalid_properties.push('invalid value for "started_at", started_at cannot be nil.')
  end

  if @duration_seconds.nil?
    invalid_properties.push('invalid value for "duration_seconds", duration_seconds cannot be nil.')
  end

  if @timeline.nil?
    invalid_properties.push('invalid value for "timeline", timeline cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 505

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/pingram/models/get_voice_call_response_call.rb', line 299

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @tracking_id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["active", "ended", "failed"])
  return false unless status_validator.valid?(@status)
  return false if @agent_name.nil?
  return false if @direction.nil?
  direction_validator = EnumAttributeValidator.new('String', ["inbound", "outbound"])
  return false unless direction_validator.valid?(@direction)
  return false if @source.nil?
  source_validator = EnumAttributeValidator.new('String', ["pstn", "web"])
  return false unless source_validator.valid?(@source)
  return false if @from.nil?
  return false if @to.nil?
  return false if @started_at.nil?
  return false if @duration_seconds.nil?
  outcome_validator = EnumAttributeValidator.new('String', ["completed", "transferred", "voicemail", "no_answer", "failed"])
  return false unless outcome_validator.valid?(@outcome)
  end_reason_validator = EnumAttributeValidator.new('String', ["user_hangup", "agent_end_call", "silence_timeout", "max_duration", "free_tier_limit", "transferred", "voicemail", "provider_error", "connection_lost", "no_answer", "session_expired", "server_shutdown"])
  return false unless end_reason_validator.valid?(@end_reason)
  return false if @timeline.nil?
  true
end