Class: Pingram::InAppNotificationPatchRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/in_app_notification_patch_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InAppNotificationPatchRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::InAppNotificationPatchRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::InAppNotificationPatchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tracking_ids')
    if (value = attributes[:'tracking_ids']).is_a?(Array)
      self.tracking_ids = value
    end
  else
    self.tracking_ids = nil
  end

  if attributes.key?(:'opened')
    self.opened = attributes[:'opened']
  end

  if attributes.key?(:'clicked')
    self.clicked = attributes[:'clicked']
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end

  if attributes.key?(:'actioned1')
    self.actioned1 = attributes[:'actioned1']
  end

  if attributes.key?(:'actioned2')
    self.actioned2 = attributes[:'actioned2']
  end

  if attributes.key?(:'reply')
    self.reply = attributes[:'reply']
  end

  if attributes.key?(:'replies')
    if (value = attributes[:'replies']).is_a?(Array)
      self.replies = value
    end
  end
end

Instance Attribute Details

#actioned1Object

Returns the value of attribute actioned1.



26
27
28
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 26

def actioned1
  @actioned1
end

#actioned2Object

Returns the value of attribute actioned2.



28
29
30
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 28

def actioned2
  @actioned2
end

#archivedObject

Returns the value of attribute archived.



24
25
26
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 24

def archived
  @archived
end

#clickedObject

Returns the value of attribute clicked.



22
23
24
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 22

def clicked
  @clicked
end

#openedObject

Returns the value of attribute opened.



20
21
22
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 20

def opened
  @opened
end

#repliesObject

Returns the value of attribute replies.



32
33
34
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 32

def replies
  @replies
end

#replyObject

Returns the value of attribute reply.



30
31
32
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 30

def reply
  @reply
end

#tracking_idsObject

Returns the value of attribute tracking_ids.



18
19
20
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 18

def tracking_ids
  @tracking_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 35

def self.attribute_map
  {
    :'tracking_ids' => :'trackingIds',
    :'opened' => :'opened',
    :'clicked' => :'clicked',
    :'archived' => :'archived',
    :'actioned1' => :'actioned1',
    :'actioned2' => :'actioned2',
    :'reply' => :'reply',
    :'replies' => :'replies'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 59

def self.openapi_types
  {
    :'tracking_ids' => :'Array<String>',
    :'opened' => :'String',
    :'clicked' => :'String',
    :'archived' => :'String',
    :'actioned1' => :'String',
    :'actioned2' => :'String',
    :'reply' => :'GetInappNotificationsResponseNotificationsInnerRepliesInner',
    :'replies' => :'Array<GetInappNotificationsResponseNotificationsInnerRepliesInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tracking_ids == o.tracking_ids &&
      opened == o.opened &&
      clicked == o.clicked &&
      archived == o.archived &&
      actioned1 == o.actioned1 &&
      actioned2 == o.actioned2 &&
      reply == o.reply &&
      replies == o.replies
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 186

def hash
  [tracking_ids, opened, clicked, archived, actioned1, actioned2, reply, replies].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @tracking_ids.nil?
    invalid_properties.push('invalid value for "tracking_ids", tracking_ids cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
# File 'lib/pingram/models/in_app_notification_patch_request.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @tracking_ids.nil?
  true
end