Class: Pingram::InboundResponseBodyResultsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/inbound_response_body_results_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InboundResponseBodyResultsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::InboundResponseBodyResultsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::InboundResponseBodyResultsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'webhook')
    self.webhook = attributes[:'webhook']
  else
    self.webhook = nil
  end

  if attributes.key?(:'auto_reply')
    self.auto_reply = attributes[:'auto_reply']
  else
    self.auto_reply = nil
  end
end

Instance Attribute Details

#auto_replyObject

Returns the value of attribute auto_reply.



20
21
22
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 20

def auto_reply
  @auto_reply
end

#webhookObject

Returns the value of attribute webhook.



18
19
20
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 18

def webhook
  @webhook
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 45

def self.attribute_map
  {
    :'webhook' => :'webhook',
    :'auto_reply' => :'autoReply'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 63

def self.openapi_types
  {
    :'webhook' => :'String',
    :'auto_reply' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      webhook == o.webhook &&
      auto_reply == o.auto_reply
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 171

def hash
  [webhook, auto_reply].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 107

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @webhook.nil?
    invalid_properties.push('invalid value for "webhook", webhook cannot be nil.')
  end

  if @auto_reply.nil?
    invalid_properties.push('invalid value for "auto_reply", auto_reply cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
130
131
132
# File 'lib/pingram/models/inbound_response_body_results_inner.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @webhook.nil?
  webhook_validator = EnumAttributeValidator.new('String', ["delivered", "not_set", "not_enabled", "failed"])
  return false unless webhook_validator.valid?(@webhook)
  return false if @auto_reply.nil?
  auto_reply_validator = EnumAttributeValidator.new('String', ["sent", "skipped_opt_out", "skipped_already_replied", "skipped_no_config", "failed"])
  return false unless auto_reply_validator.valid?(@auto_reply)
  true
end