Class: Pingram::IngishtsPostRequestMetricDataQueriesInnerMetricStat

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb

Overview

<p>This structure defines the metric to be returned, along with the statistics, period, and units.</p>

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IngishtsPostRequestMetricDataQueriesInnerMetricStat

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::IngishtsPostRequestMetricDataQueriesInnerMetricStat` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::IngishtsPostRequestMetricDataQueriesInnerMetricStat`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metric')
    self.metric = attributes[:'metric']
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'stat')
    self.stat = attributes[:'stat']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end
end

Instance Attribute Details

#metricObject

Returns the value of attribute metric.



19
20
21
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 19

def metric
  @metric
end

#periodObject

<p>The granularity, in seconds, of the returned data points. For metrics with regular resolution, a period can be as short as one minute (60 seconds) and must be a multiple of 60. For high-resolution metrics that are collected at intervals of less than one minute, the period can be 1, 5, 10, 20, 30, 60, or any multiple of 60. High-resolution metrics are those metrics stored by a PutMetricData call that includes a StorageResolution of 1 second.</p> <p>If the StartTime parameter specifies a time stamp that is greater than 3 hours ago, you must specify the period as follows or no data points in that time range is returned:</p> <ul> <li> <p>Start time between 3 hours and 15 days ago - Use a multiple of 60 seconds (1 minute).</p> </li> <li> <p>Start time between 15 and 63 days ago - Use a multiple of 300 seconds (5 minutes).</p> </li> <li> <p>Start time greater than 63 days ago - Use a multiple of 3600 seconds (1 hour).</p> </li> </ul>



22
23
24
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 22

def period
  @period
end

#statObject

<p>The statistic to return. It can include any CloudWatch statistic or extended statistic.</p>



25
26
27
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 25

def stat
  @stat
end

#unitObject

Returns the value of attribute unit.



27
28
29
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 27

def unit
  @unit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 52

def self.attribute_map
  {
    :'metric' => :'Metric',
    :'period' => :'Period',
    :'stat' => :'Stat',
    :'unit' => :'Unit'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 72

def self.openapi_types
  {
    :'metric' => :'IngishtsPostRequestMetricDataQueriesInnerMetricStatMetric',
    :'period' => :'Float',
    :'stat' => :'String',
    :'unit' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      metric == o.metric &&
      period == o.period &&
      stat == o.stat &&
      unit == o.unit
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 166

def hash
  [metric, period, stat, unit].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
# File 'lib/pingram/models/ingishts_post_request_metric_data_queries_inner_metric_stat.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  unit_validator = EnumAttributeValidator.new('String', ["Bits", "Bits/Second", "Bytes", "Bytes/Second", "Count", "Count/Second", "Gigabits", "Gigabits/Second", "Gigabytes", "Gigabytes/Second", "Kilobits", "Kilobits/Second", "Kilobytes", "Kilobytes/Second", "Megabits", "Megabits/Second", "Megabytes", "Megabytes/Second", "Microseconds", "Milliseconds", "None", "Percent", "Seconds", "Terabits", "Terabits/Second", "Terabytes", "Terabytes/Second"])
  return false unless unit_validator.valid?(@unit)
  true
end