Class: Pingram::IntercomWebhookDataItemAnyOf

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/intercom_webhook_data_item_any_of.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntercomWebhookDataItemAnyOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::IntercomWebhookDataItemAnyOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::IntercomWebhookDataItemAnyOf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'admin_assignee_id')
    self.admin_assignee_id = attributes[:'admin_assignee_id']
  end

  if attributes.key?(:'team_assignee_id')
    self.team_assignee_id = attributes[:'team_assignee_id']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'contacts')
    self.contacts = attributes[:'contacts']
  else
    self.contacts = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'open')
    self.open = attributes[:'open']
  else
    self.open = nil
  end

  if attributes.key?(:'read')
    self.read = attributes[:'read']
  else
    self.read = nil
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  else
    self.priority = nil
  end
end

Instance Attribute Details

#admin_assignee_idObject

Returns the value of attribute admin_assignee_id.



28
29
30
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 28

def admin_assignee_id
  @admin_assignee_id
end

#contactsObject

Returns the value of attribute contacts.



34
35
36
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 34

def contacts
  @contacts
end

#created_atObject

Returns the value of attribute created_at.



22
23
24
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 22

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



20
21
22
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 20

def id
  @id
end

#openObject

Returns the value of attribute open.



38
39
40
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 38

def open
  @open
end

#priorityObject

Returns the value of attribute priority.



42
43
44
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 42

def priority
  @priority
end

#readObject

Returns the value of attribute read.



40
41
42
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 40

def read
  @read
end

#sourceObject

Returns the value of attribute source.



32
33
34
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 32

def source
  @source
end

#stateObject

Returns the value of attribute state.



36
37
38
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 36

def state
  @state
end

#team_assignee_idObject

Returns the value of attribute team_assignee_id.



30
31
32
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 30

def team_assignee_id
  @team_assignee_id
end

#titleObject

Returns the value of attribute title.



26
27
28
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 26

def title
  @title
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 18

def type
  @type
end

#updated_atObject

Returns the value of attribute updated_at.



24
25
26
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 24

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 67

def self.attribute_map
  {
    :'type' => :'type',
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'title' => :'title',
    :'admin_assignee_id' => :'admin_assignee_id',
    :'team_assignee_id' => :'team_assignee_id',
    :'source' => :'source',
    :'contacts' => :'contacts',
    :'state' => :'state',
    :'open' => :'open',
    :'read' => :'read',
    :'priority' => :'priority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 415

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 96

def self.openapi_types
  {
    :'type' => :'String',
    :'id' => :'String',
    :'created_at' => :'Float',
    :'updated_at' => :'Float',
    :'title' => :'String',
    :'admin_assignee_id' => :'Float',
    :'team_assignee_id' => :'String',
    :'source' => :'IntercomWebhookDataItemAnyOfSource',
    :'contacts' => :'IntercomWebhookDataItemAnyOfContacts',
    :'state' => :'String',
    :'open' => :'Boolean',
    :'read' => :'Boolean',
    :'priority' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 382

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      id == o.id &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      title == o.title &&
      admin_assignee_id == o.admin_assignee_id &&
      team_assignee_id == o.team_assignee_id &&
      source == o.source &&
      contacts == o.contacts &&
      state == o.state &&
      open == o.open &&
      read == o.read &&
      priority == o.priority
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


402
403
404
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 402

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



408
409
410
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 408

def hash
  [type, id, created_at, updated_at, title, admin_assignee_id, team_assignee_id, source, contacts, state, open, read, priority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 211

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @contacts.nil?
    invalid_properties.push('invalid value for "contacts", contacts cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @open.nil?
    invalid_properties.push('invalid value for "open", open cannot be nil.')
  end

  if @read.nil?
    invalid_properties.push('invalid value for "read", read cannot be nil.')
  end

  if @priority.nil?
    invalid_properties.push('invalid value for "priority", priority cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 437

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pingram/models/intercom_webhook_data_item_any_of.rb', line 259

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["conversation"])
  return false unless type_validator.valid?(@type)
  return false if @id.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @source.nil?
  return false if @contacts.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["open", "closed", "snoozed"])
  return false unless state_validator.valid?(@state)
  return false if @open.nil?
  return false if @read.nil?
  return false if @priority.nil?
  priority_validator = EnumAttributeValidator.new('String', ["priority", "not_priority"])
  return false unless priority_validator.valid?(@priority)
  true
end