Class: Pingram::KeysApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/keys_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ KeysApi

Returns a new instance of KeysApi.



19
20
21
# File 'lib/pingram/api/keys_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/keys_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#keys_create_api_key(create_key_request, opts = {}) ⇒ CreateKeyResponse

Create a new API key (secret or public) for an environment

Parameters:

  • create_key_request (CreateKeyRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/pingram/api/keys_api.rb', line 26

def keys_create_api_key(create_key_request, opts = {})
  data, _status_code, _headers = keys_create_api_key_with_http_info(create_key_request, opts)
  data
end

#keys_create_api_key_with_http_info(create_key_request, opts = {}) ⇒ Array<(CreateKeyResponse, Integer, Hash)>

Create a new API key (secret or public) for an environment

Parameters:

  • create_key_request (CreateKeyRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateKeyResponse, Integer, Hash)>)

    CreateKeyResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pingram/api/keys_api.rb', line 35

def keys_create_api_key_with_http_info(create_key_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeysApi.keys_create_api_key ...'
  end
  # verify the required parameter 'create_key_request' is set
  if @api_client.config.client_side_validation && create_key_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_key_request' when calling KeysApi.keys_create_api_key"
  end
  # resource path
  local_var_path = '/keys'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_key_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateKeyResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"KeysApi.keys_create_api_key",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeysApi#keys_create_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#keys_list_api_keys(opts = {}) ⇒ GetKeysResponse

List all API keys for the authenticated user’s account

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



91
92
93
94
# File 'lib/pingram/api/keys_api.rb', line 91

def keys_list_api_keys(opts = {})
  data, _status_code, _headers = keys_list_api_keys_with_http_info(opts)
  data
end

#keys_list_api_keys_with_http_info(opts = {}) ⇒ Array<(GetKeysResponse, Integer, Hash)>

List all API keys for the authenticated user&#39;s account

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetKeysResponse, Integer, Hash)>)

    GetKeysResponse data, response status code and response headers



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/pingram/api/keys_api.rb', line 99

def keys_list_api_keys_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeysApi.keys_list_api_keys ...'
  end
  # resource path
  local_var_path = '/keys'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetKeysResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"KeysApi.keys_list_api_keys",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeysApi#keys_list_api_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#keys_revoke_api_key(key_id, opts = {}) ⇒ DeleteKeyResponse

Revoke an API key

Parameters:

  • key_id (String)

    The API key ID (jti)

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



147
148
149
150
# File 'lib/pingram/api/keys_api.rb', line 147

def keys_revoke_api_key(key_id, opts = {})
  data, _status_code, _headers = keys_revoke_api_key_with_http_info(key_id, opts)
  data
end

#keys_revoke_api_key_with_http_info(key_id, opts = {}) ⇒ Array<(DeleteKeyResponse, Integer, Hash)>

Revoke an API key

Parameters:

  • key_id (String)

    The API key ID (jti)

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DeleteKeyResponse, Integer, Hash)>)

    DeleteKeyResponse data, response status code and response headers



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/pingram/api/keys_api.rb', line 156

def keys_revoke_api_key_with_http_info(key_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: KeysApi.keys_revoke_api_key ...'
  end
  # verify the required parameter 'key_id' is set
  if @api_client.config.client_side_validation && key_id.nil?
    fail ArgumentError, "Missing the required parameter 'key_id' when calling KeysApi.keys_revoke_api_key"
  end
  # resource path
  local_var_path = '/keys/{keyId}'.sub('{' + 'keyId' + '}', CGI.escape(key_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteKeyResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"KeysApi.keys_revoke_api_key",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: KeysApi#keys_revoke_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end