Class: Pingram::ListPersonalAccessTokensResponseTokensInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb

Overview

Public metadata returned by list/create (no tokenHash).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListPersonalAccessTokensResponseTokensInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::ListPersonalAccessTokensResponseTokensInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::ListPersonalAccessTokensResponseTokensInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'token_prefix')
    self.token_prefix = attributes[:'token_prefix']
  else
    self.token_prefix = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end

  if attributes.key?(:'revoked')
    self.revoked = attributes[:'revoked']
  else
    self.revoked = nil
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



25
26
27
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 25

def created_at
  @created_at
end

#expires_atObject

Returns the value of attribute expires_at.



27
28
29
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 27

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 19

def id
  @id
end

#last_used_atObject

Returns the value of attribute last_used_at.



29
30
31
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 29

def last_used_at
  @last_used_at
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 21

def name
  @name
end

#revokedObject

Returns the value of attribute revoked.



31
32
33
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 31

def revoked
  @revoked
end

#token_prefixObject

Returns the value of attribute token_prefix.



23
24
25
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 23

def token_prefix
  @token_prefix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 34

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'token_prefix' => :'tokenPrefix',
    :'created_at' => :'createdAt',
    :'expires_at' => :'expiresAt',
    :'last_used_at' => :'lastUsedAt',
    :'revoked' => :'revoked'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 57

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'token_prefix' => :'String',
    :'created_at' => :'String',
    :'expires_at' => :'String',
    :'last_used_at' => :'String',
    :'revoked' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      token_prefix == o.token_prefix &&
      created_at == o.created_at &&
      expires_at == o.expires_at &&
      last_used_at == o.last_used_at &&
      revoked == o.revoked
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 242

def hash
  [id, name, token_prefix, created_at, expires_at, last_used_at, revoked].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @token_prefix.nil?
    invalid_properties.push('invalid value for "token_prefix", token_prefix cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @revoked.nil?
    invalid_properties.push('invalid value for "revoked", revoked cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
168
# File 'lib/pingram/models/list_personal_access_tokens_response_tokens_inner.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @token_prefix.nil?
  return false if @created_at.nil?
  return false if @revoked.nil?
  true
end