Class: Pingram::LogQueryPostBody

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/log_query_post_body.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LogQueryPostBody

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/pingram/models/log_query_post_body.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::LogQueryPostBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::LogQueryPostBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_range_filter')
    if (value = attributes[:'date_range_filter']).is_a?(Array)
      self.date_range_filter = value
    end
  end

  if attributes.key?(:'user_filter')
    self.user_filter = attributes[:'user_filter']
  end

  if attributes.key?(:'env_id_filter')
    if (value = attributes[:'env_id_filter']).is_a?(Array)
      self.env_id_filter = value
    end
  end

  if attributes.key?(:'status_filter')
    self.status_filter = attributes[:'status_filter']
  end

  if attributes.key?(:'channel_filter')
    if (value = attributes[:'channel_filter']).is_a?(Array)
      self.channel_filter = value
    end
  end

  if attributes.key?(:'notification_filter')
    if (value = attributes[:'notification_filter']).is_a?(Array)
      self.notification_filter = value
    end
  end
end

Instance Attribute Details

#channel_filterObject

Returns the value of attribute channel_filter.



27
28
29
# File 'lib/pingram/models/log_query_post_body.rb', line 27

def channel_filter
  @channel_filter
end

#date_range_filterObject

A tuple of [startTime, endTime] for the date range filter, each representing a unix timestamp.



19
20
21
# File 'lib/pingram/models/log_query_post_body.rb', line 19

def date_range_filter
  @date_range_filter
end

#env_id_filterObject

Returns the value of attribute env_id_filter.



23
24
25
# File 'lib/pingram/models/log_query_post_body.rb', line 23

def env_id_filter
  @env_id_filter
end

#notification_filterObject

Returns the value of attribute notification_filter.



29
30
31
# File 'lib/pingram/models/log_query_post_body.rb', line 29

def notification_filter
  @notification_filter
end

#status_filterObject

Returns the value of attribute status_filter.



25
26
27
# File 'lib/pingram/models/log_query_post_body.rb', line 25

def status_filter
  @status_filter
end

#user_filterObject

Returns the value of attribute user_filter.



21
22
23
# File 'lib/pingram/models/log_query_post_body.rb', line 21

def user_filter
  @user_filter
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/pingram/models/log_query_post_body.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/pingram/models/log_query_post_body.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/pingram/models/log_query_post_body.rb', line 54

def self.attribute_map
  {
    :'date_range_filter' => :'dateRangeFilter',
    :'user_filter' => :'userFilter',
    :'env_id_filter' => :'envIdFilter',
    :'status_filter' => :'statusFilter',
    :'channel_filter' => :'channelFilter',
    :'notification_filter' => :'notificationFilter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/pingram/models/log_query_post_body.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/pingram/models/log_query_post_body.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
# File 'lib/pingram/models/log_query_post_body.rb', line 76

def self.openapi_types
  {
    :'date_range_filter' => :'Array<Float>',
    :'user_filter' => :'String',
    :'env_id_filter' => :'Array<String>',
    :'status_filter' => :'String',
    :'channel_filter' => :'Array<String>',
    :'notification_filter' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



187
188
189
190
191
192
193
194
195
196
# File 'lib/pingram/models/log_query_post_body.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_range_filter == o.date_range_filter &&
      user_filter == o.user_filter &&
      env_id_filter == o.env_id_filter &&
      status_filter == o.status_filter &&
      channel_filter == o.channel_filter &&
      notification_filter == o.notification_filter
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


200
201
202
# File 'lib/pingram/models/log_query_post_body.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



206
207
208
# File 'lib/pingram/models/log_query_post_body.rb', line 206

def hash
  [date_range_filter, user_filter, env_id_filter, status_filter, channel_filter, notification_filter].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pingram/models/log_query_post_body.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@date_range_filter.nil? && @date_range_filter.length > 2
    invalid_properties.push('invalid value for "date_range_filter", number of items must be less than or equal to 2.')
  end

  if !@date_range_filter.nil? && @date_range_filter.length < 2
    invalid_properties.push('invalid value for "date_range_filter", number of items must be greater than or equal to 2.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/pingram/models/log_query_post_body.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



160
161
162
163
164
165
# File 'lib/pingram/models/log_query_post_body.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@date_range_filter.nil? && @date_range_filter.length > 2
  return false if !@date_range_filter.nil? && @date_range_filter.length < 2
  true
end