Class: Pingram::LogsQueryResultResponse

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/logs_query_result_response.rb

Overview

Response type for GET /logs/query/queryId

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LogsQueryResultResponse

Initializes the object



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/pingram/models/logs_query_result_response.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::LogsQueryResultResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::LogsQueryResultResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'logs')
    if (value = attributes[:'logs']).is_a?(Array)
      self.logs = value
    end
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end
end

Instance Attribute Details

#error ⇒ Object

Returns the value of attribute error.



25
26
27
# File 'lib/pingram/models/logs_query_result_response.rb', line 25

def error
  @error
end

#logs ⇒ Object

Returns the value of attribute logs.



21
22
23
# File 'lib/pingram/models/logs_query_result_response.rb', line 21

def logs
  @logs
end

#message ⇒ Object

Returns the value of attribute message.



23
24
25
# File 'lib/pingram/models/logs_query_result_response.rb', line 23

def message
  @message
end

#status ⇒ Object

Returns the value of attribute status.



19
20
21
# File 'lib/pingram/models/logs_query_result_response.rb', line 19

def status
  @status
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



38
39
40
# File 'lib/pingram/models/logs_query_result_response.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/pingram/models/logs_query_result_response.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/pingram/models/logs_query_result_response.rb', line 28

def self.attribute_map
  {
    :'status' => :'status',
    :'logs' => :'logs',
    :'message' => :'message',
    :'error' => :'error'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/pingram/models/logs_query_result_response.rb', line 156

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



58
59
60
61
# File 'lib/pingram/models/logs_query_result_response.rb', line 58

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/pingram/models/logs_query_result_response.rb', line 48

def self.openapi_types
  {
    :'status' => :'String',
    :'logs' => :'Array<LogsGetResponseLogsInner>',
    :'message' => :'String',
    :'error' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



132
133
134
135
136
137
138
139
# File 'lib/pingram/models/logs_query_result_response.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      logs == o.logs &&
      message == o.message &&
      error == o.error
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


143
144
145
# File 'lib/pingram/models/logs_query_result_response.rb', line 143

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



149
150
151
# File 'lib/pingram/models/logs_query_result_response.rb', line 149

def hash
  [status, logs, message, error].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



102
103
104
105
106
107
108
109
110
# File 'lib/pingram/models/logs_query_result_response.rb', line 102

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/pingram/models/logs_query_result_response.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



114
115
116
117
118
# File 'lib/pingram/models/logs_query_result_response.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @status.nil?
  true
end