Class: Pingram::NotificationPatchRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/notification_patch_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NotificationPatchRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/pingram/models/notification_patch_request.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::NotificationPatchRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::NotificationPatchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'channels')
    if (value = attributes[:'channels']).is_a?(Array)
      self.channels = value
    end
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'deduplication')
    self.deduplication = attributes[:'deduplication']
  end

  if attributes.key?(:'throttling')
    self.throttling = attributes[:'throttling']
  end

  if attributes.key?(:'retention')
    self.retention = attributes[:'retention']
  end

  if attributes.key?(:'options')
    self.options = attributes[:'options']
  end
end

Instance Attribute Details

#channelsObject

Returns the value of attribute channels.



20
21
22
# File 'lib/pingram/models/notification_patch_request.rb', line 20

def channels
  @channels
end

#deduplicationObject

Returns the value of attribute deduplication.



24
25
26
# File 'lib/pingram/models/notification_patch_request.rb', line 24

def deduplication
  @deduplication
end

#enabledObject

Returns the value of attribute enabled.



22
23
24
# File 'lib/pingram/models/notification_patch_request.rb', line 22

def enabled
  @enabled
end

#optionsObject

Returns the value of attribute options.



30
31
32
# File 'lib/pingram/models/notification_patch_request.rb', line 30

def options
  @options
end

#retentionObject

Returns the value of attribute retention.



28
29
30
# File 'lib/pingram/models/notification_patch_request.rb', line 28

def retention
  @retention
end

#throttlingObject

Returns the value of attribute throttling.



26
27
28
# File 'lib/pingram/models/notification_patch_request.rb', line 26

def throttling
  @throttling
end

#titleObject

Returns the value of attribute title.



18
19
20
# File 'lib/pingram/models/notification_patch_request.rb', line 18

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pingram/models/notification_patch_request.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pingram/models/notification_patch_request.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/pingram/models/notification_patch_request.rb', line 33

def self.attribute_map
  {
    :'title' => :'title',
    :'channels' => :'channels',
    :'enabled' => :'enabled',
    :'deduplication' => :'deduplication',
    :'throttling' => :'throttling',
    :'retention' => :'retention',
    :'options' => :'options'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/pingram/models/notification_patch_request.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
73
74
75
# File 'lib/pingram/models/notification_patch_request.rb', line 69

def self.openapi_nullable
  Set.new([
    :'deduplication',
    :'throttling',
    :'retention',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/pingram/models/notification_patch_request.rb', line 56

def self.openapi_types
  {
    :'title' => :'String',
    :'channels' => :'Array<ChannelsEnum>',
    :'enabled' => :'Boolean',
    :'deduplication' => :'NotificationPatchRequestDeduplication',
    :'throttling' => :'NotificationPatchRequestThrottling',
    :'retention' => :'Float',
    :'options' => :'GetNotificationsResponseInnerOptions'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/pingram/models/notification_patch_request.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      channels == o.channels &&
      enabled == o.enabled &&
      deduplication == o.deduplication &&
      throttling == o.throttling &&
      retention == o.retention &&
      options == o.options
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/pingram/models/notification_patch_request.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/pingram/models/notification_patch_request.rb', line 161

def hash
  [title, channels, enabled, deduplication, throttling, retention, options].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
# File 'lib/pingram/models/notification_patch_request.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/pingram/models/notification_patch_request.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
# File 'lib/pingram/models/notification_patch_request.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end