Class: Pingram::NumbersApi
- Inherits:
-
Object
- Object
- Pingram::NumbersApi
- Defined in:
- lib/pingram/api/numbers_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ NumbersApi
constructor
A new instance of NumbersApi.
-
#numbers_list(opts = {}) ⇒ ListPhoneNumbersResponse
List all phone numbers registered for the account.
-
#numbers_list_with_http_info(opts = {}) ⇒ Array<(ListPhoneNumbersResponse, Integer, Hash)>
List all phone numbers registered for the account.
-
#numbers_order_number(order_phone_number_request, opts = {}) ⇒ OrderPhoneNumberResponse
Purchase a Telnyx phone number for the authenticated account.
-
#numbers_order_number_with_http_info(order_phone_number_request, opts = {}) ⇒ Array<(OrderPhoneNumberResponse, Integer, Hash)>
Purchase a Telnyx phone number for the authenticated account.
-
#numbers_search_available(country_code, opts = {}) ⇒ SearchAvailablePhoneNumbersResponse
Search for available Telnyx phone numbers.
-
#numbers_search_available_with_http_info(country_code, opts = {}) ⇒ Array<(SearchAvailablePhoneNumbersResponse, Integer, Hash)>
Search for available Telnyx phone numbers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ NumbersApi
Returns a new instance of NumbersApi.
19 20 21 |
# File 'lib/pingram/api/numbers_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/numbers_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#numbers_list(opts = {}) ⇒ ListPhoneNumbersResponse
List all phone numbers registered for the account
25 26 27 28 |
# File 'lib/pingram/api/numbers_api.rb', line 25 def numbers_list(opts = {}) data, _status_code, _headers = numbers_list_with_http_info(opts) data end |
#numbers_list_with_http_info(opts = {}) ⇒ Array<(ListPhoneNumbersResponse, Integer, Hash)>
List all phone numbers registered for the account
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/pingram/api/numbers_api.rb', line 33 def numbers_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NumbersApi.numbers_list ...' end # resource path local_var_path = '/numbers/list' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListPhoneNumbersResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"NumbersApi.numbers_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NumbersApi#numbers_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#numbers_order_number(order_phone_number_request, opts = {}) ⇒ OrderPhoneNumberResponse
Purchase a Telnyx phone number for the authenticated account
81 82 83 84 |
# File 'lib/pingram/api/numbers_api.rb', line 81 def numbers_order_number(order_phone_number_request, opts = {}) data, _status_code, _headers = numbers_order_number_with_http_info(order_phone_number_request, opts) data end |
#numbers_order_number_with_http_info(order_phone_number_request, opts = {}) ⇒ Array<(OrderPhoneNumberResponse, Integer, Hash)>
Purchase a Telnyx phone number for the authenticated account
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/api/numbers_api.rb', line 90 def numbers_order_number_with_http_info(order_phone_number_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NumbersApi.numbers_order_number ...' end # verify the required parameter 'order_phone_number_request' is set if @api_client.config.client_side_validation && order_phone_number_request.nil? fail ArgumentError, "Missing the required parameter 'order_phone_number_request' when calling NumbersApi.numbers_order_number" end # resource path local_var_path = '/numbers/order' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(order_phone_number_request) # return_type return_type = opts[:debug_return_type] || 'OrderPhoneNumberResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"NumbersApi.numbers_order_number", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NumbersApi#numbers_order_number\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#numbers_search_available(country_code, opts = {}) ⇒ SearchAvailablePhoneNumbersResponse
Search for available Telnyx phone numbers
150 151 152 153 |
# File 'lib/pingram/api/numbers_api.rb', line 150 def numbers_search_available(country_code, opts = {}) data, _status_code, _headers = numbers_search_available_with_http_info(country_code, opts) data end |
#numbers_search_available_with_http_info(country_code, opts = {}) ⇒ Array<(SearchAvailablePhoneNumbersResponse, Integer, Hash)>
Search for available Telnyx phone numbers
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pingram/api/numbers_api.rb', line 162 def numbers_search_available_with_http_info(country_code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NumbersApi.numbers_search_available ...' end # verify the required parameter 'country_code' is set if @api_client.config.client_side_validation && country_code.nil? fail ArgumentError, "Missing the required parameter 'country_code' when calling NumbersApi.numbers_search_available" end # resource path local_var_path = '/numbers/available' # query parameters query_params = opts[:query_params] || {} query_params[:'countryCode'] = country_code query_params[:'features'] = opts[:'features'] if !opts[:'features'].nil? query_params[:'areaCode'] = opts[:'area_code'] if !opts[:'area_code'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SearchAvailablePhoneNumbersResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"NumbersApi.numbers_search_available", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NumbersApi#numbers_search_available\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |