Class: Pingram::OrganizationApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/organization_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OrganizationApi

Returns a new instance of OrganizationApi.



19
20
21
# File 'lib/pingram/api/organization_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/organization_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#organization_create(opts = {}) ⇒ CreateOrganizationResponse

Create organization after SMS verification bypass

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



25
26
27
28
# File 'lib/pingram/api/organization_api.rb', line 25

def organization_create(opts = {})
  data, _status_code, _headers = organization_create_with_http_info(opts)
  data
end

#organization_create_with_http_info(opts = {}) ⇒ Array<(CreateOrganizationResponse, Integer, Hash)>

Create organization after SMS verification bypass

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateOrganizationResponse, Integer, Hash)>)

    CreateOrganizationResponse data, response status code and response headers



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/pingram/api/organization_api.rb', line 33

def organization_create_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationApi.organization_create ...'
  end
  # resource path
  local_var_path = '/organizations'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CreateOrganizationResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"OrganizationApi.organization_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationApi#organization_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#organization_get_usage(opts = {}) ⇒ OrganizationUsage

Get usage for the authenticated account’s organization (new billing model).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



80
81
82
83
# File 'lib/pingram/api/organization_api.rb', line 80

def organization_get_usage(opts = {})
  data, _status_code, _headers = organization_get_usage_with_http_info(opts)
  data
end

#organization_get_usage_history(start_date, end_date, opts = {}) ⇒ OrganizationUsageHistory

Get historical usage for the authenticated account’s organization over a date range.

Parameters:

  • start_date (String)

    Start date (YYYY-MM-DD) for the range

  • end_date (String)

    End date (YYYY-MM-DD) for the range

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



137
138
139
140
# File 'lib/pingram/api/organization_api.rb', line 137

def organization_get_usage_history(start_date, end_date, opts = {})
  data, _status_code, _headers = organization_get_usage_history_with_http_info(start_date, end_date, opts)
  data
end

#organization_get_usage_history_with_http_info(start_date, end_date, opts = {}) ⇒ Array<(OrganizationUsageHistory, Integer, Hash)>

Get historical usage for the authenticated account&#39;s organization over a date range.

Parameters:

  • start_date (String)

    Start date (YYYY-MM-DD) for the range

  • end_date (String)

    End date (YYYY-MM-DD) for the range

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(OrganizationUsageHistory, Integer, Hash)>)

    OrganizationUsageHistory data, response status code and response headers



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/pingram/api/organization_api.rb', line 147

def organization_get_usage_history_with_http_info(start_date, end_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationApi.organization_get_usage_history ...'
  end
  # verify the required parameter 'start_date' is set
  if @api_client.config.client_side_validation && start_date.nil?
    fail ArgumentError, "Missing the required parameter 'start_date' when calling OrganizationApi.organization_get_usage_history"
  end
  # verify the required parameter 'end_date' is set
  if @api_client.config.client_side_validation && end_date.nil?
    fail ArgumentError, "Missing the required parameter 'end_date' when calling OrganizationApi.organization_get_usage_history"
  end
  # resource path
  local_var_path = '/organization/usage/history'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'startDate'] = start_date
  query_params[:'endDate'] = end_date

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'OrganizationUsageHistory'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"OrganizationApi.organization_get_usage_history",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationApi#organization_get_usage_history\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#organization_get_usage_with_http_info(opts = {}) ⇒ Array<(OrganizationUsage, Integer, Hash)>

Get usage for the authenticated account&#39;s organization (new billing model).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(OrganizationUsage, Integer, Hash)>)

    OrganizationUsage data, response status code and response headers



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/pingram/api/organization_api.rb', line 88

def organization_get_usage_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationApi.organization_get_usage ...'
  end
  # resource path
  local_var_path = '/organization/usage'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'OrganizationUsage'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"OrganizationApi.organization_get_usage",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationApi#organization_get_usage\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end