Class: Pingram::OrganizationUsage

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/organization_usage.rb

Overview

Response for GET /account/organization/usage

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationUsage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/pingram/models/organization_usage.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::OrganizationUsage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::OrganizationUsage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'costs')
    self.costs = attributes[:'costs']
  end

  if attributes.key?(:'counts')
    self.counts = attributes[:'counts']
  end

  if attributes.key?(:'billing_cycle_start')
    self.billing_cycle_start = attributes[:'billing_cycle_start']
  else
    self.billing_cycle_start = nil
  end

  if attributes.key?(:'billing_cycle_end')
    self.billing_cycle_end = attributes[:'billing_cycle_end']
  else
    self.billing_cycle_end = nil
  end
end

Instance Attribute Details

#billing_cycle_endObject

Billing cycle end date (ISO string)



27
28
29
# File 'lib/pingram/models/organization_usage.rb', line 27

def billing_cycle_end
  @billing_cycle_end
end

#billing_cycle_startObject

Billing cycle start date (ISO string)



24
25
26
# File 'lib/pingram/models/organization_usage.rb', line 24

def billing_cycle_start
  @billing_cycle_start
end

#costsObject

Returns the value of attribute costs.



19
20
21
# File 'lib/pingram/models/organization_usage.rb', line 19

def costs
  @costs
end

#countsObject

Returns the value of attribute counts.



21
22
23
# File 'lib/pingram/models/organization_usage.rb', line 21

def counts
  @counts
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/pingram/models/organization_usage.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/pingram/models/organization_usage.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/pingram/models/organization_usage.rb', line 30

def self.attribute_map
  {
    :'costs' => :'costs',
    :'counts' => :'counts',
    :'billing_cycle_start' => :'billingCycleStart',
    :'billing_cycle_end' => :'billingCycleEnd'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/pingram/models/organization_usage.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/pingram/models/organization_usage.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/pingram/models/organization_usage.rb', line 50

def self.openapi_types
  {
    :'costs' => :'OrganizationUsageCosts',
    :'counts' => :'OrganizationUsageCounts',
    :'billing_cycle_start' => :'String',
    :'billing_cycle_end' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
# File 'lib/pingram/models/organization_usage.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      costs == o.costs &&
      counts == o.counts &&
      billing_cycle_start == o.billing_cycle_start &&
      billing_cycle_end == o.billing_cycle_end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/pingram/models/organization_usage.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/pingram/models/organization_usage.rb', line 166

def hash
  [costs, counts, billing_cycle_start, billing_cycle_end].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/pingram/models/organization_usage.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @billing_cycle_start.nil?
    invalid_properties.push('invalid value for "billing_cycle_start", billing_cycle_start cannot be nil.')
  end

  if @billing_cycle_end.nil?
    invalid_properties.push('invalid value for "billing_cycle_end", billing_cycle_end cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/pingram/models/organization_usage.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
124
125
# File 'lib/pingram/models/organization_usage.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @billing_cycle_start.nil?
  return false if @billing_cycle_end.nil?
  true
end