Class: Pingram::OrganizationUsageHistoryItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/organization_usage_history_items_inner.rb

Overview

Single usage item in historical response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationUsageHistoryItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::OrganizationUsageHistoryItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::OrganizationUsageHistoryItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'year_month')
    self.year_month = attributes[:'year_month']
  else
    self.year_month = nil
  end

  if attributes.key?(:'message_usage')
    self.message_usage = attributes[:'message_usage']
  else
    self.message_usage = nil
  end

  if attributes.key?(:'budget_usage')
    self.budget_usage = attributes[:'budget_usage']
  else
    self.budget_usage = nil
  end

  if attributes.key?(:'cost_sms')
    self.cost_sms = attributes[:'cost_sms']
  else
    self.cost_sms = nil
  end

  if attributes.key?(:'cost_call')
    self.cost_call = attributes[:'cost_call']
  else
    self.cost_call = nil
  end

  if attributes.key?(:'channel_usages')
    if (value = attributes[:'channel_usages']).is_a?(Hash)
      self.channel_usages = value
    end
  else
    self.channel_usages = nil
  end
end

Instance Attribute Details

#budget_usageObject

Total budget usage in USD (cost_SMS + cost_CALL)



26
27
28
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 26

def budget_usage
  @budget_usage
end

#channel_usagesObject

Per-channel usage breakdown



35
36
37
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 35

def channel_usages
  @channel_usages
end

#cost_callObject

Call cost in USD



32
33
34
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 32

def cost_call
  @cost_call
end

#cost_smsObject

SMS cost in USD



29
30
31
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 29

def cost_sms
  @cost_sms
end

#message_usageObject

Total message usage (EMAIL + INAPP_WEB + WEB_PUSH + PUSH + SLACK)



23
24
25
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 23

def message_usage
  @message_usage
end

#year_monthObject

Year-month (YYYY-MM) for this usage period



20
21
22
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 20

def year_month
  @year_month
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 38

def self.attribute_map
  {
    :'year_month' => :'yearMonth',
    :'message_usage' => :'messageUsage',
    :'budget_usage' => :'budgetUsage',
    :'cost_sms' => :'costSms',
    :'cost_call' => :'costCall',
    :'channel_usages' => :'channelUsages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 265

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 60

def self.openapi_types
  {
    :'year_month' => :'String',
    :'message_usage' => :'Float',
    :'budget_usage' => :'Float',
    :'cost_sms' => :'Float',
    :'cost_call' => :'Float',
    :'channel_usages' => :'Hash<String, Float>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      year_month == o.year_month &&
      message_usage == o.message_usage &&
      budget_usage == o.budget_usage &&
      cost_sms == o.cost_sms &&
      cost_call == o.cost_call &&
      channel_usages == o.channel_usages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 258

def hash
  [year_month, message_usage, budget_usage, cost_sms, cost_call, channel_usages].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @year_month.nil?
    invalid_properties.push('invalid value for "year_month", year_month cannot be nil.')
  end

  if @message_usage.nil?
    invalid_properties.push('invalid value for "message_usage", message_usage cannot be nil.')
  end

  if @budget_usage.nil?
    invalid_properties.push('invalid value for "budget_usage", budget_usage cannot be nil.')
  end

  if @cost_sms.nil?
    invalid_properties.push('invalid value for "cost_sms", cost_sms cannot be nil.')
  end

  if @cost_call.nil?
    invalid_properties.push('invalid value for "cost_call", cost_call cannot be nil.')
  end

  if @channel_usages.nil?
    invalid_properties.push('invalid value for "channel_usages", channel_usages cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
174
175
# File 'lib/pingram/models/organization_usage_history_items_inner.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @year_month.nil?
  return false if @message_usage.nil?
  return false if @budget_usage.nil?
  return false if @cost_sms.nil?
  return false if @cost_call.nil?
  return false if @channel_usages.nil?
  true
end