Class: Pingram::ProfileApi
- Inherits:
-
Object
- Object
- Pingram::ProfileApi
- Defined in:
- lib/pingram/api/profile_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ProfileApi
constructor
A new instance of ProfileApi.
-
#profile_accept_invite(accept_invite_request, opts = {}) ⇒ AcceptInviteResponse
Accept a team invitation using a token.
-
#profile_accept_invite_with_http_info(accept_invite_request, opts = {}) ⇒ Array<(AcceptInviteResponse, Integer, Hash)>
Accept a team invitation using a token.
-
#profile_change_email(change_email_request, opts = {}) ⇒ SuccessResponse
Change the email address of the authenticated user.
-
#profile_change_email_with_http_info(change_email_request, opts = {}) ⇒ Array<(SuccessResponse, Integer, Hash)>
Change the email address of the authenticated user.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProfileApi
Returns a new instance of ProfileApi.
19 20 21 |
# File 'lib/pingram/api/profile_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/profile_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#profile_accept_invite(accept_invite_request, opts = {}) ⇒ AcceptInviteResponse
Accept a team invitation using a token
26 27 28 29 |
# File 'lib/pingram/api/profile_api.rb', line 26 def profile_accept_invite(accept_invite_request, opts = {}) data, _status_code, _headers = profile_accept_invite_with_http_info(accept_invite_request, opts) data end |
#profile_accept_invite_with_http_info(accept_invite_request, opts = {}) ⇒ Array<(AcceptInviteResponse, Integer, Hash)>
Accept a team invitation using a token
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/profile_api.rb', line 35 def profile_accept_invite_with_http_info(accept_invite_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfileApi.profile_accept_invite ...' end # verify the required parameter 'accept_invite_request' is set if @api_client.config.client_side_validation && accept_invite_request.nil? fail ArgumentError, "Missing the required parameter 'accept_invite_request' when calling ProfileApi.profile_accept_invite" end # resource path local_var_path = '/profile/accept_invite' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(accept_invite_request) # return_type return_type = opts[:debug_return_type] || 'AcceptInviteResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"ProfileApi.profile_accept_invite", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfileApi#profile_accept_invite\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#profile_change_email(change_email_request, opts = {}) ⇒ SuccessResponse
Change the email address of the authenticated user
92 93 94 95 |
# File 'lib/pingram/api/profile_api.rb', line 92 def profile_change_email(change_email_request, opts = {}) data, _status_code, _headers = profile_change_email_with_http_info(change_email_request, opts) data end |
#profile_change_email_with_http_info(change_email_request, opts = {}) ⇒ Array<(SuccessResponse, Integer, Hash)>
Change the email address of the authenticated user
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pingram/api/profile_api.rb', line 101 def profile_change_email_with_http_info(change_email_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfileApi.profile_change_email ...' end # verify the required parameter 'change_email_request' is set if @api_client.config.client_side_validation && change_email_request.nil? fail ArgumentError, "Missing the required parameter 'change_email_request' when calling ProfileApi.profile_change_email" end # resource path local_var_path = '/profile/change-email' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(change_email_request) # return_type return_type = opts[:debug_return_type] || 'SuccessResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"ProfileApi.profile_change_email", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfileApi#profile_change_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |