Class: Pingram::PushSettingsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/push_settings_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PushSettingsApi

Returns a new instance of PushSettingsApi.



19
20
21
# File 'lib/pingram/api/push_settings_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/push_settings_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#push_settings_delete_push_apn_settings(opts = {}) ⇒ nil

Delete Apple Push Notification (APN) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


25
26
27
28
# File 'lib/pingram/api/push_settings_api.rb', line 25

def push_settings_delete_push_apn_settings(opts = {})
  push_settings_delete_push_apn_settings_with_http_info(opts)
  nil
end

#push_settings_delete_push_apn_settings_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Apple Push Notification (APN) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/pingram/api/push_settings_api.rb', line 33

def push_settings_delete_push_apn_settings_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PushSettingsApi.push_settings_delete_push_apn_settings ...'
  end
  # resource path
  local_var_path = '/settings/push/apn'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"PushSettingsApi.push_settings_delete_push_apn_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PushSettingsApi#push_settings_delete_push_apn_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#push_settings_delete_push_fcm_settings(opts = {}) ⇒ nil

Delete Firebase Cloud Messaging (FCM) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


78
79
80
81
# File 'lib/pingram/api/push_settings_api.rb', line 78

def push_settings_delete_push_fcm_settings(opts = {})
  push_settings_delete_push_fcm_settings_with_http_info(opts)
  nil
end

#push_settings_delete_push_fcm_settings_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Firebase Cloud Messaging (FCM) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/pingram/api/push_settings_api.rb', line 86

def push_settings_delete_push_fcm_settings_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PushSettingsApi.push_settings_delete_push_fcm_settings ...'
  end
  # resource path
  local_var_path = '/settings/push/fcm'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"PushSettingsApi.push_settings_delete_push_fcm_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PushSettingsApi#push_settings_delete_push_fcm_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#push_settings_get_push_apn_settings(opts = {}) ⇒ APNConfig

Get Apple Push Notification (APN) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



131
132
133
134
# File 'lib/pingram/api/push_settings_api.rb', line 131

def push_settings_get_push_apn_settings(opts = {})
  data, _status_code, _headers = push_settings_get_push_apn_settings_with_http_info(opts)
  data
end

#push_settings_get_push_apn_settings_with_http_info(opts = {}) ⇒ Array<(APNConfig, Integer, Hash)>

Get Apple Push Notification (APN) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(APNConfig, Integer, Hash)>)

    APNConfig data, response status code and response headers



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/pingram/api/push_settings_api.rb', line 139

def push_settings_get_push_apn_settings_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PushSettingsApi.push_settings_get_push_apn_settings ...'
  end
  # resource path
  local_var_path = '/settings/push/apn'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'APNConfig'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"PushSettingsApi.push_settings_get_push_apn_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PushSettingsApi#push_settings_get_push_apn_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#push_settings_get_push_fcm_settings(opts = {}) ⇒ PushSettingsFCMResponse

Get Firebase Cloud Messaging (FCM) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



186
187
188
189
# File 'lib/pingram/api/push_settings_api.rb', line 186

def push_settings_get_push_fcm_settings(opts = {})
  data, _status_code, _headers = push_settings_get_push_fcm_settings_with_http_info(opts)
  data
end

#push_settings_get_push_fcm_settings_with_http_info(opts = {}) ⇒ Array<(PushSettingsFCMResponse, Integer, Hash)>

Get Firebase Cloud Messaging (FCM) configuration for the current account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PushSettingsFCMResponse, Integer, Hash)>)

    PushSettingsFCMResponse data, response status code and response headers



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/pingram/api/push_settings_api.rb', line 194

def push_settings_get_push_fcm_settings_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PushSettingsApi.push_settings_get_push_fcm_settings ...'
  end
  # resource path
  local_var_path = '/settings/push/fcm'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PushSettingsFCMResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"PushSettingsApi.push_settings_get_push_fcm_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PushSettingsApi#push_settings_get_push_fcm_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#push_settings_upsert_push_apn_settings(apn_config, opts = {}) ⇒ APNConfig

Create or update Apple Push Notification (APN) configuration for the current account.

Parameters:

  • apn_config (APNConfig)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



242
243
244
245
# File 'lib/pingram/api/push_settings_api.rb', line 242

def push_settings_upsert_push_apn_settings(apn_config, opts = {})
  data, _status_code, _headers = push_settings_upsert_push_apn_settings_with_http_info(apn_config, opts)
  data
end

#push_settings_upsert_push_apn_settings_with_http_info(apn_config, opts = {}) ⇒ Array<(APNConfig, Integer, Hash)>

Create or update Apple Push Notification (APN) configuration for the current account.

Parameters:

  • apn_config (APNConfig)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(APNConfig, Integer, Hash)>)

    APNConfig data, response status code and response headers



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/pingram/api/push_settings_api.rb', line 251

def push_settings_upsert_push_apn_settings_with_http_info(apn_config, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PushSettingsApi.push_settings_upsert_push_apn_settings ...'
  end
  # verify the required parameter 'apn_config' is set
  if @api_client.config.client_side_validation && apn_config.nil?
    fail ArgumentError, "Missing the required parameter 'apn_config' when calling PushSettingsApi.push_settings_upsert_push_apn_settings"
  end
  # resource path
  local_var_path = '/settings/push/apn'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(apn_config)

  # return_type
  return_type = opts[:debug_return_type] || 'APNConfig'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"PushSettingsApi.push_settings_upsert_push_apn_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PushSettingsApi#push_settings_upsert_push_apn_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#push_settings_upsert_push_fcm_settings(push_settings_fcm_put_request, opts = {}) ⇒ PushSettingsFCMResponse

Create or update Firebase Cloud Messaging (FCM) configuration for the current account.

Parameters:

Returns:



308
309
310
311
# File 'lib/pingram/api/push_settings_api.rb', line 308

def push_settings_upsert_push_fcm_settings(push_settings_fcm_put_request, opts = {})
  data, _status_code, _headers = push_settings_upsert_push_fcm_settings_with_http_info(push_settings_fcm_put_request, opts)
  data
end

#push_settings_upsert_push_fcm_settings_with_http_info(push_settings_fcm_put_request, opts = {}) ⇒ Array<(PushSettingsFCMResponse, Integer, Hash)>

Create or update Firebase Cloud Messaging (FCM) configuration for the current account.

Parameters:

Returns:

  • (Array<(PushSettingsFCMResponse, Integer, Hash)>)

    PushSettingsFCMResponse data, response status code and response headers



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/pingram/api/push_settings_api.rb', line 317

def push_settings_upsert_push_fcm_settings_with_http_info(push_settings_fcm_put_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PushSettingsApi.push_settings_upsert_push_fcm_settings ...'
  end
  # verify the required parameter 'push_settings_fcm_put_request' is set
  if @api_client.config.client_side_validation && push_settings_fcm_put_request.nil?
    fail ArgumentError, "Missing the required parameter 'push_settings_fcm_put_request' when calling PushSettingsApi.push_settings_upsert_push_fcm_settings"
  end
  # resource path
  local_var_path = '/settings/push/fcm'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(push_settings_fcm_put_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PushSettingsFCMResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"PushSettingsApi.push_settings_upsert_push_fcm_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PushSettingsApi#push_settings_upsert_push_fcm_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end