Class: Pingram::RegistrationsApi
- Inherits:
-
Object
- Object
- Pingram::RegistrationsApi
- Defined in:
- lib/pingram/api/registrations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RegistrationsApi
constructor
A new instance of RegistrationsApi.
-
#registrations_create_us10dlc_brand(ten_dlc_brand_create_request, opts = {}) ⇒ TenDlcBrandRegistration
Create a new 10DLC brand registration.
-
#registrations_create_us10dlc_brand_with_http_info(ten_dlc_brand_create_request, opts = {}) ⇒ Array<(TenDlcBrandRegistration, Integer, Hash)>
Create a new 10DLC brand registration.
-
#registrations_get_us10dlc_brand(opts = {}) ⇒ TenDlcBrandRegistration
Get the 10DLC brand registration for the authenticated account.
-
#registrations_get_us10dlc_brand_with_http_info(opts = {}) ⇒ Array<(TenDlcBrandRegistration, Integer, Hash)>
Get the 10DLC brand registration for the authenticated account.
-
#registrations_update_us10dlc_brand(ten_dlc_brand_update_request, opts = {}) ⇒ TenDlcBrandRegistration
Update an existing 10DLC brand registration.
-
#registrations_update_us10dlc_brand_with_http_info(ten_dlc_brand_update_request, opts = {}) ⇒ Array<(TenDlcBrandRegistration, Integer, Hash)>
Update an existing 10DLC brand registration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RegistrationsApi
Returns a new instance of RegistrationsApi.
19 20 21 |
# File 'lib/pingram/api/registrations_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/registrations_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#registrations_create_us10dlc_brand(ten_dlc_brand_create_request, opts = {}) ⇒ TenDlcBrandRegistration
Create a new 10DLC brand registration. Sets brandStatus to pending_review; Pingram handles carrier submission after review.
26 27 28 29 |
# File 'lib/pingram/api/registrations_api.rb', line 26 def registrations_create_us10dlc_brand(ten_dlc_brand_create_request, opts = {}) data, _status_code, _headers = registrations_create_us10dlc_brand_with_http_info(ten_dlc_brand_create_request, opts) data end |
#registrations_create_us10dlc_brand_with_http_info(ten_dlc_brand_create_request, opts = {}) ⇒ Array<(TenDlcBrandRegistration, Integer, Hash)>
Create a new 10DLC brand registration. Sets brandStatus to pending_review; Pingram handles carrier submission after review.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/registrations_api.rb', line 35 def registrations_create_us10dlc_brand_with_http_info(ten_dlc_brand_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RegistrationsApi.registrations_create_us10dlc_brand ...' end # verify the required parameter 'ten_dlc_brand_create_request' is set if @api_client.config.client_side_validation && ten_dlc_brand_create_request.nil? fail ArgumentError, "Missing the required parameter 'ten_dlc_brand_create_request' when calling RegistrationsApi.registrations_create_us10dlc_brand" end # resource path local_var_path = '/registrations/us/10dlc/brand' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(ten_dlc_brand_create_request) # return_type return_type = opts[:debug_return_type] || 'TenDlcBrandRegistration' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"RegistrationsApi.registrations_create_us10dlc_brand", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RegistrationsApi#registrations_create_us10dlc_brand\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#registrations_get_us10dlc_brand(opts = {}) ⇒ TenDlcBrandRegistration
Get the 10DLC brand registration for the authenticated account. Returns null when no registration exists yet.
91 92 93 94 |
# File 'lib/pingram/api/registrations_api.rb', line 91 def registrations_get_us10dlc_brand(opts = {}) data, _status_code, _headers = registrations_get_us10dlc_brand_with_http_info(opts) data end |
#registrations_get_us10dlc_brand_with_http_info(opts = {}) ⇒ Array<(TenDlcBrandRegistration, Integer, Hash)>
Get the 10DLC brand registration for the authenticated account. Returns null when no registration exists yet.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/api/registrations_api.rb', line 99 def registrations_get_us10dlc_brand_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RegistrationsApi.registrations_get_us10dlc_brand ...' end # resource path local_var_path = '/registrations/us/10dlc/brand' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TenDlcBrandRegistration' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"RegistrationsApi.registrations_get_us10dlc_brand", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RegistrationsApi#registrations_get_us10dlc_brand\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#registrations_update_us10dlc_brand(ten_dlc_brand_update_request, opts = {}) ⇒ TenDlcBrandRegistration
Update an existing 10DLC brand registration. Business fields are editable before carrier submission; workflow status is managed by Pingram.
147 148 149 150 |
# File 'lib/pingram/api/registrations_api.rb', line 147 def registrations_update_us10dlc_brand(ten_dlc_brand_update_request, opts = {}) data, _status_code, _headers = registrations_update_us10dlc_brand_with_http_info(ten_dlc_brand_update_request, opts) data end |
#registrations_update_us10dlc_brand_with_http_info(ten_dlc_brand_update_request, opts = {}) ⇒ Array<(TenDlcBrandRegistration, Integer, Hash)>
Update an existing 10DLC brand registration. Business fields are editable before carrier submission; workflow status is managed by Pingram.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/pingram/api/registrations_api.rb', line 156 def registrations_update_us10dlc_brand_with_http_info(ten_dlc_brand_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RegistrationsApi.registrations_update_us10dlc_brand ...' end # verify the required parameter 'ten_dlc_brand_update_request' is set if @api_client.config.client_side_validation && ten_dlc_brand_update_request.nil? fail ArgumentError, "Missing the required parameter 'ten_dlc_brand_update_request' when calling RegistrationsApi.registrations_update_us10dlc_brand" end # resource path local_var_path = '/registrations/us/10dlc/brand' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(ten_dlc_brand_update_request) # return_type return_type = opts[:debug_return_type] || 'TenDlcBrandRegistration' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"RegistrationsApi.registrations_update_us10dlc_brand", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RegistrationsApi#registrations_update_us10dlc_brand\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |