Class: Pingram::SenderApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/sender_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SenderApi

Returns a new instance of SenderApi.



19
20
21
# File 'lib/pingram/api/sender_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/sender_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#sender_delete_schedule(tracking_id, opts = {}) ⇒ MessageResponse

Delete (unschedule) an already scheduled notification

Parameters:

  • tracking_id (String)

    The tracking ID of the scheduled notification

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/pingram/api/sender_api.rb', line 26

def sender_delete_schedule(tracking_id, opts = {})
  data, _status_code, _headers = sender_delete_schedule_with_http_info(tracking_id, opts)
  data
end

#sender_delete_schedule_with_http_info(tracking_id, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>

Delete (unschedule) an already scheduled notification

Parameters:

  • tracking_id (String)

    The tracking ID of the scheduled notification

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MessageResponse, Integer, Hash)>)

    MessageResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/pingram/api/sender_api.rb', line 35

def sender_delete_schedule_with_http_info(tracking_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SenderApi.sender_delete_schedule ...'
  end
  # verify the required parameter 'tracking_id' is set
  if @api_client.config.client_side_validation && tracking_id.nil?
    fail ArgumentError, "Missing the required parameter 'tracking_id' when calling SenderApi.sender_delete_schedule"
  end
  # resource path
  local_var_path = '/sender/scheduler/{trackingId}'.sub('{' + 'trackingId' + '}', CGI.escape(tracking_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MessageResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"SenderApi.sender_delete_schedule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SenderApi#sender_delete_schedule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#sender_test_email(post_email_test_request, opts = {}) ⇒ PostEmailTestResponse

Test the emailer with a sample email

Parameters:

  • post_email_test_request (PostEmailTestRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



87
88
89
90
# File 'lib/pingram/api/sender_api.rb', line 87

def sender_test_email(post_email_test_request, opts = {})
  data, _status_code, _headers = sender_test_email_with_http_info(post_email_test_request, opts)
  data
end

#sender_test_email_with_http_info(post_email_test_request, opts = {}) ⇒ Array<(PostEmailTestResponse, Integer, Hash)>

Test the emailer with a sample email

Parameters:

  • post_email_test_request (PostEmailTestRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PostEmailTestResponse, Integer, Hash)>)

    PostEmailTestResponse data, response status code and response headers



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/pingram/api/sender_api.rb', line 96

def sender_test_email_with_http_info(post_email_test_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SenderApi.sender_test_email ...'
  end
  # verify the required parameter 'post_email_test_request' is set
  if @api_client.config.client_side_validation && post_email_test_request.nil?
    fail ArgumentError, "Missing the required parameter 'post_email_test_request' when calling SenderApi.sender_test_email"
  end
  # resource path
  local_var_path = '/sender/test/email'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(post_email_test_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PostEmailTestResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"SenderApi.sender_test_email",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SenderApi#sender_test_email\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#sender_update_schedule(tracking_id, sender_post_body, opts = {}) ⇒ MessageResponse

Update the body or schedule of an already scheduled notification.

Parameters:

  • tracking_id (String)

    The tracking ID of the scheduled notification

  • sender_post_body (SenderPostBody)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



154
155
156
157
# File 'lib/pingram/api/sender_api.rb', line 154

def sender_update_schedule(tracking_id, sender_post_body, opts = {})
  data, _status_code, _headers = sender_update_schedule_with_http_info(tracking_id, sender_post_body, opts)
  data
end

#sender_update_schedule_with_http_info(tracking_id, sender_post_body, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>

Update the body or schedule of an already scheduled notification.

Parameters:

  • tracking_id (String)

    The tracking ID of the scheduled notification

  • sender_post_body (SenderPostBody)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MessageResponse, Integer, Hash)>)

    MessageResponse data, response status code and response headers



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/pingram/api/sender_api.rb', line 164

def sender_update_schedule_with_http_info(tracking_id, sender_post_body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SenderApi.sender_update_schedule ...'
  end
  # verify the required parameter 'tracking_id' is set
  if @api_client.config.client_side_validation && tracking_id.nil?
    fail ArgumentError, "Missing the required parameter 'tracking_id' when calling SenderApi.sender_update_schedule"
  end
  # verify the required parameter 'sender_post_body' is set
  if @api_client.config.client_side_validation && sender_post_body.nil?
    fail ArgumentError, "Missing the required parameter 'sender_post_body' when calling SenderApi.sender_update_schedule"
  end
  # resource path
  local_var_path = '/sender/scheduler/{trackingId}'.sub('{' + 'trackingId' + '}', CGI.escape(tracking_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(sender_post_body)

  # return_type
  return_type = opts[:debug_return_type] || 'MessageResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"SenderApi.sender_update_schedule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SenderApi#sender_update_schedule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end