Class: Pingram::SenderPostBodyOptionsFcmAndroid
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::SenderPostBodyOptionsFcmAndroid
- Defined in:
- lib/pingram/models/sender_post_body_options_fcm_android.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#collapse_key ⇒ Object
Returns the value of attribute collapse_key.
-
#priority ⇒ Object
Returns the value of attribute priority.
-
#restricted_package_name ⇒ Object
Returns the value of attribute restricted_package_name.
-
#ttl ⇒ Object
Returns the value of attribute ttl.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SenderPostBodyOptionsFcmAndroid
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SenderPostBodyOptionsFcmAndroid
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::SenderPostBodyOptionsFcmAndroid` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::SenderPostBodyOptionsFcmAndroid`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'collapse_key') self.collapse_key = attributes[:'collapse_key'] end if attributes.key?(:'priority') self.priority = attributes[:'priority'] end if attributes.key?(:'ttl') self.ttl = attributes[:'ttl'] end if attributes.key?(:'restricted_package_name') self.restricted_package_name = attributes[:'restricted_package_name'] end end |
Instance Attribute Details
#collapse_key ⇒ Object
Returns the value of attribute collapse_key.
18 19 20 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 18 def collapse_key @collapse_key end |
#priority ⇒ Object
Returns the value of attribute priority.
20 21 22 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 20 def priority @priority end |
#restricted_package_name ⇒ Object
Returns the value of attribute restricted_package_name.
24 25 26 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 24 def restricted_package_name @restricted_package_name end |
#ttl ⇒ Object
Returns the value of attribute ttl.
22 23 24 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 22 def ttl @ttl end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 49 def self.attribute_map { :'collapse_key' => :'collapseKey', :'priority' => :'priority', :'ttl' => :'ttl', :'restricted_package_name' => :'restrictedPackageName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 69 def self.openapi_types { :'collapse_key' => :'String', :'priority' => :'String', :'ttl' => :'Float', :'restricted_package_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && collapse_key == o.collapse_key && priority == o.priority && ttl == o.ttl && restricted_package_name == o.restricted_package_name end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 163 def hash [collapse_key, priority, ttl, restricted_package_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 |
# File 'lib/pingram/models/sender_post_body_options_fcm_android.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' priority_validator = EnumAttributeValidator.new('String', ["high", "normal"]) return false unless priority_validator.valid?(@priority) true end |