Class: Pingram::SubNotificationsApi
- Inherits:
-
Object
- Object
- Pingram::SubNotificationsApi
- Defined in:
- lib/pingram/api/sub_notifications_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SubNotificationsApi
constructor
A new instance of SubNotificationsApi.
-
#sub_notifications_delete_sub_notification(notification_id, sub_notification_id, opts = {}) ⇒ nil
This endpoint is no longer maintained and should not be used.
-
#sub_notifications_delete_sub_notification_with_http_info(notification_id, sub_notification_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
This endpoint is no longer maintained and should not be used.
-
#sub_notifications_put_sub_notification(notification_id, sub_notification_id, sub_notification_put_request, opts = {}) ⇒ SubNotification
This endpoint is no longer maintained and should not be used.
-
#sub_notifications_put_sub_notification_with_http_info(notification_id, sub_notification_id, sub_notification_put_request, opts = {}) ⇒ Array<(SubNotification, Integer, Hash)>
This endpoint is no longer maintained and should not be used.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SubNotificationsApi
Returns a new instance of SubNotificationsApi.
19 20 21 |
# File 'lib/pingram/api/sub_notifications_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/sub_notifications_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#sub_notifications_delete_sub_notification(notification_id, sub_notification_id, opts = {}) ⇒ nil
This endpoint is no longer maintained and should not be used.
27 28 29 30 |
# File 'lib/pingram/api/sub_notifications_api.rb', line 27 def sub_notifications_delete_sub_notification(notification_id, sub_notification_id, opts = {}) sub_notifications_delete_sub_notification_with_http_info(notification_id, sub_notification_id, opts) nil end |
#sub_notifications_delete_sub_notification_with_http_info(notification_id, sub_notification_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
This endpoint is no longer maintained and should not be used.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/pingram/api/sub_notifications_api.rb', line 37 def sub_notifications_delete_sub_notification_with_http_info(notification_id, sub_notification_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SubNotificationsApi.sub_notifications_delete_sub_notification ...' end # verify the required parameter 'notification_id' is set if @api_client.config.client_side_validation && notification_id.nil? fail ArgumentError, "Missing the required parameter 'notification_id' when calling SubNotificationsApi.sub_notifications_delete_sub_notification" end # verify the required parameter 'sub_notification_id' is set if @api_client.config.client_side_validation && sub_notification_id.nil? fail ArgumentError, "Missing the required parameter 'sub_notification_id' when calling SubNotificationsApi.sub_notifications_delete_sub_notification" end # resource path local_var_path = '/notifications/{notificationId}/subNotifications/{subNotificationId}'.sub('{' + 'notificationId' + '}', CGI.escape(notification_id.to_s)).sub('{' + 'subNotificationId' + '}', CGI.escape(sub_notification_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"SubNotificationsApi.sub_notifications_delete_sub_notification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SubNotificationsApi#sub_notifications_delete_sub_notification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sub_notifications_put_sub_notification(notification_id, sub_notification_id, sub_notification_put_request, opts = {}) ⇒ SubNotification
This endpoint is no longer maintained and should not be used.
95 96 97 98 |
# File 'lib/pingram/api/sub_notifications_api.rb', line 95 def sub_notifications_put_sub_notification(notification_id, sub_notification_id, sub_notification_put_request, opts = {}) data, _status_code, _headers = sub_notifications_put_sub_notification_with_http_info(notification_id, sub_notification_id, sub_notification_put_request, opts) data end |
#sub_notifications_put_sub_notification_with_http_info(notification_id, sub_notification_id, sub_notification_put_request, opts = {}) ⇒ Array<(SubNotification, Integer, Hash)>
This endpoint is no longer maintained and should not be used.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/pingram/api/sub_notifications_api.rb', line 106 def sub_notifications_put_sub_notification_with_http_info(notification_id, sub_notification_id, sub_notification_put_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SubNotificationsApi.sub_notifications_put_sub_notification ...' end # verify the required parameter 'notification_id' is set if @api_client.config.client_side_validation && notification_id.nil? fail ArgumentError, "Missing the required parameter 'notification_id' when calling SubNotificationsApi.sub_notifications_put_sub_notification" end # verify the required parameter 'sub_notification_id' is set if @api_client.config.client_side_validation && sub_notification_id.nil? fail ArgumentError, "Missing the required parameter 'sub_notification_id' when calling SubNotificationsApi.sub_notifications_put_sub_notification" end # verify the required parameter 'sub_notification_put_request' is set if @api_client.config.client_side_validation && sub_notification_put_request.nil? fail ArgumentError, "Missing the required parameter 'sub_notification_put_request' when calling SubNotificationsApi.sub_notifications_put_sub_notification" end # resource path local_var_path = '/notifications/{notificationId}/subNotifications/{subNotificationId}'.sub('{' + 'notificationId' + '}', CGI.escape(notification_id.to_s)).sub('{' + 'subNotificationId' + '}', CGI.escape(sub_notification_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(sub_notification_put_request) # return_type return_type = opts[:debug_return_type] || 'SubNotification' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"SubNotificationsApi.sub_notifications_put_sub_notification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SubNotificationsApi#sub_notifications_put_sub_notification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |