Class: Pingram::TenDlcBrandCreateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/ten_dlc_brand_create_request.rb

Overview

Request body for POST /registrations/us/10dlc/brand

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TenDlcBrandCreateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::TenDlcBrandCreateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::TenDlcBrandCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  else
    self.scenario_id = nil
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  else
    self.business_type = nil
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  else
    self.legal_name = nil
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  else
    self.website = nil
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  else
    self.compliance_contact_email = nil
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  else
    self.compliance_contact_phone = nil
  end
end

Instance Attribute Details

#business_typeObject

Legal entity type for a 10DLC brand. - PRIVATE_PROFIT: private for-profit (LLC, corp, etc.) - SOLE_PROPRIETOR: sole proprietorship - PUBLIC_PROFIT: publicly traded for-profit - NON_PROFIT: non-profit - GOVERNMENT: government



23
24
25
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 23

def business_type
  @business_type
end

#cityObject

Returns the value of attribute city.



42
43
44
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 42

def city
  @city
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



48
49
50
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 48

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



50
51
52
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 50

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



38
39
40
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 38

def country
  @country
end

#first_nameObject

Required when businessType is SOLE_PROPRIETOR.



28
29
30
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 28

def first_name
  @first_name
end

#last_nameObject

Required when businessType is SOLE_PROPRIETOR.



31
32
33
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 31

def last_name
  @last_name
end

Returns the value of attribute legal_name.



25
26
27
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 25

def legal_name
  @legal_name
end

#postal_codeObject

Returns the value of attribute postal_code.



46
47
48
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 46

def postal_code
  @postal_code
end

#scenario_idObject

Who the 10DLC brand is registered for. - own_brand: personal or company project - client_brand: agency or contractor



20
21
22
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 20

def scenario_id
  @scenario_id
end

#stateObject

Returns the value of attribute state.



44
45
46
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 44

def state
  @state
end

#streetObject

Returns the value of attribute street.



40
41
42
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 40

def street
  @street
end

#tax_idObject

For US companies (country US): 9-digit EIN (Employer Identification Number). For Canada (country CA): 9-digit BN (Business Number). For other countries: national business tax identifier. Required except when businessType is SOLE_PROPRIETOR.



34
35
36
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 34

def tax_id
  @tax_id
end

#websiteObject

Returns the value of attribute website.



36
37
38
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 36

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 75

def self.attribute_map
  {
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'street' => :'street',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postalCode',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 377

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 125

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 105

def self.openapi_types
  {
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'street' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 343

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      street == o.street &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


364
365
366
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 364

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



370
371
372
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 370

def hash
  [scenario_id, business_type, legal_name, first_name, last_name, tax_id, website, country, street, city, state, postal_code, compliance_contact_email, compliance_contact_phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 219

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @scenario_id.nil?
    invalid_properties.push('invalid value for "scenario_id", scenario_id cannot be nil.')
  end

  if @business_type.nil?
    invalid_properties.push('invalid value for "business_type", business_type cannot be nil.')
  end

  if @legal_name.nil?
    invalid_properties.push('invalid value for "legal_name", legal_name cannot be nil.')
  end

  if @website.nil?
    invalid_properties.push('invalid value for "website", website cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @compliance_contact_email.nil?
    invalid_properties.push('invalid value for "compliance_contact_email", compliance_contact_email cannot be nil.')
  end

  if @compliance_contact_phone.nil?
    invalid_properties.push('invalid value for "compliance_contact_phone", compliance_contact_phone cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 399

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 255

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @scenario_id.nil?
  scenario_id_validator = EnumAttributeValidator.new('String', ["own_brand", "client_brand"])
  return false unless scenario_id_validator.valid?(@scenario_id)
  return false if @business_type.nil?
  business_type_validator = EnumAttributeValidator.new('String', ["PRIVATE_PROFIT", "SOLE_PROPRIETOR", "PUBLIC_PROFIT", "NON_PROFIT", "GOVERNMENT"])
  return false unless business_type_validator.valid?(@business_type)
  return false if @legal_name.nil?
  return false if @website.nil?
  return false if @country.nil?
  return false if @compliance_contact_email.nil?
  return false if @compliance_contact_phone.nil?
  true
end