Class: Pingram::TenDlcBrandRegistrationDetails

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pingram/models/ten_dlc_brand_registration_details.rb

Overview

System-access GET response; includes internal Telnyx provider IDs and admin-only fields.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TenDlcBrandRegistrationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 176

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::TenDlcBrandRegistrationDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::TenDlcBrandRegistrationDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  else
    self.scenario_id = nil
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  else
    self.business_type = nil
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  else
    self.legal_name = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  else
    self.website = nil
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'full_address')
    self.full_address = attributes[:'full_address']
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  else
    self.compliance_contact_email = nil
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  else
    self.compliance_contact_phone = nil
  end

  if attributes.key?(:'brand_status')
    self.brand_status = attributes[:'brand_status']
  else
    self.brand_status = nil
  end

  if attributes.key?(:'campaign_status')
    self.campaign_status = attributes[:'campaign_status']
  else
    self.campaign_status = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'vertical')
    self.vertical = attributes[:'vertical']
  end

  if attributes.key?(:'entity_type')
    self.entity_type = attributes[:'entity_type']
  end

  if attributes.key?(:'telnyx_profile_id')
    self.telnyx_profile_id = attributes[:'telnyx_profile_id']
  end

  if attributes.key?(:'telnyx_brand_id')
    self.telnyx_brand_id = attributes[:'telnyx_brand_id']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



19
20
21
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 19

def 
  @account_id
end

#brand_statusObject

Pingram-side brand registration workflow status. - not_started: no customer submission yet - pending_review: customer submitted; Pingram has not submitted to carriers - in_progress: submitted for carrier review - approved | rejected | info_needed: review outcome



56
57
58
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 56

def brand_status
  @brand_status
end

#business_typeObject

Returns the value of attribute business_type.



23
24
25
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 23

def business_type
  @business_type
end

#campaign_statusObject

Pingram-side brand registration workflow status. - not_started: no customer submission yet - pending_review: customer submitted; Pingram has not submitted to carriers - in_progress: submitted for carrier review - approved | rejected | info_needed: review outcome



59
60
61
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 59

def campaign_status
  @campaign_status
end

#cityObject

Returns the value of attribute city.



42
43
44
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 42

def city
  @city
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



51
52
53
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 51

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



53
54
55
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 53

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



38
39
40
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 38

def country
  @country
end

#created_atObject

Returns the value of attribute created_at.



61
62
63
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 61

def created_at
  @created_at
end

#display_nameObject

Brand display name (marketing/DBA); defaults to legalName on customer submit.



28
29
30
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 28

def display_name
  @display_name
end

#entity_typeObject

Legacy only when businessType is Other.



68
69
70
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 68

def entity_type
  @entity_type
end

#first_nameObject

Returns the value of attribute first_name.



30
31
32
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 30

def first_name
  @first_name
end

#full_addressObject

Legacy records only; new submissions use structured address fields.



49
50
51
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 49

def full_address
  @full_address
end

#last_nameObject

Returns the value of attribute last_name.



32
33
34
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 32

def last_name
  @last_name
end

Returns the value of attribute legal_name.



25
26
27
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 25

def legal_name
  @legal_name
end

#postal_codeObject

Returns the value of attribute postal_code.



46
47
48
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 46

def postal_code
  @postal_code
end

#scenario_idObject

Returns the value of attribute scenario_id.



21
22
23
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 21

def scenario_id
  @scenario_id
end

#stateObject

Returns the value of attribute state.



44
45
46
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 44

def state
  @state
end

#streetObject

Returns the value of attribute street.



40
41
42
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 40

def street
  @street
end

#tax_idObject

Returns the value of attribute tax_id.



34
35
36
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 34

def tax_id
  @tax_id
end

#telnyx_brand_idObject

Returns the value of attribute telnyx_brand_id.



72
73
74
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 72

def telnyx_brand_id
  @telnyx_brand_id
end

#telnyx_profile_idObject

Returns the value of attribute telnyx_profile_id.



70
71
72
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 70

def telnyx_profile_id
  @telnyx_profile_id
end

#updated_atObject

Returns the value of attribute updated_at.



63
64
65
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 63

def updated_at
  @updated_at
end

#verticalObject

Returns the value of attribute vertical.



65
66
67
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 65

def vertical
  @vertical
end

#websiteObject

Returns the value of attribute website.



36
37
38
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 36

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



128
129
130
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 128

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



133
134
135
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 133

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 97

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'display_name' => :'displayName',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'street' => :'street',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postalCode',
    :'full_address' => :'fullAddress',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone',
    :'brand_status' => :'brandStatus',
    :'campaign_status' => :'campaignStatus',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'vertical' => :'vertical',
    :'entity_type' => :'entityType',
    :'telnyx_profile_id' => :'telnyxProfileId',
    :'telnyx_brand_id' => :'telnyxBrandId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 561

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



169
170
171
172
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 169

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 138

def self.openapi_types
  {
    :'account_id' => :'String',
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'display_name' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'street' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'full_address' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String',
    :'brand_status' => :'String',
    :'campaign_status' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'vertical' => :'String',
    :'entity_type' => :'String',
    :'telnyx_profile_id' => :'String',
    :'telnyx_brand_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 516

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      display_name == o.display_name &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      street == o.street &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code &&
      full_address == o.full_address &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone &&
      brand_status == o.brand_status &&
      campaign_status == o.campaign_status &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      vertical == o.vertical &&
      entity_type == o.entity_type &&
      telnyx_profile_id == o.telnyx_profile_id &&
      telnyx_brand_id == o.telnyx_brand_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


548
549
550
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 548

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



554
555
556
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 554

def hash
  [, scenario_id, business_type, legal_name, display_name, first_name, last_name, tax_id, website, country, street, city, state, postal_code, full_address, compliance_contact_email, compliance_contact_phone, brand_status, campaign_status, created_at, updated_at, vertical, entity_type, telnyx_profile_id, telnyx_brand_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 317

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @scenario_id.nil?
    invalid_properties.push('invalid value for "scenario_id", scenario_id cannot be nil.')
  end

  if @business_type.nil?
    invalid_properties.push('invalid value for "business_type", business_type cannot be nil.')
  end

  if @legal_name.nil?
    invalid_properties.push('invalid value for "legal_name", legal_name cannot be nil.')
  end

  if @website.nil?
    invalid_properties.push('invalid value for "website", website cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @compliance_contact_email.nil?
    invalid_properties.push('invalid value for "compliance_contact_email", compliance_contact_email cannot be nil.')
  end

  if @compliance_contact_phone.nil?
    invalid_properties.push('invalid value for "compliance_contact_phone", compliance_contact_phone cannot be nil.')
  end

  if @brand_status.nil?
    invalid_properties.push('invalid value for "brand_status", brand_status cannot be nil.')
  end

  if @campaign_status.nil?
    invalid_properties.push('invalid value for "campaign_status", campaign_status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 583

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/pingram/models/ten_dlc_brand_registration_details.rb', line 373

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @scenario_id.nil?
  return false if @business_type.nil?
  return false if @legal_name.nil?
  return false if @website.nil?
  return false if @country.nil?
  return false if @compliance_contact_email.nil?
  return false if @compliance_contact_phone.nil?
  return false if @brand_status.nil?
  brand_status_validator = EnumAttributeValidator.new('String', ["not_started", "in_progress", "pending_review", "approved", "rejected", "info_needed"])
  return false unless brand_status_validator.valid?(@brand_status)
  return false if @campaign_status.nil?
  campaign_status_validator = EnumAttributeValidator.new('String', ["not_started", "in_progress", "pending_review", "approved", "rejected", "info_needed"])
  return false unless campaign_status_validator.valid?(@campaign_status)
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end