Class: Pingram::User

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/pingram/models/user.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::User` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'push_tokens')
    if (value = attributes[:'push_tokens']).is_a?(Array)
      self.push_tokens = value
    end
  end

  if attributes.key?(:'web_push_tokens')
    if (value = attributes[:'web_push_tokens']).is_a?(Array)
      self.web_push_tokens = value
    end
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end

  if attributes.key?(:'slack_channel')
    self.slack_channel = attributes[:'slack_channel']
  end

  if attributes.key?(:'slack_token')
    self.slack_token = attributes[:'slack_token']
  end

  if attributes.key?(:'last_seen_time')
    self.last_seen_time = attributes[:'last_seen_time']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'email_suppression_status')
    self.email_suppression_status = attributes[:'email_suppression_status']
  end
end

Instance Attribute Details

#created_atObject

Creation timestamp. Read-only.



48
49
50
# File 'lib/pingram/models/user.rb', line 48

def created_at
  @created_at
end

#emailObject

User’s email address for email notifications.



22
23
24
# File 'lib/pingram/models/user.rb', line 22

def email
  @email
end

#email_suppression_statusObject

Returns the value of attribute email_suppression_status.



50
51
52
# File 'lib/pingram/models/user.rb', line 50

def email_suppression_status
  @email_suppression_status
end

#idObject

Unique user identifier. Required.



19
20
21
# File 'lib/pingram/models/user.rb', line 19

def id
  @id
end

#last_seen_timeObject

Last activity timestamp. Updated automatically. Read-only.



42
43
44
# File 'lib/pingram/models/user.rb', line 42

def last_seen_time
  @last_seen_time
end

#numberObject

User’s phone number for SMS/call notifications.



25
26
27
# File 'lib/pingram/models/user.rb', line 25

def number
  @number
end

#push_tokensObject

Mobile push tokens (FCM, APN) for push notifications.



28
29
30
# File 'lib/pingram/models/user.rb', line 28

def push_tokens
  @push_tokens
end

#slack_channelObject

The destination channel of slack notifications sent to this user. Can be either of the following: - Channel name, e.g. \“test\” - Channel name with # prefix, e.g. \“#test\” - Channel ID, e.g. \“C1234567890\” - User ID for DM, e.g. \“U1234567890\” - Username with @ prefix, e.g. \“@test\”



37
38
39
# File 'lib/pingram/models/user.rb', line 37

def slack_channel
  @slack_channel
end

#slack_tokenObject

Returns the value of attribute slack_token.



39
40
41
# File 'lib/pingram/models/user.rb', line 39

def slack_token
  @slack_token
end

#timezoneObject

User’s timezone (e.g. \“America/New_York\”) for scheduling.



34
35
36
# File 'lib/pingram/models/user.rb', line 34

def timezone
  @timezone
end

#updated_atObject

Last update timestamp. Read-only.



45
46
47
# File 'lib/pingram/models/user.rb', line 45

def updated_at
  @updated_at
end

#web_push_tokensObject

Web push subscription config from the browser.



31
32
33
# File 'lib/pingram/models/user.rb', line 31

def web_push_tokens
  @web_push_tokens
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/pingram/models/user.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/pingram/models/user.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/pingram/models/user.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'email' => :'email',
    :'number' => :'number',
    :'push_tokens' => :'pushTokens',
    :'web_push_tokens' => :'webPushTokens',
    :'timezone' => :'timezone',
    :'slack_channel' => :'slackChannel',
    :'slack_token' => :'slackToken',
    :'last_seen_time' => :'lastSeenTime',
    :'updated_at' => :'updatedAt',
    :'created_at' => :'createdAt',
    :'email_suppression_status' => :'emailSuppressionStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/pingram/models/user.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/pingram/models/user.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/pingram/models/user.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'email' => :'String',
    :'number' => :'String',
    :'push_tokens' => :'Array<GetUsersResponseUsersInnerPushTokensInner>',
    :'web_push_tokens' => :'Array<GetUsersResponseUsersInnerWebPushTokensInner>',
    :'timezone' => :'String',
    :'slack_channel' => :'String',
    :'slack_token' => :'GetUsersResponseUsersInnerSlackToken',
    :'last_seen_time' => :'String',
    :'updated_at' => :'String',
    :'created_at' => :'String',
    :'email_suppression_status' => :'GetUsersResponseUsersInnerEmailSuppressionStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/pingram/models/user.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      email == o.email &&
      number == o.number &&
      push_tokens == o.push_tokens &&
      web_push_tokens == o.web_push_tokens &&
      timezone == o.timezone &&
      slack_channel == o.slack_channel &&
      slack_token == o.slack_token &&
      last_seen_time == o.last_seen_time &&
      updated_at == o.updated_at &&
      created_at == o.created_at &&
      email_suppression_status == o.email_suppression_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/pingram/models/user.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/pingram/models/user.rb', line 232

def hash
  [id, email, number, push_tokens, web_push_tokens, timezone, slack_channel, slack_token, last_seen_time, updated_at, created_at, email_suppression_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
# File 'lib/pingram/models/user.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/pingram/models/user.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
# File 'lib/pingram/models/user.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end