Class: Pingram::UsersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/users_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UsersApi



19
20
21
# File 'lib/pingram/api/users_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/users_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#users_delete_user(user_id, opts = {}) ⇒ DeleteUserResponse

Delete a user and all associated data (in-app notifications, preferences, and user record)

Options Hash (opts):

  • :env_id (String) —

    Environment ID (required when using JWT auth)



27
28
29
30
# File 'lib/pingram/api/users_api.rb', line 27

def users_delete_user(user_id, opts = {})
  data, _status_code, _headers = users_delete_user_with_http_info(user_id, opts)
  data
end

#users_delete_user_with_http_info(user_id, opts = {}) ⇒ Array<(DeleteUserResponse, Integer, Hash)>

Delete a user and all associated data (in-app notifications, preferences, and user record)

Options Hash (opts):

  • :env_id (String) —

    Environment ID (required when using JWT auth)



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/pingram/api/users_api.rb', line 37

def users_delete_user_with_http_info(user_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersApi.users_delete_user ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersApi.users_delete_user"
  end
  # resource path
  local_var_path = '/users/{userId}'.sub('{' + 'userId' + '}', CGI.escape(user_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'envId'] = opts[:'env_id'] if !opts[:'env_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteUserResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"UsersApi.users_delete_user",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersApi#users_delete_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#users_list_users(limit, next_token, opts = {}) ⇒ GetUsersResponse

Get all users for an environment with pagination support

Options Hash (opts):

  • :env_id (String) —

    Environment ID (required when using JWT auth)



92
93
94
95
# File 'lib/pingram/api/users_api.rb', line 92

def users_list_users(limit, next_token, opts = {})
  data, _status_code, _headers = users_list_users_with_http_info(limit, next_token, opts)
  data
end

#users_list_users_with_http_info(limit, next_token, opts = {}) ⇒ Array<(GetUsersResponse, Integer, Hash)>

Get all users for an environment with pagination support

Options Hash (opts):

  • :env_id (String) —

    Environment ID (required when using JWT auth)



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pingram/api/users_api.rb', line 103

def users_list_users_with_http_info(limit, next_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersApi.users_list_users ...'
  end
  # verify the required parameter 'limit' is set
  if @api_client.config.client_side_validation && limit.nil?
    fail ArgumentError, "Missing the required parameter 'limit' when calling UsersApi.users_list_users"
  end
  # verify the required parameter 'next_token' is set
  if @api_client.config.client_side_validation && next_token.nil?
    fail ArgumentError, "Missing the required parameter 'next_token' when calling UsersApi.users_list_users"
  end
  # resource path
  local_var_path = '/users'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = limit
  query_params[:'nextToken'] = next_token
  query_params[:'envId'] = opts[:'env_id'] if !opts[:'env_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetUsersResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"UsersApi.users_list_users",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersApi#users_list_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#users_remove_user_from_suppression(user_id, channel, opts = {}) ⇒ UserSuppressionDeleteResponse

Remove user suppression status for a specific channel

Options Hash (opts):

  • :env_id (String) —

    Environment ID (required when using JWT auth)



164
165
166
167
# File 'lib/pingram/api/users_api.rb', line 164

def users_remove_user_from_suppression(user_id, channel, opts = {})
  data, _status_code, _headers = users_remove_user_from_suppression_with_http_info(user_id, channel, opts)
  data
end

#users_remove_user_from_suppression_with_http_info(user_id, channel, opts = {}) ⇒ Array<(UserSuppressionDeleteResponse, Integer, Hash)>

Remove user suppression status for a specific channel

Options Hash (opts):

  • :env_id (String) —

    Environment ID (required when using JWT auth)



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/pingram/api/users_api.rb', line 175

def users_remove_user_from_suppression_with_http_info(user_id, channel, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersApi.users_remove_user_from_suppression ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersApi.users_remove_user_from_suppression"
  end
  # verify the required parameter 'channel' is set
  if @api_client.config.client_side_validation && channel.nil?
    fail ArgumentError, "Missing the required parameter 'channel' when calling UsersApi.users_remove_user_from_suppression"
  end
  # resource path
  local_var_path = '/user_suppression/{userId}/channel/{channel}'.sub('{' + 'userId' + '}', CGI.escape(user_id.to_s)).sub('{' + 'channel' + '}', CGI.escape(channel.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'envId'] = opts[:'env_id'] if !opts[:'env_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserSuppressionDeleteResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"UsersApi.users_remove_user_from_suppression",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersApi#users_remove_user_from_suppression\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end