Class: Pingram::WebhooksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pingram/api/webhooks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ WebhooksApi

Returns a new instance of WebhooksApi.



19
20
21
# File 'lib/pingram/api/webhooks_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/pingram/api/webhooks_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#webhooks_create_webhook(webhook_endpoint_upsert_request, opts = {}) ⇒ WebhookEndpoint

Create a webhook.

Parameters:

Returns:



26
27
28
29
# File 'lib/pingram/api/webhooks_api.rb', line 26

def webhooks_create_webhook(webhook_endpoint_upsert_request, opts = {})
  data, _status_code, _headers = webhooks_create_webhook_with_http_info(webhook_endpoint_upsert_request, opts)
  data
end

#webhooks_create_webhook_with_http_info(webhook_endpoint_upsert_request, opts = {}) ⇒ Array<(WebhookEndpoint, Integer, Hash)>

Create a webhook.

Parameters:

Returns:

  • (Array<(WebhookEndpoint, Integer, Hash)>) —

    WebhookEndpoint data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pingram/api/webhooks_api.rb', line 35

def webhooks_create_webhook_with_http_info(webhook_endpoint_upsert_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_create_webhook ...'
  end
  # verify the required parameter 'webhook_endpoint_upsert_request' is set
  if @api_client.config.client_side_validation && webhook_endpoint_upsert_request.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_endpoint_upsert_request' when calling WebhooksApi.webhooks_create_webhook"
  end
  # resource path
  local_var_path = '/webhooks'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_endpoint_upsert_request)

  # return_type
  return_type = opts[:debug_return_type] || 'WebhookEndpoint'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"WebhooksApi.webhooks_create_webhook",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#webhooks_create_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#webhooks_delete_webhook(endpoint_id, opts = {}) ⇒ nil

Delete a webhook.

Parameters:

  • endpoint_id (String) —

    Webhook endpoint id

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (nil)


92
93
94
95
# File 'lib/pingram/api/webhooks_api.rb', line 92

def webhooks_delete_webhook(endpoint_id, opts = {})
  webhooks_delete_webhook_with_http_info(endpoint_id, opts)
  nil
end

#webhooks_delete_webhook_with_http_info(endpoint_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a webhook.

Parameters:

  • endpoint_id (String) —

    Webhook endpoint id

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>) —

    nil, response status code and response headers



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/pingram/api/webhooks_api.rb', line 101

def webhooks_delete_webhook_with_http_info(endpoint_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_delete_webhook ...'
  end
  # verify the required parameter 'endpoint_id' is set
  if @api_client.config.client_side_validation && endpoint_id.nil?
    fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WebhooksApi.webhooks_delete_webhook"
  end
  # resource path
  local_var_path = '/webhooks/{endpointId}'.sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"WebhooksApi.webhooks_delete_webhook",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#webhooks_delete_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#webhooks_list_webhooks(opts = {}) ⇒ WebhookEndpointsResponse

List webhooks for the current account.

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:



152
153
154
155
# File 'lib/pingram/api/webhooks_api.rb', line 152

def webhooks_list_webhooks(opts = {})
  data, _status_code, _headers = webhooks_list_webhooks_with_http_info(opts)
  data
end

#webhooks_list_webhooks_with_http_info(opts = {}) ⇒ Array<(WebhookEndpointsResponse, Integer, Hash)>

List webhooks for the current account.

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(WebhookEndpointsResponse, Integer, Hash)>) —

    WebhookEndpointsResponse data, response status code and response headers



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/pingram/api/webhooks_api.rb', line 160

def webhooks_list_webhooks_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_list_webhooks ...'
  end
  # resource path
  local_var_path = '/webhooks'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'WebhookEndpointsResponse'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"WebhooksApi.webhooks_list_webhooks",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#webhooks_list_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#webhooks_update_webhook(endpoint_id, webhook_endpoint_upsert_request, opts = {}) ⇒ WebhookEndpoint

Update a webhook. The signing secret is preserved.

Parameters:

  • endpoint_id (String) —

    Webhook endpoint id

  • webhook_endpoint_upsert_request (WebhookEndpointUpsertRequest)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:



209
210
211
212
# File 'lib/pingram/api/webhooks_api.rb', line 209

def webhooks_update_webhook(endpoint_id, webhook_endpoint_upsert_request, opts = {})
  data, _status_code, _headers = webhooks_update_webhook_with_http_info(endpoint_id, webhook_endpoint_upsert_request, opts)
  data
end

#webhooks_update_webhook_with_http_info(endpoint_id, webhook_endpoint_upsert_request, opts = {}) ⇒ Array<(WebhookEndpoint, Integer, Hash)>

Update a webhook. The signing secret is preserved.

Parameters:

  • endpoint_id (String) —

    Webhook endpoint id

  • webhook_endpoint_upsert_request (WebhookEndpointUpsertRequest)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(WebhookEndpoint, Integer, Hash)>) —

    WebhookEndpoint data, response status code and response headers



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/pingram/api/webhooks_api.rb', line 219

def webhooks_update_webhook_with_http_info(endpoint_id, webhook_endpoint_upsert_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_update_webhook ...'
  end
  # verify the required parameter 'endpoint_id' is set
  if @api_client.config.client_side_validation && endpoint_id.nil?
    fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling WebhooksApi.webhooks_update_webhook"
  end
  # verify the required parameter 'webhook_endpoint_upsert_request' is set
  if @api_client.config.client_side_validation && webhook_endpoint_upsert_request.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_endpoint_upsert_request' when calling WebhooksApi.webhooks_update_webhook"
  end
  # resource path
  local_var_path = '/webhooks/{endpointId}'.sub('{' + 'endpointId' + '}', CGI.escape(endpoint_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_endpoint_upsert_request)

  # return_type
  return_type = opts[:debug_return_type] || 'WebhookEndpoint'

  # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization)
  auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey']

  new_options = opts.merge(
    :operation => :"WebhooksApi.webhooks_update_webhook",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#webhooks_update_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end