Class: Pingram::AccountApi
- Inherits:
-
Object
- Object
- Pingram::AccountApi
- Defined in:
- lib/pingram/api/account_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#account_configure_supabase_smtp(supabase_configure_request, opts = {}) ⇒ SupabaseConfigureResponse
Configure SMTP settings for a Supabase project.
-
#account_configure_supabase_smtp_with_http_info(supabase_configure_request, opts = {}) ⇒ Array<(SupabaseConfigureResponse, Integer, Hash)>
Configure SMTP settings for a Supabase project.
-
#account_get_account_details(opts = {}) ⇒ AccountGetResponse
Get account information for the authenticated user.
-
#account_get_account_details_with_http_info(opts = {}) ⇒ Array<(AccountGetResponse, Integer, Hash)>
Get account information for the authenticated user.
-
#account_get_organization(opts = {}) ⇒ Organization
Get organization for the authenticated account (new billing model).
-
#account_get_organization_with_http_info(opts = {}) ⇒ Array<(Organization, Integer, Hash)>
Get organization for the authenticated account (new billing model).
-
#account_get_supabase_status(opts = {}) ⇒ SupabaseStatusResponse
Get Supabase integration status for the account.
-
#account_get_supabase_status_with_http_info(opts = {}) ⇒ Array<(SupabaseStatusResponse, Integer, Hash)>
Get Supabase integration status for the account.
-
#account_list_supabase_projects(opts = {}) ⇒ SupabaseProjectsResponse
List Supabase projects for the connected account.
-
#account_list_supabase_projects_with_http_info(opts = {}) ⇒ Array<(SupabaseProjectsResponse, Integer, Hash)>
List Supabase projects for the connected account.
-
#account_prepare_checkout_session(billing_post_request_body, opts = {}) ⇒ BillingPostResponseBody
Get or create Stripe customer and optionally create checkout session.
-
#account_prepare_checkout_session_with_http_info(billing_post_request_body, opts = {}) ⇒ Array<(BillingPostResponseBody, Integer, Hash)>
Get or create Stripe customer and optionally create checkout session.
-
#account_revoke_supabase(opts = {}) ⇒ SupabaseConfigureResponse
Revoke Supabase integration (removes stored tokens and project info).
-
#account_revoke_supabase_with_http_info(opts = {}) ⇒ Array<(SupabaseConfigureResponse, Integer, Hash)>
Revoke Supabase integration (removes stored tokens and project info).
-
#account_supabase_o_auth(supabase_o_auth_request, opts = {}) ⇒ SupabaseOAuthResponse
Exchange Supabase OAuth authorization code for tokens.
-
#account_supabase_o_auth_with_http_info(supabase_o_auth_request, opts = {}) ⇒ Array<(SupabaseOAuthResponse, Integer, Hash)>
Exchange Supabase OAuth authorization code for tokens.
-
#account_update_account(create_account_request_body, opts = {}) ⇒ CreateAccountResponse
Create or update an account name.
-
#account_update_account_with_http_info(create_account_request_body, opts = {}) ⇒ Array<(CreateAccountResponse, Integer, Hash)>
Create or update an account name.
-
#initialize(api_client = ApiClient.default) ⇒ AccountApi
constructor
A new instance of AccountApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AccountApi
Returns a new instance of AccountApi.
19 20 21 |
# File 'lib/pingram/api/account_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/account_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#account_configure_supabase_smtp(supabase_configure_request, opts = {}) ⇒ SupabaseConfigureResponse
Configure SMTP settings for a Supabase project
26 27 28 29 |
# File 'lib/pingram/api/account_api.rb', line 26 def account_configure_supabase_smtp(supabase_configure_request, opts = {}) data, _status_code, _headers = account_configure_supabase_smtp_with_http_info(supabase_configure_request, opts) data end |
#account_configure_supabase_smtp_with_http_info(supabase_configure_request, opts = {}) ⇒ Array<(SupabaseConfigureResponse, Integer, Hash)>
Configure SMTP settings for a Supabase project
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/account_api.rb', line 35 def account_configure_supabase_smtp_with_http_info(supabase_configure_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_configure_supabase_smtp ...' end # verify the required parameter 'supabase_configure_request' is set if @api_client.config.client_side_validation && supabase_configure_request.nil? fail ArgumentError, "Missing the required parameter 'supabase_configure_request' when calling AccountApi.account_configure_supabase_smtp" end # resource path local_var_path = '/account/supabase/configure' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(supabase_configure_request) # return_type return_type = opts[:debug_return_type] || 'SupabaseConfigureResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_configure_supabase_smtp", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_configure_supabase_smtp\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_get_account_details(opts = {}) ⇒ AccountGetResponse
Get account information for the authenticated user
91 92 93 94 |
# File 'lib/pingram/api/account_api.rb', line 91 def account_get_account_details(opts = {}) data, _status_code, _headers = account_get_account_details_with_http_info(opts) data end |
#account_get_account_details_with_http_info(opts = {}) ⇒ Array<(AccountGetResponse, Integer, Hash)>
Get account information for the authenticated user
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/api/account_api.rb', line 99 def account_get_account_details_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_get_account_details ...' end # resource path local_var_path = '/account' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AccountGetResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_get_account_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_get_account_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_get_organization(opts = {}) ⇒ Organization
Get organization for the authenticated account (new billing model).
146 147 148 149 |
# File 'lib/pingram/api/account_api.rb', line 146 def account_get_organization(opts = {}) data, _status_code, _headers = account_get_organization_with_http_info(opts) data end |
#account_get_organization_with_http_info(opts = {}) ⇒ Array<(Organization, Integer, Hash)>
Get organization for the authenticated account (new billing model).
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/pingram/api/account_api.rb', line 154 def account_get_organization_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_get_organization ...' end # resource path local_var_path = '/account/organization' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Organization' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_get_organization", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_get_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_get_supabase_status(opts = {}) ⇒ SupabaseStatusResponse
Get Supabase integration status for the account
201 202 203 204 |
# File 'lib/pingram/api/account_api.rb', line 201 def account_get_supabase_status(opts = {}) data, _status_code, _headers = account_get_supabase_status_with_http_info(opts) data end |
#account_get_supabase_status_with_http_info(opts = {}) ⇒ Array<(SupabaseStatusResponse, Integer, Hash)>
Get Supabase integration status for the account
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/pingram/api/account_api.rb', line 209 def account_get_supabase_status_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_get_supabase_status ...' end # resource path local_var_path = '/account/supabase/status' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SupabaseStatusResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_get_supabase_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_get_supabase_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_list_supabase_projects(opts = {}) ⇒ SupabaseProjectsResponse
List Supabase projects for the connected account
256 257 258 259 |
# File 'lib/pingram/api/account_api.rb', line 256 def account_list_supabase_projects(opts = {}) data, _status_code, _headers = account_list_supabase_projects_with_http_info(opts) data end |
#account_list_supabase_projects_with_http_info(opts = {}) ⇒ Array<(SupabaseProjectsResponse, Integer, Hash)>
List Supabase projects for the connected account
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/pingram/api/account_api.rb', line 264 def account_list_supabase_projects_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_list_supabase_projects ...' end # resource path local_var_path = '/account/supabase/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SupabaseProjectsResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_list_supabase_projects", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_list_supabase_projects\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_prepare_checkout_session(billing_post_request_body, opts = {}) ⇒ BillingPostResponseBody
Get or create Stripe customer and optionally create checkout session
312 313 314 315 |
# File 'lib/pingram/api/account_api.rb', line 312 def account_prepare_checkout_session(billing_post_request_body, opts = {}) data, _status_code, _headers = account_prepare_checkout_session_with_http_info(billing_post_request_body, opts) data end |
#account_prepare_checkout_session_with_http_info(billing_post_request_body, opts = {}) ⇒ Array<(BillingPostResponseBody, Integer, Hash)>
Get or create Stripe customer and optionally create checkout session
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/pingram/api/account_api.rb', line 321 def account_prepare_checkout_session_with_http_info(billing_post_request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_prepare_checkout_session ...' end # verify the required parameter 'billing_post_request_body' is set if @api_client.config.client_side_validation && billing_post_request_body.nil? fail ArgumentError, "Missing the required parameter 'billing_post_request_body' when calling AccountApi.account_prepare_checkout_session" end # resource path local_var_path = '/billing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(billing_post_request_body) # return_type return_type = opts[:debug_return_type] || 'BillingPostResponseBody' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_prepare_checkout_session", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_prepare_checkout_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_revoke_supabase(opts = {}) ⇒ SupabaseConfigureResponse
Revoke Supabase integration (removes stored tokens and project info)
377 378 379 380 |
# File 'lib/pingram/api/account_api.rb', line 377 def account_revoke_supabase(opts = {}) data, _status_code, _headers = account_revoke_supabase_with_http_info(opts) data end |
#account_revoke_supabase_with_http_info(opts = {}) ⇒ Array<(SupabaseConfigureResponse, Integer, Hash)>
Revoke Supabase integration (removes stored tokens and project info)
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/pingram/api/account_api.rb', line 385 def account_revoke_supabase_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_revoke_supabase ...' end # resource path local_var_path = '/account/supabase' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SupabaseConfigureResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_revoke_supabase", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_revoke_supabase\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_supabase_o_auth(supabase_o_auth_request, opts = {}) ⇒ SupabaseOAuthResponse
Exchange Supabase OAuth authorization code for tokens
433 434 435 436 |
# File 'lib/pingram/api/account_api.rb', line 433 def account_supabase_o_auth(supabase_o_auth_request, opts = {}) data, _status_code, _headers = account_supabase_o_auth_with_http_info(supabase_o_auth_request, opts) data end |
#account_supabase_o_auth_with_http_info(supabase_o_auth_request, opts = {}) ⇒ Array<(SupabaseOAuthResponse, Integer, Hash)>
Exchange Supabase OAuth authorization code for tokens
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/pingram/api/account_api.rb', line 442 def account_supabase_o_auth_with_http_info(supabase_o_auth_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_supabase_o_auth ...' end # verify the required parameter 'supabase_o_auth_request' is set if @api_client.config.client_side_validation && supabase_o_auth_request.nil? fail ArgumentError, "Missing the required parameter 'supabase_o_auth_request' when calling AccountApi.account_supabase_o_auth" end # resource path local_var_path = '/account/supabase/oauth' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(supabase_o_auth_request) # return_type return_type = opts[:debug_return_type] || 'SupabaseOAuthResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_supabase_o_auth", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_supabase_o_auth\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#account_update_account(create_account_request_body, opts = {}) ⇒ CreateAccountResponse
Create or update an account name
499 500 501 502 |
# File 'lib/pingram/api/account_api.rb', line 499 def account_update_account(create_account_request_body, opts = {}) data, _status_code, _headers = account_update_account_with_http_info(create_account_request_body, opts) data end |
#account_update_account_with_http_info(create_account_request_body, opts = {}) ⇒ Array<(CreateAccountResponse, Integer, Hash)>
Create or update an account name
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 |
# File 'lib/pingram/api/account_api.rb', line 508 def account_update_account_with_http_info(create_account_request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.account_update_account ...' end # verify the required parameter 'create_account_request_body' is set if @api_client.config.client_side_validation && create_account_request_body.nil? fail ArgumentError, "Missing the required parameter 'create_account_request_body' when calling AccountApi.account_update_account" end # resource path local_var_path = '/account' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_account_request_body) # return_type return_type = opts[:debug_return_type] || 'CreateAccountResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"AccountApi.account_update_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#account_update_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |