Class: Pingram::AccountGetResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::AccountGetResponse
- Defined in:
- lib/pingram/models/account_get_response.rb
Overview
GET /account response: public plan fields for the authenticated account.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_type ⇒ Object
Returns the value of attribute account_type.
-
#allow_overage ⇒ Object
Returns the value of attribute allow_overage.
-
#anniversary_date ⇒ Object
ISO date (YYYY-MM-DD) when the billing cycle resets.
-
#billing_version ⇒ Object
When omitted, defaults to LATEST_BILLING_VERSION.
-
#call_cap ⇒ Object
Returns the value of attribute call_cap.
-
#cost_cap ⇒ Object
Returns the value of attribute cost_cap.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#creator ⇒ Object
Returns the value of attribute creator.
-
#messages_cap ⇒ Object
Returns the value of attribute messages_cap.
-
#name ⇒ Object
Returns the value of attribute name.
-
#sms_cap ⇒ Object
Returns the value of attribute sms_cap.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountGetResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountGetResponse
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pingram/models/account_get_response.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::AccountGetResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::AccountGetResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] else self.account_type = nil end if attributes.key?(:'creator') self.creator = attributes[:'creator'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'messages_cap') self. = attributes[:'messages_cap'] else self. = nil end if attributes.key?(:'cost_cap') self.cost_cap = attributes[:'cost_cap'] else self.cost_cap = nil end if attributes.key?(:'sms_cap') self.sms_cap = attributes[:'sms_cap'] end if attributes.key?(:'call_cap') self.call_cap = attributes[:'call_cap'] end if attributes.key?(:'billing_version') self.billing_version = attributes[:'billing_version'] end if attributes.key?(:'anniversary_date') self.anniversary_date = attributes[:'anniversary_date'] else self.anniversary_date = nil end if attributes.key?(:'allow_overage') self.allow_overage = attributes[:'allow_overage'] else self.allow_overage = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
19 20 21 |
# File 'lib/pingram/models/account_get_response.rb', line 19 def account_id @account_id end |
#account_type ⇒ Object
Returns the value of attribute account_type.
21 22 23 |
# File 'lib/pingram/models/account_get_response.rb', line 21 def account_type @account_type end |
#allow_overage ⇒ Object
Returns the value of attribute allow_overage.
41 42 43 |
# File 'lib/pingram/models/account_get_response.rb', line 41 def allow_overage @allow_overage end |
#anniversary_date ⇒ Object
ISO date (YYYY-MM-DD) when the billing cycle resets.
39 40 41 |
# File 'lib/pingram/models/account_get_response.rb', line 39 def anniversary_date @anniversary_date end |
#billing_version ⇒ Object
When omitted, defaults to LATEST_BILLING_VERSION.
36 37 38 |
# File 'lib/pingram/models/account_get_response.rb', line 36 def billing_version @billing_version end |
#call_cap ⇒ Object
Returns the value of attribute call_cap.
33 34 35 |
# File 'lib/pingram/models/account_get_response.rb', line 33 def call_cap @call_cap end |
#cost_cap ⇒ Object
Returns the value of attribute cost_cap.
29 30 31 |
# File 'lib/pingram/models/account_get_response.rb', line 29 def cost_cap @cost_cap end |
#created_at ⇒ Object
Returns the value of attribute created_at.
43 44 45 |
# File 'lib/pingram/models/account_get_response.rb', line 43 def created_at @created_at end |
#creator ⇒ Object
Returns the value of attribute creator.
23 24 25 |
# File 'lib/pingram/models/account_get_response.rb', line 23 def creator @creator end |
#messages_cap ⇒ Object
Returns the value of attribute messages_cap.
27 28 29 |
# File 'lib/pingram/models/account_get_response.rb', line 27 def @messages_cap end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/pingram/models/account_get_response.rb', line 25 def name @name end |
#sms_cap ⇒ Object
Returns the value of attribute sms_cap.
31 32 33 |
# File 'lib/pingram/models/account_get_response.rb', line 31 def sms_cap @sms_cap end |
#status ⇒ Object
Returns the value of attribute status.
47 48 49 |
# File 'lib/pingram/models/account_get_response.rb', line 47 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
45 46 47 |
# File 'lib/pingram/models/account_get_response.rb', line 45 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/pingram/models/account_get_response.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/pingram/models/account_get_response.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/pingram/models/account_get_response.rb', line 72 def self.attribute_map { :'account_id' => :'accountId', :'account_type' => :'accountType', :'creator' => :'creator', :'name' => :'name', :'messages_cap' => :'messagesCap', :'cost_cap' => :'costCap', :'sms_cap' => :'smsCap', :'call_cap' => :'callCap', :'billing_version' => :'billingVersion', :'anniversary_date' => :'anniversaryDate', :'allow_overage' => :'allowOverage', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/pingram/models/account_get_response.rb', line 413 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 |
# File 'lib/pingram/models/account_get_response.rb', line 122 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/pingram/models/account_get_response.rb', line 102 def self.openapi_types { :'account_id' => :'String', :'account_type' => :'String', :'creator' => :'String', :'name' => :'String', :'messages_cap' => :'Float', :'cost_cap' => :'Float', :'sms_cap' => :'Float', :'call_cap' => :'Float', :'billing_version' => :'Float', :'anniversary_date' => :'String', :'allow_overage' => :'Boolean', :'created_at' => :'String', :'updated_at' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/pingram/models/account_get_response.rb', line 379 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && account_type == o.account_type && creator == o.creator && name == o.name && == o. && cost_cap == o.cost_cap && sms_cap == o.sms_cap && call_cap == o.call_cap && billing_version == o.billing_version && anniversary_date == o.anniversary_date && allow_overage == o.allow_overage && created_at == o.created_at && updated_at == o.updated_at && status == o.status end |
#eql?(o) ⇒ Boolean
400 401 402 |
# File 'lib/pingram/models/account_get_response.rb', line 400 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
406 407 408 |
# File 'lib/pingram/models/account_get_response.rb', line 406 def hash [account_id, account_type, creator, name, , cost_cap, sms_cap, call_cap, billing_version, anniversary_date, allow_overage, created_at, updated_at, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/pingram/models/account_get_response.rb', line 218 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @account_type.nil? invalid_properties.push('invalid value for "account_type", account_type cannot be nil.') end if @messages_cap.nil? invalid_properties.push('invalid value for "messages_cap", messages_cap cannot be nil.') end if @cost_cap.nil? invalid_properties.push('invalid value for "cost_cap", cost_cap cannot be nil.') end if @anniversary_date.nil? invalid_properties.push('invalid value for "anniversary_date", anniversary_date cannot be nil.') end if @allow_overage.nil? invalid_properties.push('invalid value for "allow_overage", allow_overage cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/pingram/models/account_get_response.rb', line 435 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pingram/models/account_get_response.rb', line 258 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @account_type.nil? account_type_validator = EnumAttributeValidator.new('String', ["free", "paid"]) return false unless account_type_validator.valid?(@account_type) return false if @messages_cap.nil? return false if @cost_cap.nil? billing_version_validator = EnumAttributeValidator.new('Float', [1, 3]) return false unless billing_version_validator.valid?(@billing_version) return false if @anniversary_date.nil? return false if @allow_overage.nil? return false if @created_at.nil? return false if @updated_at.nil? status_validator = EnumAttributeValidator.new('String', ["verified", "unverified", "blocked"]) return false unless status_validator.valid?(@status) true end |