Class: Pingram::AccountGetResponse

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/account_get_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountGetResponse

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/pingram/models/account_get_response.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::AccountGetResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::AccountGetResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  else
    self. = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'stripe_customer_id')
    self.stripe_customer_id = attributes[:'stripe_customer_id']
  end

  if attributes.key?(:'stripe_subscription_id')
    self.stripe_subscription_id = attributes[:'stripe_subscription_id']
  end

  if attributes.key?(:'subscription_status')
    self.subscription_status = attributes[:'subscription_status']
  end

  if attributes.key?(:'anniversary_date')
    self.anniversary_date = attributes[:'anniversary_date']
  end

  if attributes.key?(:'pending_downgrade_effective_date')
    self.pending_downgrade_effective_date = attributes[:'pending_downgrade_effective_date']
  end

  if attributes.key?(:'pending_downgrade_account_type')
    self. = attributes[:'pending_downgrade_account_type']
  end

  if attributes.key?(:'pending_downgrade_usage_limit')
    self.pending_downgrade_usage_limit = attributes[:'pending_downgrade_usage_limit']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/pingram/models/account_get_response.rb', line 18

def 
  @account_id
end

#account_typeObject

Returns the value of attribute account_type.



22
23
24
# File 'lib/pingram/models/account_get_response.rb', line 22

def 
  @account_type
end

#anniversary_dateObject

Returns the value of attribute anniversary_date.



32
33
34
# File 'lib/pingram/models/account_get_response.rb', line 32

def anniversary_date
  @anniversary_date
end

#created_atObject

Returns the value of attribute created_at.



24
25
26
# File 'lib/pingram/models/account_get_response.rb', line 24

def created_at
  @created_at
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pingram/models/account_get_response.rb', line 20

def name
  @name
end

#pending_downgrade_account_typeObject

Returns the value of attribute pending_downgrade_account_type.



36
37
38
# File 'lib/pingram/models/account_get_response.rb', line 36

def 
  @pending_downgrade_account_type
end

#pending_downgrade_effective_dateObject

Returns the value of attribute pending_downgrade_effective_date.



34
35
36
# File 'lib/pingram/models/account_get_response.rb', line 34

def pending_downgrade_effective_date
  @pending_downgrade_effective_date
end

#pending_downgrade_usage_limitObject

Returns the value of attribute pending_downgrade_usage_limit.



38
39
40
# File 'lib/pingram/models/account_get_response.rb', line 38

def pending_downgrade_usage_limit
  @pending_downgrade_usage_limit
end

#stripe_customer_idObject

Returns the value of attribute stripe_customer_id.



26
27
28
# File 'lib/pingram/models/account_get_response.rb', line 26

def stripe_customer_id
  @stripe_customer_id
end

#stripe_subscription_idObject

Returns the value of attribute stripe_subscription_id.



28
29
30
# File 'lib/pingram/models/account_get_response.rb', line 28

def stripe_subscription_id
  @stripe_subscription_id
end

#subscription_statusObject

Returns the value of attribute subscription_status.



30
31
32
# File 'lib/pingram/models/account_get_response.rb', line 30

def subscription_status
  @subscription_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/pingram/models/account_get_response.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/pingram/models/account_get_response.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/pingram/models/account_get_response.rb', line 63

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'account_type' => :'accountType',
    :'created_at' => :'createdAt',
    :'stripe_customer_id' => :'stripeCustomerId',
    :'stripe_subscription_id' => :'stripeSubscriptionId',
    :'subscription_status' => :'subscriptionStatus',
    :'anniversary_date' => :'anniversaryDate',
    :'pending_downgrade_effective_date' => :'pendingDowngradeEffectiveDate',
    :'pending_downgrade_account_type' => :'pendingDowngradeAccountType',
    :'pending_downgrade_usage_limit' => :'pendingDowngradeUsageLimit'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/pingram/models/account_get_response.rb', line 316

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
# File 'lib/pingram/models/account_get_response.rb', line 107

def self.openapi_nullable
  Set.new([
    :'subscription_status',
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/pingram/models/account_get_response.rb', line 90

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'account_type' => :'String',
    :'created_at' => :'String',
    :'stripe_customer_id' => :'String',
    :'stripe_subscription_id' => :'String',
    :'subscription_status' => :'String',
    :'anniversary_date' => :'String',
    :'pending_downgrade_effective_date' => :'String',
    :'pending_downgrade_account_type' => :'String',
    :'pending_downgrade_usage_limit' => :'AccountGetResponsePendingDowngradeUsageLimit'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/pingram/models/account_get_response.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
       == o. &&
      created_at == o.created_at &&
      stripe_customer_id == o.stripe_customer_id &&
      stripe_subscription_id == o.stripe_subscription_id &&
      subscription_status == o.subscription_status &&
      anniversary_date == o.anniversary_date &&
      pending_downgrade_effective_date == o.pending_downgrade_effective_date &&
       == o. &&
      pending_downgrade_usage_limit == o.pending_downgrade_usage_limit
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


303
304
305
# File 'lib/pingram/models/account_get_response.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



309
310
311
# File 'lib/pingram/models/account_get_response.rb', line 309

def hash
  [, name, , created_at, stripe_customer_id, stripe_subscription_id, subscription_status, anniversary_date, pending_downgrade_effective_date, , pending_downgrade_usage_limit].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/pingram/models/account_get_response.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @account_type.nil?
    invalid_properties.push('invalid value for "account_type", account_type cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/pingram/models/account_get_response.rb', line 338

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/pingram/models/account_get_response.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @account_type.nil?
   = EnumAttributeValidator.new('String', ["free", "paid"])
  return false unless .valid?(@account_type)
  return false if @created_at.nil?
  subscription_status_validator = EnumAttributeValidator.new('String', ["active", "canceled", "past_due", "paused"])
  return false unless subscription_status_validator.valid?(@subscription_status)
   = EnumAttributeValidator.new('String', ["free"])
  return false unless .valid?(@pending_downgrade_account_type)
  true
end