Class: Pingram::BillingPostRequestBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::BillingPostRequestBody
- Defined in:
- lib/pingram/models/billing_post_request_body.rb
Instance Attribute Summary collapse
-
#budget_price_id ⇒ Object
Price ID for the budget tier (SMS, CALL).
-
#cancel_url ⇒ Object
Returns the value of attribute cancel_url.
-
#message_price_id ⇒ Object
Price ID for the message tier (EMAIL, INAPP_WEB, WEB_PUSH, PUSH, SLACK).
-
#success_url ⇒ Object
Returns the value of attribute success_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BillingPostRequestBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BillingPostRequestBody
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::BillingPostRequestBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::BillingPostRequestBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message_price_id') self. = attributes[:'message_price_id'] end if attributes.key?(:'budget_price_id') self.budget_price_id = attributes[:'budget_price_id'] end if attributes.key?(:'success_url') self.success_url = attributes[:'success_url'] else self.success_url = nil end if attributes.key?(:'cancel_url') self.cancel_url = attributes[:'cancel_url'] else self.cancel_url = nil end end |
Instance Attribute Details
#budget_price_id ⇒ Object
Price ID for the budget tier (SMS, CALL)
22 23 24 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 22 def budget_price_id @budget_price_id end |
#cancel_url ⇒ Object
Returns the value of attribute cancel_url.
26 27 28 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 26 def cancel_url @cancel_url end |
#message_price_id ⇒ Object
Price ID for the message tier (EMAIL, INAPP_WEB, WEB_PUSH, PUSH, SLACK)
19 20 21 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 19 def end |
#success_url ⇒ Object
Returns the value of attribute success_url.
24 25 26 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 24 def success_url @success_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 29 def self.attribute_map { :'message_price_id' => :'messagePriceId', :'budget_price_id' => :'budgetPriceId', :'success_url' => :'successUrl', :'cancel_url' => :'cancelUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 49 def self.openapi_types { :'message_price_id' => :'String', :'budget_price_id' => :'String', :'success_url' => :'String', :'cancel_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && budget_price_id == o.budget_price_id && success_url == o.success_url && cancel_url == o.cancel_url end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 165 def hash [, budget_price_id, success_url, cancel_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @success_url.nil? invalid_properties.push('invalid value for "success_url", success_url cannot be nil.') end if @cancel_url.nil? invalid_properties.push('invalid value for "cancel_url", cancel_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 123 124 |
# File 'lib/pingram/models/billing_post_request_body.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @success_url.nil? return false if @cancel_url.nil? true end |