Class: Pingram::BillingPostResponseBody

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/billing_post_response_body.rb

Overview

POST /billing response: account + merged usage limits (when present) + optional session.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BillingPostResponseBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/pingram/models/billing_post_response_body.rb', line 171

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::BillingPostResponseBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::BillingPostResponseBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'organization_type')
    self.organization_type = attributes[:'organization_type']
  else
    self.organization_type = nil
  end

  if attributes.key?(:'creator')
    self.creator = attributes[:'creator']
  else
    self.creator = nil
  end

  if attributes.key?(:'messages_cap')
    self.messages_cap = attributes[:'messages_cap']
  else
    self.messages_cap = nil
  end

  if attributes.key?(:'cost_cap')
    self.cost_cap = attributes[:'cost_cap']
  else
    self.cost_cap = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'anniversary_date')
    self.anniversary_date = attributes[:'anniversary_date']
  else
    self.anniversary_date = nil
  end

  if attributes.key?(:'allow_overage')
    self.allow_overage = attributes[:'allow_overage']
  else
    self.allow_overage = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'sms_cap')
    self.sms_cap = attributes[:'sms_cap']
  end

  if attributes.key?(:'call_cap')
    self.call_cap = attributes[:'call_cap']
  end

  if attributes.key?(:'stripe_customer_id')
    self.stripe_customer_id = attributes[:'stripe_customer_id']
  end

  if attributes.key?(:'stripe_subscription_id')
    self.stripe_subscription_id = attributes[:'stripe_subscription_id']
  end

  if attributes.key?(:'subscription_status')
    self.subscription_status = attributes[:'subscription_status']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'pending_downgrade_cost_cap')
    self.pending_downgrade_cost_cap = attributes[:'pending_downgrade_cost_cap']
  end

  if attributes.key?(:'pending_downgrade_messages_cap')
    self.pending_downgrade_messages_cap = attributes[:'pending_downgrade_messages_cap']
  end

  if attributes.key?(:'pending_downgrade_sms_cap')
    self.pending_downgrade_sms_cap = attributes[:'pending_downgrade_sms_cap']
  end

  if attributes.key?(:'pending_downgrade_call_cap')
    self.pending_downgrade_call_cap = attributes[:'pending_downgrade_call_cap']
  end

  if attributes.key?(:'pending_downgrade_effective_date')
    self.pending_downgrade_effective_date = attributes[:'pending_downgrade_effective_date']
  end

  if attributes.key?(:'pending_downgrade_account_type')
    self. = attributes[:'pending_downgrade_account_type']
  end

  if attributes.key?(:'session_id')
    self.session_id = attributes[:'session_id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end
end

Instance Attribute Details

#allow_overageObject

Returns the value of attribute allow_overage.



36
37
38
# File 'lib/pingram/models/billing_post_response_body.rb', line 36

def allow_overage
  @allow_overage
end

#anniversary_dateObject

ISO date (YYYY-MM-DD) when the billing cycle resets.



34
35
36
# File 'lib/pingram/models/billing_post_response_body.rb', line 34

def anniversary_date
  @anniversary_date
end

#call_capObject

Returns the value of attribute call_cap.



42
43
44
# File 'lib/pingram/models/billing_post_response_body.rb', line 42

def call_cap
  @call_cap
end

#cost_capObject

Returns the value of attribute cost_cap.



27
28
29
# File 'lib/pingram/models/billing_post_response_body.rb', line 27

def cost_cap
  @cost_cap
end

#created_atObject

Returns the value of attribute created_at.



29
30
31
# File 'lib/pingram/models/billing_post_response_body.rb', line 29

def created_at
  @created_at
end

#creatorObject

Returns the value of attribute creator.



23
24
25
# File 'lib/pingram/models/billing_post_response_body.rb', line 23

def creator
  @creator
end

#messages_capObject

Returns the value of attribute messages_cap.



25
26
27
# File 'lib/pingram/models/billing_post_response_body.rb', line 25

def messages_cap
  @messages_cap
end

#nameObject

Returns the value of attribute name.



38
39
40
# File 'lib/pingram/models/billing_post_response_body.rb', line 38

def name
  @name
end

#organization_idObject

Returns the value of attribute organization_id.



19
20
21
# File 'lib/pingram/models/billing_post_response_body.rb', line 19

def organization_id
  @organization_id
end

#organization_typeObject

Returns the value of attribute organization_type.



21
22
23
# File 'lib/pingram/models/billing_post_response_body.rb', line 21

def organization_type
  @organization_type
end

#pending_downgrade_account_typeObject

Returns the value of attribute pending_downgrade_account_type.



64
65
66
# File 'lib/pingram/models/billing_post_response_body.rb', line 64

def 
  
end

#pending_downgrade_call_capObject

Returns the value of attribute pending_downgrade_call_cap.



60
61
62
# File 'lib/pingram/models/billing_post_response_body.rb', line 60

def pending_downgrade_call_cap
  @pending_downgrade_call_cap
end

#pending_downgrade_cost_capObject

Returns the value of attribute pending_downgrade_cost_cap.



54
55
56
# File 'lib/pingram/models/billing_post_response_body.rb', line 54

def pending_downgrade_cost_cap
  @pending_downgrade_cost_cap
end

#pending_downgrade_effective_dateObject

Returns the value of attribute pending_downgrade_effective_date.



62
63
64
# File 'lib/pingram/models/billing_post_response_body.rb', line 62

def pending_downgrade_effective_date
  @pending_downgrade_effective_date
end

#pending_downgrade_messages_capObject

Returns the value of attribute pending_downgrade_messages_cap.



56
57
58
# File 'lib/pingram/models/billing_post_response_body.rb', line 56

def pending_downgrade_messages_cap
  @pending_downgrade_messages_cap
end

#pending_downgrade_sms_capObject

Returns the value of attribute pending_downgrade_sms_cap.



58
59
60
# File 'lib/pingram/models/billing_post_response_body.rb', line 58

def pending_downgrade_sms_cap
  @pending_downgrade_sms_cap
end

#session_idObject

Returns the value of attribute session_id.



66
67
68
# File 'lib/pingram/models/billing_post_response_body.rb', line 66

def session_id
  @session_id
end

#sms_capObject

Returns the value of attribute sms_cap.



40
41
42
# File 'lib/pingram/models/billing_post_response_body.rb', line 40

def sms_cap
  @sms_cap
end

#statusObject

Verification status; internalCap applies when not ‘verified’.



52
53
54
# File 'lib/pingram/models/billing_post_response_body.rb', line 52

def status
  @status
end

#stripe_customer_idObject

Stripe subscription ID.



45
46
47
# File 'lib/pingram/models/billing_post_response_body.rb', line 45

def stripe_customer_id
  @stripe_customer_id
end

#stripe_subscription_idObject

Returns the value of attribute stripe_subscription_id.



47
48
49
# File 'lib/pingram/models/billing_post_response_body.rb', line 47

def stripe_subscription_id
  @stripe_subscription_id
end

#subscription_statusObject

Returns the value of attribute subscription_status.



49
50
51
# File 'lib/pingram/models/billing_post_response_body.rb', line 49

def subscription_status
  @subscription_status
end

#updated_atObject

Returns the value of attribute updated_at.



31
32
33
# File 'lib/pingram/models/billing_post_response_body.rb', line 31

def updated_at
  @updated_at
end

#urlObject

Returns the value of attribute url.



68
69
70
# File 'lib/pingram/models/billing_post_response_body.rb', line 68

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



123
124
125
# File 'lib/pingram/models/billing_post_response_body.rb', line 123

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



128
129
130
# File 'lib/pingram/models/billing_post_response_body.rb', line 128

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/pingram/models/billing_post_response_body.rb', line 93

def self.attribute_map
  {
    :'organization_id' => :'organizationId',
    :'organization_type' => :'organizationType',
    :'creator' => :'creator',
    :'messages_cap' => :'messagesCap',
    :'cost_cap' => :'costCap',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'anniversary_date' => :'anniversaryDate',
    :'allow_overage' => :'allowOverage',
    :'name' => :'name',
    :'sms_cap' => :'smsCap',
    :'call_cap' => :'callCap',
    :'stripe_customer_id' => :'stripeCustomerId',
    :'stripe_subscription_id' => :'stripeSubscriptionId',
    :'subscription_status' => :'subscriptionStatus',
    :'status' => :'status',
    :'pending_downgrade_cost_cap' => :'pendingDowngradeCostCap',
    :'pending_downgrade_messages_cap' => :'pendingDowngradeMessagesCap',
    :'pending_downgrade_sms_cap' => :'pendingDowngradeSmsCap',
    :'pending_downgrade_call_cap' => :'pendingDowngradeCallCap',
    :'pending_downgrade_effective_date' => :'pendingDowngradeEffectiveDate',
    :'pending_downgrade_account_type' => :'pendingDowngradeAccountType',
    :'session_id' => :'sessionId',
    :'url' => :'url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/pingram/models/billing_post_response_body.rb', line 551

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



163
164
165
166
167
# File 'lib/pingram/models/billing_post_response_body.rb', line 163

def self.openapi_nullable
  Set.new([
    :'subscription_status',
  ])
end

.openapi_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pingram/models/billing_post_response_body.rb', line 133

def self.openapi_types
  {
    :'organization_id' => :'String',
    :'organization_type' => :'String',
    :'creator' => :'String',
    :'messages_cap' => :'Float',
    :'cost_cap' => :'Float',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'anniversary_date' => :'String',
    :'allow_overage' => :'Boolean',
    :'name' => :'String',
    :'sms_cap' => :'Float',
    :'call_cap' => :'Float',
    :'stripe_customer_id' => :'String',
    :'stripe_subscription_id' => :'String',
    :'subscription_status' => :'String',
    :'status' => :'String',
    :'pending_downgrade_cost_cap' => :'Float',
    :'pending_downgrade_messages_cap' => :'Float',
    :'pending_downgrade_sms_cap' => :'Float',
    :'pending_downgrade_call_cap' => :'Float',
    :'pending_downgrade_effective_date' => :'String',
    :'pending_downgrade_account_type' => :'String',
    :'session_id' => :'String',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/pingram/models/billing_post_response_body.rb', line 507

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      organization_id == o.organization_id &&
      organization_type == o.organization_type &&
      creator == o.creator &&
      messages_cap == o.messages_cap &&
      cost_cap == o.cost_cap &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      anniversary_date == o.anniversary_date &&
      allow_overage == o.allow_overage &&
      name == o.name &&
      sms_cap == o.sms_cap &&
      call_cap == o.call_cap &&
      stripe_customer_id == o.stripe_customer_id &&
      stripe_subscription_id == o.stripe_subscription_id &&
      subscription_status == o.subscription_status &&
      status == o.status &&
      pending_downgrade_cost_cap == o.pending_downgrade_cost_cap &&
      pending_downgrade_messages_cap == o.pending_downgrade_messages_cap &&
      pending_downgrade_sms_cap == o.pending_downgrade_sms_cap &&
      pending_downgrade_call_cap == o.pending_downgrade_call_cap &&
      pending_downgrade_effective_date == o.pending_downgrade_effective_date &&
       == o. &&
      session_id == o.session_id &&
      url == o.url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


538
539
540
# File 'lib/pingram/models/billing_post_response_body.rb', line 538

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



544
545
546
# File 'lib/pingram/models/billing_post_response_body.rb', line 544

def hash
  [organization_id, organization_type, creator, messages_cap, cost_cap, created_at, updated_at, anniversary_date, allow_overage, name, sms_cap, call_cap, stripe_customer_id, stripe_subscription_id, subscription_status, status, pending_downgrade_cost_cap, pending_downgrade_messages_cap, pending_downgrade_sms_cap, pending_downgrade_call_cap, pending_downgrade_effective_date, , session_id, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/pingram/models/billing_post_response_body.rb', line 304

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  if @organization_type.nil?
    invalid_properties.push('invalid value for "organization_type", organization_type cannot be nil.')
  end

  if @creator.nil?
    invalid_properties.push('invalid value for "creator", creator cannot be nil.')
  end

  if @messages_cap.nil?
    invalid_properties.push('invalid value for "messages_cap", messages_cap cannot be nil.')
  end

  if @cost_cap.nil?
    invalid_properties.push('invalid value for "cost_cap", cost_cap cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @anniversary_date.nil?
    invalid_properties.push('invalid value for "anniversary_date", anniversary_date cannot be nil.')
  end

  if @allow_overage.nil?
    invalid_properties.push('invalid value for "allow_overage", allow_overage cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/pingram/models/billing_post_response_body.rb', line 573

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/pingram/models/billing_post_response_body.rb', line 352

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @organization_id.nil?
  return false if @organization_type.nil?
  organization_type_validator = EnumAttributeValidator.new('String', ["free", "paid"])
  return false unless organization_type_validator.valid?(@organization_type)
  return false if @creator.nil?
  return false if @messages_cap.nil?
  return false if @cost_cap.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @anniversary_date.nil?
  return false if @allow_overage.nil?
  return false if @name.nil?
  subscription_status_validator = EnumAttributeValidator.new('String', ["active", "canceled", "past_due", "paused"])
  return false unless subscription_status_validator.valid?(@subscription_status)
  status_validator = EnumAttributeValidator.new('String', ["verified", "unverified", "blocked"])
  return false unless status_validator.valid?(@status)
   = EnumAttributeValidator.new('String', ["free"])
  return false unless .valid?()
  true
end