Class: Pingram::CreateKeyResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::CreateKeyResponse
- Defined in:
- lib/pingram/models/create_key_response.rb
Overview
Response body for POST /keys endpoint Returns the newly created API key (only time the full key is returned)
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
ISO 8601 timestamp when the key was created.
-
#environment_id ⇒ Object
Environment ID if the key is scoped to a specific environment.
-
#id ⇒ Object
Unique identifier for the key (jti).
-
#key ⇒ Object
The full API key string - ONLY returned on creation, never shown again.
-
#key_type ⇒ Object
Type of API key that was created.
-
#name ⇒ Object
Human-readable name/description for the key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateKeyResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateKeyResponse
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/pingram/models/create_key_response.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::CreateKeyResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::CreateKeyResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'key_type') self.key_type = attributes[:'key_type'] else self.key_type = nil end if attributes.key?(:'environment_id') self.environment_id = attributes[:'environment_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
ISO 8601 timestamp when the key was created
35 36 37 |
# File 'lib/pingram/models/create_key_response.rb', line 35 def created_at @created_at end |
#environment_id ⇒ Object
Environment ID if the key is scoped to a specific environment
29 30 31 |
# File 'lib/pingram/models/create_key_response.rb', line 29 def environment_id @environment_id end |
#id ⇒ Object
Unique identifier for the key (jti)
20 21 22 |
# File 'lib/pingram/models/create_key_response.rb', line 20 def id @id end |
#key ⇒ Object
The full API key string - ONLY returned on creation, never shown again
23 24 25 |
# File 'lib/pingram/models/create_key_response.rb', line 23 def key @key end |
#key_type ⇒ Object
Type of API key that was created
26 27 28 |
# File 'lib/pingram/models/create_key_response.rb', line 26 def key_type @key_type end |
#name ⇒ Object
Human-readable name/description for the key
32 33 34 |
# File 'lib/pingram/models/create_key_response.rb', line 32 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/pingram/models/create_key_response.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/pingram/models/create_key_response.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/pingram/models/create_key_response.rb', line 60 def self.attribute_map { :'id' => :'id', :'key' => :'key', :'key_type' => :'keyType', :'environment_id' => :'environmentId', :'name' => :'name', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/pingram/models/create_key_response.rb', line 270 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/pingram/models/create_key_response.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/pingram/models/create_key_response.rb', line 82 def self.openapi_types { :'id' => :'String', :'key' => :'String', :'key_type' => :'String', :'environment_id' => :'String', :'name' => :'String', :'created_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/pingram/models/create_key_response.rb', line 244 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && key == o.key && key_type == o.key_type && environment_id == o.environment_id && name == o.name && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/pingram/models/create_key_response.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/pingram/models/create_key_response.rb', line 263 def hash [id, key, key_type, environment_id, name, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/pingram/models/create_key_response.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @key_type.nil? invalid_properties.push('invalid value for "key_type", key_type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/pingram/models/create_key_response.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/pingram/models/create_key_response.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @key.nil? return false if @key_type.nil? key_type_validator = EnumAttributeValidator.new('String', ["secret", "public"]) return false unless key_type_validator.valid?(@key_type) return false if @name.nil? return false if @created_at.nil? true end |