Class: Pingram::DomainDnsCheckRecordsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::DomainDnsCheckRecordsInner
- Defined in:
- lib/pingram/models/domain_dns_check_records_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#expected ⇒ Object
Returns the value of attribute expected.
-
#found ⇒ Object
Returns the value of attribute found.
-
#host ⇒ Object
Returns the value of attribute host.
-
#id ⇒ Object
Returns the value of attribute id.
-
#label ⇒ Object
Returns the value of attribute label.
-
#observed ⇒ Object
Returns the value of attribute observed.
-
#record_type ⇒ Object
Returns the value of attribute record_type.
-
#required ⇒ Object
Returns the value of attribute required.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainDnsCheckRecordsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DomainDnsCheckRecordsInner
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::DomainDnsCheckRecordsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::DomainDnsCheckRecordsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'required') self.required = attributes[:'required'] else self.required = nil end if attributes.key?(:'found') self.found = attributes[:'found'] else self.found = nil end if attributes.key?(:'host') self.host = attributes[:'host'] else self.host = nil end if attributes.key?(:'record_type') self.record_type = attributes[:'record_type'] else self.record_type = nil end if attributes.key?(:'expected') self.expected = attributes[:'expected'] else self.expected = nil end if attributes.key?(:'observed') if (value = attributes[:'observed']).is_a?(Array) self.observed = value end end end |
Instance Attribute Details
#expected ⇒ Object
Returns the value of attribute expected.
30 31 32 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 30 def expected @expected end |
#found ⇒ Object
Returns the value of attribute found.
24 25 26 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 24 def found @found end |
#host ⇒ Object
Returns the value of attribute host.
26 27 28 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 26 def host @host end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 18 def id @id end |
#label ⇒ Object
Returns the value of attribute label.
20 21 22 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 20 def label @label end |
#observed ⇒ Object
Returns the value of attribute observed.
32 33 34 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 32 def observed @observed end |
#record_type ⇒ Object
Returns the value of attribute record_type.
28 29 30 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 28 def record_type @record_type end |
#required ⇒ Object
Returns the value of attribute required.
22 23 24 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 22 def required @required end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 57 def self.attribute_map { :'id' => :'id', :'label' => :'label', :'required' => :'required', :'found' => :'found', :'host' => :'host', :'record_type' => :'recordType', :'expected' => :'expected', :'observed' => :'observed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 319 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 81 def self.openapi_types { :'id' => :'String', :'label' => :'String', :'required' => :'Boolean', :'found' => :'Boolean', :'host' => :'String', :'record_type' => :'String', :'expected' => :'String', :'observed' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && label == o.label && required == o.required && found == o.found && host == o.host && record_type == o.record_type && expected == o.expected && observed == o.observed end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 312 def hash [id, label, required, found, host, record_type, expected, observed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end if @required.nil? invalid_properties.push('invalid value for "required", required cannot be nil.') end if @found.nil? invalid_properties.push('invalid value for "found", found cannot be nil.') end if @host.nil? invalid_properties.push('invalid value for "host", host cannot be nil.') end if @record_type.nil? invalid_properties.push('invalid value for "record_type", record_type cannot be nil.') end if @expected.nil? invalid_properties.push('invalid value for "expected", expected cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 341 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/pingram/models/domain_dns_check_records_inner.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? id_validator = EnumAttributeValidator.new('String', ["dkim", "mail_from_spf", "mail_from_mx", "dmarc", "inbound_mx"]) return false unless id_validator.valid?(@id) return false if @label.nil? return false if @required.nil? return false if @found.nil? return false if @host.nil? return false if @record_type.nil? record_type_validator = EnumAttributeValidator.new('String', ["TXT", "MX", "CNAME"]) return false unless record_type_validator.valid?(@record_type) return false if @expected.nil? true end |