Class: Pingram::DomainsApi
- Inherits:
-
Object
- Object
- Pingram::DomainsApi
- Defined in:
- lib/pingram/api/domains_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#domains_add_domain(post_senders_request_body, opts = {}) ⇒ Array<GetSendersResponseInner>
Request to verify a new sender domain.
-
#domains_add_domain_with_http_info(post_senders_request_body, opts = {}) ⇒ Array<(Array<GetSendersResponseInner>, Integer, Hash)>
Request to verify a new sender domain.
-
#domains_delete_domain(sender, opts = {}) ⇒ SuccessResponse
Delete a sender domain or email address.
-
#domains_delete_domain_with_http_info(sender, opts = {}) ⇒ Array<(SuccessResponse, Integer, Hash)>
Delete a sender domain or email address.
-
#domains_list_domains(opts = {}) ⇒ Array<GetSendersResponseInner>
Get all sender domains configured for the account.
-
#domains_list_domains_with_http_info(opts = {}) ⇒ Array<(Array<GetSendersResponseInner>, Integer, Hash)>
Get all sender domains configured for the account.
-
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
constructor
A new instance of DomainsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
Returns a new instance of DomainsApi.
19 20 21 |
# File 'lib/pingram/api/domains_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/domains_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#domains_add_domain(post_senders_request_body, opts = {}) ⇒ Array<GetSendersResponseInner>
Request to verify a new sender domain
26 27 28 29 |
# File 'lib/pingram/api/domains_api.rb', line 26 def domains_add_domain(post_senders_request_body, opts = {}) data, _status_code, _headers = domains_add_domain_with_http_info(post_senders_request_body, opts) data end |
#domains_add_domain_with_http_info(post_senders_request_body, opts = {}) ⇒ Array<(Array<GetSendersResponseInner>, Integer, Hash)>
Request to verify a new sender domain
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/domains_api.rb', line 35 def domains_add_domain_with_http_info(post_senders_request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.domains_add_domain ...' end # verify the required parameter 'post_senders_request_body' is set if @api_client.config.client_side_validation && post_senders_request_body.nil? fail ArgumentError, "Missing the required parameter 'post_senders_request_body' when calling DomainsApi.domains_add_domain" end # resource path local_var_path = '/domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(post_senders_request_body) # return_type return_type = opts[:debug_return_type] || 'Array<GetSendersResponseInner>' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"DomainsApi.domains_add_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#domains_add_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#domains_delete_domain(sender, opts = {}) ⇒ SuccessResponse
Delete a sender domain or email address
92 93 94 95 |
# File 'lib/pingram/api/domains_api.rb', line 92 def domains_delete_domain(sender, opts = {}) data, _status_code, _headers = domains_delete_domain_with_http_info(sender, opts) data end |
#domains_delete_domain_with_http_info(sender, opts = {}) ⇒ Array<(SuccessResponse, Integer, Hash)>
Delete a sender domain or email address
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/pingram/api/domains_api.rb', line 101 def domains_delete_domain_with_http_info(sender, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.domains_delete_domain ...' end # verify the required parameter 'sender' is set if @api_client.config.client_side_validation && sender.nil? fail ArgumentError, "Missing the required parameter 'sender' when calling DomainsApi.domains_delete_domain" end # resource path local_var_path = '/domains/{sender}'.sub('{' + 'sender' + '}', CGI.escape(sender.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SuccessResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"DomainsApi.domains_delete_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#domains_delete_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#domains_list_domains(opts = {}) ⇒ Array<GetSendersResponseInner>
Get all sender domains configured for the account
152 153 154 155 |
# File 'lib/pingram/api/domains_api.rb', line 152 def domains_list_domains(opts = {}) data, _status_code, _headers = domains_list_domains_with_http_info(opts) data end |
#domains_list_domains_with_http_info(opts = {}) ⇒ Array<(Array<GetSendersResponseInner>, Integer, Hash)>
Get all sender domains configured for the account
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/pingram/api/domains_api.rb', line 160 def domains_list_domains_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.domains_list_domains ...' end # resource path local_var_path = '/domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<GetSendersResponseInner>' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"DomainsApi.domains_list_domains", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#domains_list_domains\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |