Class: Pingram::EmailApi
- Inherits:
-
Object
- Object
- Pingram::EmailApi
- Defined in:
- lib/pingram/api/email_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#email_delete_suppressions(reason, opts = {}) ⇒ MessageResponse
Start removing all email suppressions of the given reason (
retryableorbounces) for users in the environment. -
#email_delete_suppressions_with_http_info(reason, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>
Start removing all email suppressions of the given reason (`retryable` or `bounces`) for users in the environment.
-
#email_send(send_email_request, opts = {}) ⇒ SendEmailApiResponse
Send an email.
-
#email_send_with_http_info(send_email_request, opts = {}) ⇒ Array<(SendEmailApiResponse, Integer, Hash)>
Send an email.
-
#initialize(api_client = ApiClient.default) ⇒ EmailApi
constructor
A new instance of EmailApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/email_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#email_delete_suppressions(reason, opts = {}) ⇒ MessageResponse
Start removing all email suppressions of the given reason (retryable or bounces) for users in the environment. Returns immediately after the job is queued — suppressions are not yet cleared when this response is received. Large removals are processed in the background in batches.
26 27 28 29 |
# File 'lib/pingram/api/email_api.rb', line 26 def email_delete_suppressions(reason, opts = {}) data, _status_code, _headers = email_delete_suppressions_with_http_info(reason, opts) data end |
#email_delete_suppressions_with_http_info(reason, opts = {}) ⇒ Array<(MessageResponse, Integer, Hash)>
Start removing all email suppressions of the given reason (`retryable` or `bounces`) for users in the environment. Returns immediately after the job is queued — suppressions are not yet cleared when this response is received. Large removals are processed in the background in batches.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/pingram/api/email_api.rb', line 35 def email_delete_suppressions_with_http_info(reason, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailApi.email_delete_suppressions ...' end # verify the required parameter 'reason' is set if @api_client.config.client_side_validation && reason.nil? fail ArgumentError, "Missing the required parameter 'reason' when calling EmailApi.email_delete_suppressions" end # resource path local_var_path = '/email/suppressions/{reason}'.sub('{' + 'reason' + '}', CGI.escape(reason.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MessageResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"EmailApi.email_delete_suppressions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailApi#email_delete_suppressions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#email_send(send_email_request, opts = {}) ⇒ SendEmailApiResponse
Send an email. Requires type, to, subject, and html. Optional: fromAddress, fromName, schedule, attachments. The fromAddress must be a verified domain; otherwise our built-in address will be used which is fine for testing purposes.
87 88 89 90 |
# File 'lib/pingram/api/email_api.rb', line 87 def email_send(send_email_request, opts = {}) data, _status_code, _headers = email_send_with_http_info(send_email_request, opts) data end |
#email_send_with_http_info(send_email_request, opts = {}) ⇒ Array<(SendEmailApiResponse, Integer, Hash)>
Send an email. Requires `type`, `to`, `subject`, and `html`. Optional: `fromAddress`, `fromName`, `schedule`, attachments. The fromAddress must be a verified domain; otherwise our built-in address will be used which is fine for testing purposes.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/pingram/api/email_api.rb', line 96 def email_send_with_http_info(send_email_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailApi.email_send ...' end # verify the required parameter 'send_email_request' is set if @api_client.config.client_side_validation && send_email_request.nil? fail ArgumentError, "Missing the required parameter 'send_email_request' when calling EmailApi.email_send" end # resource path local_var_path = '/email' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(send_email_request) # return_type return_type = opts[:debug_return_type] || 'SendEmailApiResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"EmailApi.email_send", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailApi#email_send\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |