Class: Pingram::EmailComponentResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::EmailComponentResponse
- Defined in:
- lib/pingram/models/email_component_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#component_id ⇒ Object
Returns the value of attribute component_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#env_id ⇒ Object
Returns the value of attribute env_id.
-
#html ⇒ Object
Returns the value of attribute html.
-
#internal ⇒ Object
Returns the value of attribute internal.
-
#internal_page ⇒ Object
Returns the value of attribute internal_page.
-
#modified_at ⇒ Object
Returns the value of attribute modified_at.
-
#name ⇒ Object
Returns the value of attribute name.
-
#referenced_by ⇒ Object
Returns the value of attribute referenced_by.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmailComponentResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EmailComponentResponse
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/pingram/models/email_component_response.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::EmailComponentResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::EmailComponentResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'env_id') self.env_id = attributes[:'env_id'] else self.env_id = nil end if attributes.key?(:'component_id') self.component_id = attributes[:'component_id'] else self.component_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'internal') self.internal = attributes[:'internal'] else self.internal = nil end if attributes.key?(:'internal_page') self.internal_page = attributes[:'internal_page'] else self.internal_page = nil end if attributes.key?(:'html') self.html = attributes[:'html'] else self.html = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'modified_at') self.modified_at = attributes[:'modified_at'] else self.modified_at = nil end if attributes.key?(:'referenced_by') if (value = attributes[:'referenced_by']).is_a?(Array) self.referenced_by = value end else self.referenced_by = nil end if attributes.key?(:'channel') self.channel = attributes[:'channel'] else self.channel = nil end end |
Instance Attribute Details
#channel ⇒ Object
Returns the value of attribute channel.
36 37 38 |
# File 'lib/pingram/models/email_component_response.rb', line 36 def channel @channel end |
#component_id ⇒ Object
Returns the value of attribute component_id.
20 21 22 |
# File 'lib/pingram/models/email_component_response.rb', line 20 def component_id @component_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/pingram/models/email_component_response.rb', line 30 def created_at @created_at end |
#env_id ⇒ Object
Returns the value of attribute env_id.
18 19 20 |
# File 'lib/pingram/models/email_component_response.rb', line 18 def env_id @env_id end |
#html ⇒ Object
Returns the value of attribute html.
28 29 30 |
# File 'lib/pingram/models/email_component_response.rb', line 28 def html @html end |
#internal ⇒ Object
Returns the value of attribute internal.
24 25 26 |
# File 'lib/pingram/models/email_component_response.rb', line 24 def internal @internal end |
#internal_page ⇒ Object
Returns the value of attribute internal_page.
26 27 28 |
# File 'lib/pingram/models/email_component_response.rb', line 26 def internal_page @internal_page end |
#modified_at ⇒ Object
Returns the value of attribute modified_at.
32 33 34 |
# File 'lib/pingram/models/email_component_response.rb', line 32 def modified_at @modified_at end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/pingram/models/email_component_response.rb', line 22 def name @name end |
#referenced_by ⇒ Object
Returns the value of attribute referenced_by.
34 35 36 |
# File 'lib/pingram/models/email_component_response.rb', line 34 def referenced_by @referenced_by end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/pingram/models/email_component_response.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/pingram/models/email_component_response.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/pingram/models/email_component_response.rb', line 61 def self.attribute_map { :'env_id' => :'envId', :'component_id' => :'componentId', :'name' => :'name', :'internal' => :'internal', :'internal_page' => :'internalPage', :'html' => :'html', :'created_at' => :'createdAt', :'modified_at' => :'modifiedAt', :'referenced_by' => :'referencedBy', :'channel' => :'channel' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/pingram/models/email_component_response.rb', line 386 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/pingram/models/email_component_response.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/pingram/models/email_component_response.rb', line 87 def self.openapi_types { :'env_id' => :'String', :'component_id' => :'String', :'name' => :'String', :'internal' => :'String', :'internal_page' => :'String', :'html' => :'String', :'created_at' => :'String', :'modified_at' => :'String', :'referenced_by' => :'Array<EmailComponentResponseReferencedByInner>', :'channel' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/pingram/models/email_component_response.rb', line 356 def ==(o) return true if self.equal?(o) self.class == o.class && env_id == o.env_id && component_id == o.component_id && name == o.name && internal == o.internal && internal_page == o.internal_page && html == o.html && created_at == o.created_at && modified_at == o.modified_at && referenced_by == o.referenced_by && channel == o.channel end |
#eql?(o) ⇒ Boolean
373 374 375 |
# File 'lib/pingram/models/email_component_response.rb', line 373 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
379 380 381 |
# File 'lib/pingram/models/email_component_response.rb', line 379 def hash [env_id, component_id, name, internal, internal_page, html, created_at, modified_at, referenced_by, channel].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/pingram/models/email_component_response.rb', line 189 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @env_id.nil? invalid_properties.push('invalid value for "env_id", env_id cannot be nil.') end if @component_id.nil? invalid_properties.push('invalid value for "component_id", component_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @internal.nil? invalid_properties.push('invalid value for "internal", internal cannot be nil.') end if @internal_page.nil? invalid_properties.push('invalid value for "internal_page", internal_page cannot be nil.') end if @html.nil? invalid_properties.push('invalid value for "html", html cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @modified_at.nil? invalid_properties.push('invalid value for "modified_at", modified_at cannot be nil.') end if @referenced_by.nil? invalid_properties.push('invalid value for "referenced_by", referenced_by cannot be nil.') end if @channel.nil? invalid_properties.push('invalid value for "channel", channel cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/pingram/models/email_component_response.rb', line 408 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/pingram/models/email_component_response.rb', line 237 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @env_id.nil? return false if @component_id.nil? return false if @name.nil? return false if @internal.nil? return false if @internal_page.nil? return false if @html.nil? return false if @created_at.nil? return false if @modified_at.nil? return false if @referenced_by.nil? return false if @channel.nil? channel_validator = EnumAttributeValidator.new('String', ["EMAIL"]) return false unless channel_validator.valid?(@channel) true end |