Class: Pingram::EnvironmentsApi
- Inherits:
-
Object
- Object
- Pingram::EnvironmentsApi
- Defined in:
- lib/pingram/api/environments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#environments_list_environments(opts = {}) ⇒ Array<GetEnvironmentsResponseInner>
Get all environments for the authenticated account.
-
#environments_list_environments_with_http_info(opts = {}) ⇒ Array<(Array<GetEnvironmentsResponseInner>, Integer, Hash)>
Get all environments for the authenticated account.
-
#environments_update_environment(client_id, environment_patch_request, opts = {}) ⇒ Environment
Update environment settings (title, secret, disable sending, secure mode).
-
#environments_update_environment_with_http_info(client_id, environment_patch_request, opts = {}) ⇒ Array<(Environment, Integer, Hash)>
Update environment settings (title, secret, disable sending, secure mode).
-
#initialize(api_client = ApiClient.default) ⇒ EnvironmentsApi
constructor
A new instance of EnvironmentsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EnvironmentsApi
Returns a new instance of EnvironmentsApi.
19 20 21 |
# File 'lib/pingram/api/environments_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/environments_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#environments_list_environments(opts = {}) ⇒ Array<GetEnvironmentsResponseInner>
Get all environments for the authenticated account
25 26 27 28 |
# File 'lib/pingram/api/environments_api.rb', line 25 def environments_list_environments(opts = {}) data, _status_code, _headers = environments_list_environments_with_http_info(opts) data end |
#environments_list_environments_with_http_info(opts = {}) ⇒ Array<(Array<GetEnvironmentsResponseInner>, Integer, Hash)>
Get all environments for the authenticated account
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/pingram/api/environments_api.rb', line 33 def environments_list_environments_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.environments_list_environments ...' end # resource path local_var_path = '/environments' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<GetEnvironmentsResponseInner>' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"EnvironmentsApi.environments_list_environments", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#environments_list_environments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#environments_update_environment(client_id, environment_patch_request, opts = {}) ⇒ Environment
Update environment settings (title, secret, disable sending, secure mode)
82 83 84 85 |
# File 'lib/pingram/api/environments_api.rb', line 82 def environments_update_environment(client_id, environment_patch_request, opts = {}) data, _status_code, _headers = environments_update_environment_with_http_info(client_id, environment_patch_request, opts) data end |
#environments_update_environment_with_http_info(client_id, environment_patch_request, opts = {}) ⇒ Array<(Environment, Integer, Hash)>
Update environment settings (title, secret, disable sending, secure mode)
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/pingram/api/environments_api.rb', line 92 def environments_update_environment_with_http_info(client_id, environment_patch_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.environments_update_environment ...' end # verify the required parameter 'client_id' is set if @api_client.config.client_side_validation && client_id.nil? fail ArgumentError, "Missing the required parameter 'client_id' when calling EnvironmentsApi.environments_update_environment" end # verify the required parameter 'environment_patch_request' is set if @api_client.config.client_side_validation && environment_patch_request.nil? fail ArgumentError, "Missing the required parameter 'environment_patch_request' when calling EnvironmentsApi.environments_update_environment" end # resource path local_var_path = '/environments/{clientId}'.sub('{' + 'clientId' + '}', CGI.escape(client_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(environment_patch_request) # return_type return_type = opts[:debug_return_type] || 'Environment' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"EnvironmentsApi.environments_update_environment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#environments_update_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |