Class: Pingram::GetSendersResponseInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::GetSendersResponseInner
- Defined in:
- lib/pingram/models/get_senders_response_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#last_sync ⇒ Object
Returns the value of attribute last_sync.
-
#mail_from_domain_status ⇒ Object
Returns the value of attribute mail_from_domain_status.
-
#private_dkim_key ⇒ Object
Returns the value of attribute private_dkim_key.
-
#reminder_sent_at ⇒ Object
Returns the value of attribute reminder_sent_at.
-
#selector ⇒ Object
Returns the value of attribute selector.
-
#sender ⇒ Object
Returns the value of attribute sender.
-
#status ⇒ Object
Returns the value of attribute status.
-
#verification_records ⇒ Object
Returns the value of attribute verification_records.
-
#verification_tokens ⇒ Object
Returns the value of attribute verification_tokens.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetSendersResponseInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetSendersResponseInner
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetSendersResponseInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetSendersResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'sender') self.sender = attributes[:'sender'] else self.sender = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'last_sync') self.last_sync = attributes[:'last_sync'] else self.last_sync = nil end if attributes.key?(:'verification_tokens') if (value = attributes[:'verification_tokens']).is_a?(Array) self.verification_tokens = value end end if attributes.key?(:'mail_from_domain_status') self.mail_from_domain_status = attributes[:'mail_from_domain_status'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'private_dkim_key') self.private_dkim_key = attributes[:'private_dkim_key'] end if attributes.key?(:'reminder_sent_at') self.reminder_sent_at = attributes[:'reminder_sent_at'] end if attributes.key?(:'selector') self.selector = attributes[:'selector'] else self.selector = nil end if attributes.key?(:'verification_records') self.verification_records = attributes[:'verification_records'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
28 29 30 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 28 def created_at @created_at end |
#last_sync ⇒ Object
Returns the value of attribute last_sync.
22 23 24 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 22 def last_sync @last_sync end |
#mail_from_domain_status ⇒ Object
Returns the value of attribute mail_from_domain_status.
26 27 28 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 26 def mail_from_domain_status @mail_from_domain_status end |
#private_dkim_key ⇒ Object
Returns the value of attribute private_dkim_key.
30 31 32 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 30 def private_dkim_key @private_dkim_key end |
#reminder_sent_at ⇒ Object
Returns the value of attribute reminder_sent_at.
32 33 34 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 32 def reminder_sent_at @reminder_sent_at end |
#selector ⇒ Object
Returns the value of attribute selector.
34 35 36 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 34 def selector @selector end |
#sender ⇒ Object
Returns the value of attribute sender.
18 19 20 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 18 def sender @sender end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 20 def status @status end |
#verification_records ⇒ Object
Returns the value of attribute verification_records.
36 37 38 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 36 def verification_records @verification_records end |
#verification_tokens ⇒ Object
Returns the value of attribute verification_tokens.
24 25 26 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 24 def verification_tokens @verification_tokens end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 61 def self.attribute_map { :'sender' => :'sender', :'status' => :'status', :'last_sync' => :'lastSync', :'verification_tokens' => :'verificationTokens', :'mail_from_domain_status' => :'mailFromDomainStatus', :'created_at' => :'createdAt', :'private_dkim_key' => :'privateDKIMKey', :'reminder_sent_at' => :'reminderSentAt', :'selector' => :'selector', :'verification_records' => :'verificationRecords' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 313 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 87 def self.openapi_types { :'sender' => :'String', :'status' => :'String', :'last_sync' => :'Time', :'verification_tokens' => :'Array<String>', :'mail_from_domain_status' => :'String', :'created_at' => :'String', :'private_dkim_key' => :'String', :'reminder_sent_at' => :'String', :'selector' => :'String', :'verification_records' => :'GetSendersResponseInnerVerificationRecords' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 283 def ==(o) return true if self.equal?(o) self.class == o.class && sender == o.sender && status == o.status && last_sync == o.last_sync && verification_tokens == o.verification_tokens && mail_from_domain_status == o.mail_from_domain_status && created_at == o.created_at && private_dkim_key == o.private_dkim_key && reminder_sent_at == o.reminder_sent_at && selector == o.selector && verification_records == o.verification_records end |
#eql?(o) ⇒ Boolean
300 301 302 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 300 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 306 def hash [sender, status, last_sync, verification_tokens, mail_from_domain_status, created_at, private_dkim_key, reminder_sent_at, selector, verification_records].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @sender.nil? invalid_properties.push('invalid value for "sender", sender cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @last_sync.nil? invalid_properties.push('invalid value for "last_sync", last_sync cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @selector.nil? invalid_properties.push('invalid value for "selector", selector cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/pingram/models/get_senders_response_inner.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @sender.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["SUCCESS", "PENDING", "FAILED", "TEMPORARY_FAILURE", "NOT_STARTED"]) return false unless status_validator.valid?(@status) return false if @last_sync.nil? mail_from_domain_status_validator = EnumAttributeValidator.new('String', ["PENDING", "SUCCESS", "FAILED", "TEMPORARY_FAILURE"]) return false unless mail_from_domain_status_validator.valid?(@mail_from_domain_status) return false if @created_at.nil? return false if @selector.nil? true end |