Class: Pingram::GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInner
- Defined in:
- lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb
Instance Attribute Summary collapse
-
#app_unfurl_url ⇒ Object
The exact URL posted in the source message.
-
#entity_payload ⇒ Object
Schema for the given entity type.
-
#entity_type ⇒ Object
Entity type (e.g., ‘slack#/entities/task’, ‘slack#/entities/file’).
-
#external_ref ⇒ Object
Returns the value of attribute external_ref.
-
#url ⇒ Object
URL used to identify an entity within the developer’s system.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInner
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] else self.entity_type = nil end if attributes.key?(:'entity_payload') if (value = attributes[:'entity_payload']).is_a?(Hash) self.entity_payload = value end else self.entity_payload = nil end if attributes.key?(:'external_ref') self.external_ref = attributes[:'external_ref'] else self.external_ref = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'app_unfurl_url') self.app_unfurl_url = attributes[:'app_unfurl_url'] end end |
Instance Attribute Details
#app_unfurl_url ⇒ Object
The exact URL posted in the source message. Required in metadata passed to chat.unfurl.
30 31 32 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 30 def app_unfurl_url @app_unfurl_url end |
#entity_payload ⇒ Object
Schema for the given entity type.
22 23 24 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 22 def entity_payload @entity_payload end |
#entity_type ⇒ Object
Entity type (e.g., ‘slack#/entities/task’, ‘slack#/entities/file’).
19 20 21 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 19 def entity_type @entity_type end |
#external_ref ⇒ Object
Returns the value of attribute external_ref.
24 25 26 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 24 def external_ref @external_ref end |
#url ⇒ Object
URL used to identify an entity within the developer’s system.
27 28 29 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 27 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 33 def self.attribute_map { :'entity_type' => :'entity_type', :'entity_payload' => :'entity_payload', :'external_ref' => :'external_ref', :'url' => :'url', :'app_unfurl_url' => :'app_unfurl_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 54 def self.openapi_types { :'entity_type' => :'String', :'entity_payload' => :'Hash<String, Object>', :'external_ref' => :'GetTemplatesListResponseInnerAnyOf5MetadataEntitiesInnerExternalRef', :'url' => :'String', :'app_unfurl_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && entity_type == o.entity_type && entity_payload == o.entity_payload && external_ref == o.external_ref && url == o.url && app_unfurl_url == o.app_unfurl_url end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 212 def hash [entity_type, entity_payload, external_ref, url, app_unfurl_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @entity_type.nil? invalid_properties.push('invalid value for "entity_type", entity_type cannot be nil.') end if @entity_payload.nil? invalid_properties.push('invalid value for "entity_payload", entity_payload cannot be nil.') end if @external_ref.nil? invalid_properties.push('invalid value for "external_ref", external_ref cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 150 |
# File 'lib/pingram/models/get_templates_list_response_inner_any_of5_metadata_entities_inner.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @entity_type.nil? return false if @entity_payload.nil? return false if @external_ref.nil? return false if @url.nil? true end |