Class: Pingram::IngishtsPostRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::IngishtsPostRequest
- Defined in:
- lib/pingram/models/ingishts_post_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#end_time ⇒ Object
Returns the value of attribute end_time.
-
#label_options ⇒ Object
Returns the value of attribute label_options.
-
#max_datapoints ⇒ Object
Returns the value of attribute max_datapoints.
-
#metric_data_queries ⇒ Object
Returns the value of attribute metric_data_queries.
-
#next_token ⇒ Object
Returns the value of attribute next_token.
-
#scan_by ⇒ Object
Returns the value of attribute scan_by.
-
#start_time ⇒ Object
Returns the value of attribute start_time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IngishtsPostRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IngishtsPostRequest
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::IngishtsPostRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::IngishtsPostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] else self.start_time = nil end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] else self.end_time = nil end if attributes.key?(:'metric_data_queries') if (value = attributes[:'metric_data_queries']).is_a?(Array) self.metric_data_queries = value end else self.metric_data_queries = nil end if attributes.key?(:'next_token') self.next_token = attributes[:'next_token'] end if attributes.key?(:'scan_by') self.scan_by = attributes[:'scan_by'] end if attributes.key?(:'max_datapoints') self.max_datapoints = attributes[:'max_datapoints'] end if attributes.key?(:'label_options') self. = attributes[:'label_options'] end end |
Instance Attribute Details
#end_time ⇒ Object
Returns the value of attribute end_time.
20 21 22 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 20 def end_time @end_time end |
#label_options ⇒ Object
Returns the value of attribute label_options.
30 31 32 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 30 def end |
#max_datapoints ⇒ Object
Returns the value of attribute max_datapoints.
28 29 30 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 28 def max_datapoints @max_datapoints end |
#metric_data_queries ⇒ Object
Returns the value of attribute metric_data_queries.
22 23 24 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 22 def metric_data_queries @metric_data_queries end |
#next_token ⇒ Object
Returns the value of attribute next_token.
24 25 26 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 24 def next_token @next_token end |
#scan_by ⇒ Object
Returns the value of attribute scan_by.
26 27 28 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 26 def scan_by @scan_by end |
#start_time ⇒ Object
Returns the value of attribute start_time.
18 19 20 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 18 def start_time @start_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 55 def self.attribute_map { :'start_time' => :'StartTime', :'end_time' => :'EndTime', :'metric_data_queries' => :'MetricDataQueries', :'next_token' => :'NextToken', :'scan_by' => :'ScanBy', :'max_datapoints' => :'MaxDatapoints', :'label_options' => :'LabelOptions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 250 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 78 def self.openapi_types { :'start_time' => :'String', :'end_time' => :'String', :'metric_data_queries' => :'Array<IngishtsPostRequestMetricDataQueriesInner>', :'next_token' => :'String', :'scan_by' => :'String', :'max_datapoints' => :'Float', :'label_options' => :'IngishtsPostRequestLabelOptions' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 223 def ==(o) return true if self.equal?(o) self.class == o.class && start_time == o.start_time && end_time == o.end_time && metric_data_queries == o.metric_data_queries && next_token == o.next_token && scan_by == o.scan_by && max_datapoints == o.max_datapoints && == o. end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 243 def hash [start_time, end_time, metric_data_queries, next_token, scan_by, max_datapoints, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @start_time.nil? invalid_properties.push('invalid value for "start_time", start_time cannot be nil.') end if @end_time.nil? invalid_properties.push('invalid value for "end_time", end_time cannot be nil.') end if @metric_data_queries.nil? invalid_properties.push('invalid value for "metric_data_queries", metric_data_queries cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 |
# File 'lib/pingram/models/ingishts_post_request.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @start_time.nil? return false if @end_time.nil? return false if @metric_data_queries.nil? scan_by_validator = EnumAttributeValidator.new('String', ["TimestampDescending", "TimestampAscending"]) return false unless scan_by_validator.valid?(@scan_by) true end |