Class: Pingram::LibraryApi
- Inherits:
-
Object
- Object
- Pingram::LibraryApi
- Defined in:
- lib/pingram/api/library_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LibraryApi
constructor
A new instance of LibraryApi.
-
#library_create(use_case, create_library_request, opts = {}) ⇒ CreateLibraryResponse
Create an upload slot in the account library.
-
#library_create_with_http_info(use_case, create_library_request, opts = {}) ⇒ Array<(CreateLibraryResponse, Integer, Hash)>
Create an upload slot in the account library.
-
#library_list(use_case, opts = {}) ⇒ ListLibraryResponse
List files in the account library for a use-case, newest first.
-
#library_list_with_http_info(use_case, opts = {}) ⇒ Array<(ListLibraryResponse, Integer, Hash)>
List files in the account library for a use-case, newest first.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LibraryApi
Returns a new instance of LibraryApi.
19 20 21 |
# File 'lib/pingram/api/library_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/library_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#library_create(use_case, create_library_request, opts = {}) ⇒ CreateLibraryResponse
Create an upload slot in the account library. PUT the file to the returned uploadUrl with the same Content-Type, then use the returned url in emails and the editor.
27 28 29 30 |
# File 'lib/pingram/api/library_api.rb', line 27 def library_create(use_case, create_library_request, opts = {}) data, _status_code, _headers = library_create_with_http_info(use_case, create_library_request, opts) data end |
#library_create_with_http_info(use_case, create_library_request, opts = {}) ⇒ Array<(CreateLibraryResponse, Integer, Hash)>
Create an upload slot in the account library. PUT the file to the returned uploadUrl with the same Content-Type, then use the returned url in emails and the editor.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/pingram/api/library_api.rb', line 37 def library_create_with_http_info(use_case, create_library_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LibraryApi.library_create ...' end # verify the required parameter 'use_case' is set if @api_client.config.client_side_validation && use_case.nil? fail ArgumentError, "Missing the required parameter 'use_case' when calling LibraryApi.library_create" end # verify the required parameter 'create_library_request' is set if @api_client.config.client_side_validation && create_library_request.nil? fail ArgumentError, "Missing the required parameter 'create_library_request' when calling LibraryApi.library_create" end # resource path local_var_path = '/library/{useCase}'.sub('{' + 'useCase' + '}', CGI.escape(use_case.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_library_request) # return_type return_type = opts[:debug_return_type] || 'CreateLibraryResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"LibraryApi.library_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LibraryApi#library_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#library_list(use_case, opts = {}) ⇒ ListLibraryResponse
List files in the account library for a use-case, newest first. Paginate with limit (default 50, max 100) and nextToken.
100 101 102 103 |
# File 'lib/pingram/api/library_api.rb', line 100 def library_list(use_case, opts = {}) data, _status_code, _headers = library_list_with_http_info(use_case, opts) data end |
#library_list_with_http_info(use_case, opts = {}) ⇒ Array<(ListLibraryResponse, Integer, Hash)>
List files in the account library for a use-case, newest first. Paginate with limit (default 50, max 100) and nextToken.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/pingram/api/library_api.rb', line 111 def library_list_with_http_info(use_case, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LibraryApi.library_list ...' end # verify the required parameter 'use_case' is set if @api_client.config.client_side_validation && use_case.nil? fail ArgumentError, "Missing the required parameter 'use_case' when calling LibraryApi.library_list" end # resource path local_var_path = '/library/{useCase}'.sub('{' + 'useCase' + '}', CGI.escape(use_case.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'nextToken'] = opts[:'next_token'] if !opts[:'next_token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListLibraryResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"LibraryApi.library_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LibraryApi#library_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |