Class: Pingram::OrganizationUsage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::OrganizationUsage
- Defined in:
- lib/pingram/models/organization_usage.rb
Overview
Response for GET /account/organization/usage
Instance Attribute Summary collapse
-
#billing_cycle_end ⇒ Object
Billing cycle end date (ISO string).
-
#billing_cycle_start ⇒ Object
Billing cycle start date (ISO string).
-
#budget_usage ⇒ Object
Total budget usage in USD (cost_SMS + cost_CALL).
-
#channel_usages ⇒ Object
Per-channel usage breakdown.
-
#cost_call ⇒ Object
Call cost in USD.
-
#cost_sms ⇒ Object
SMS cost in USD.
-
#message_usage ⇒ Object
Total message usage (EMAIL + INAPP_WEB + WEB_PUSH + PUSH + SLACK).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationUsage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationUsage
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/models/organization_usage.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::OrganizationUsage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::OrganizationUsage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message_usage') self. = attributes[:'message_usage'] else self. = nil end if attributes.key?(:'budget_usage') self.budget_usage = attributes[:'budget_usage'] else self.budget_usage = nil end if attributes.key?(:'cost_sms') self.cost_sms = attributes[:'cost_sms'] else self.cost_sms = nil end if attributes.key?(:'cost_call') self.cost_call = attributes[:'cost_call'] else self.cost_call = nil end if attributes.key?(:'channel_usages') if (value = attributes[:'channel_usages']).is_a?(Hash) self.channel_usages = value end else self.channel_usages = nil end if attributes.key?(:'billing_cycle_start') self.billing_cycle_start = attributes[:'billing_cycle_start'] else self.billing_cycle_start = nil end if attributes.key?(:'billing_cycle_end') self.billing_cycle_end = attributes[:'billing_cycle_end'] else self.billing_cycle_end = nil end end |
Instance Attribute Details
#billing_cycle_end ⇒ Object
Billing cycle end date (ISO string)
38 39 40 |
# File 'lib/pingram/models/organization_usage.rb', line 38 def billing_cycle_end @billing_cycle_end end |
#billing_cycle_start ⇒ Object
Billing cycle start date (ISO string)
35 36 37 |
# File 'lib/pingram/models/organization_usage.rb', line 35 def billing_cycle_start @billing_cycle_start end |
#budget_usage ⇒ Object
Total budget usage in USD (cost_SMS + cost_CALL)
23 24 25 |
# File 'lib/pingram/models/organization_usage.rb', line 23 def budget_usage @budget_usage end |
#channel_usages ⇒ Object
Per-channel usage breakdown
32 33 34 |
# File 'lib/pingram/models/organization_usage.rb', line 32 def channel_usages @channel_usages end |
#cost_call ⇒ Object
Call cost in USD
29 30 31 |
# File 'lib/pingram/models/organization_usage.rb', line 29 def cost_call @cost_call end |
#cost_sms ⇒ Object
SMS cost in USD
26 27 28 |
# File 'lib/pingram/models/organization_usage.rb', line 26 def cost_sms @cost_sms end |
#message_usage ⇒ Object
Total message usage (EMAIL + INAPP_WEB + WEB_PUSH + PUSH + SLACK)
20 21 22 |
# File 'lib/pingram/models/organization_usage.rb', line 20 def end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/pingram/models/organization_usage.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/pingram/models/organization_usage.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/pingram/models/organization_usage.rb', line 41 def self.attribute_map { :'message_usage' => :'messageUsage', :'budget_usage' => :'budgetUsage', :'cost_sms' => :'costSms', :'cost_call' => :'costCall', :'channel_usages' => :'channelUsages', :'billing_cycle_start' => :'billingCycleStart', :'billing_cycle_end' => :'billingCycleEnd' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/pingram/models/organization_usage.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/pingram/models/organization_usage.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/pingram/models/organization_usage.rb', line 64 def self.openapi_types { :'message_usage' => :'Float', :'budget_usage' => :'Float', :'cost_sms' => :'Float', :'cost_call' => :'Float', :'channel_usages' => :'Hash<String, Float>', :'billing_cycle_start' => :'String', :'billing_cycle_end' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pingram/models/organization_usage.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && budget_usage == o.budget_usage && cost_sms == o.cost_sms && cost_call == o.cost_call && channel_usages == o.channel_usages && billing_cycle_start == o.billing_cycle_start && billing_cycle_end == o.billing_cycle_end end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/pingram/models/organization_usage.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/pingram/models/organization_usage.rb', line 285 def hash [, budget_usage, cost_sms, cost_call, channel_usages, billing_cycle_start, billing_cycle_end].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/pingram/models/organization_usage.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if .nil? invalid_properties.push('invalid value for "message_usage", message_usage cannot be nil.') end if @budget_usage.nil? invalid_properties.push('invalid value for "budget_usage", budget_usage cannot be nil.') end if @cost_sms.nil? invalid_properties.push('invalid value for "cost_sms", cost_sms cannot be nil.') end if @cost_call.nil? invalid_properties.push('invalid value for "cost_call", cost_call cannot be nil.') end if @channel_usages.nil? invalid_properties.push('invalid value for "channel_usages", channel_usages cannot be nil.') end if @billing_cycle_start.nil? invalid_properties.push('invalid value for "billing_cycle_start", billing_cycle_start cannot be nil.') end if @billing_cycle_end.nil? invalid_properties.push('invalid value for "billing_cycle_end", billing_cycle_end cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/pingram/models/organization_usage.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/pingram/models/organization_usage.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if .nil? return false if @budget_usage.nil? return false if @cost_sms.nil? return false if @cost_call.nil? return false if @channel_usages.nil? return false if @billing_cycle_start.nil? return false if @billing_cycle_end.nil? true end |