Class: Pingram::OrganizationUsageCounts
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::OrganizationUsageCounts
- Defined in:
- lib/pingram/models/organization_usage_counts.rb
Overview
Per-channel usage breakdown
Instance Attribute Summary collapse
-
#call ⇒ Object
Returns the value of attribute call.
-
#email ⇒ Object
Returns the value of attribute email.
-
#inapp_web ⇒ Object
Returns the value of attribute inapp_web.
-
#push ⇒ Object
Returns the value of attribute push.
-
#slack ⇒ Object
Returns the value of attribute slack.
-
#sms ⇒ Object
Returns the value of attribute sms.
-
#voice ⇒ Object
Returns the value of attribute voice.
-
#web_push ⇒ Object
Returns the value of attribute web_push.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationUsageCounts
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationUsageCounts
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::OrganizationUsageCounts` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::OrganizationUsageCounts`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'inapp_web') self.inapp_web = attributes[:'inapp_web'] else self.inapp_web = nil end if attributes.key?(:'sms') self.sms = attributes[:'sms'] else self.sms = nil end if attributes.key?(:'call') self.call = attributes[:'call'] else self.call = nil end if attributes.key?(:'voice') self.voice = attributes[:'voice'] else self.voice = nil end if attributes.key?(:'push') self.push = attributes[:'push'] else self.push = nil end if attributes.key?(:'web_push') self.web_push = attributes[:'web_push'] else self.web_push = nil end if attributes.key?(:'slack') self.slack = attributes[:'slack'] else self.slack = nil end end |
Instance Attribute Details
#call ⇒ Object
Returns the value of attribute call.
25 26 27 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 25 def call @call end |
#email ⇒ Object
Returns the value of attribute email.
19 20 21 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 19 def email @email end |
#inapp_web ⇒ Object
Returns the value of attribute inapp_web.
21 22 23 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 21 def inapp_web @inapp_web end |
#push ⇒ Object
Returns the value of attribute push.
29 30 31 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 29 def push @push end |
#slack ⇒ Object
Returns the value of attribute slack.
33 34 35 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 33 def slack @slack end |
#sms ⇒ Object
Returns the value of attribute sms.
23 24 25 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 23 def sms @sms end |
#voice ⇒ Object
Returns the value of attribute voice.
27 28 29 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 27 def voice @voice end |
#web_push ⇒ Object
Returns the value of attribute web_push.
31 32 33 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 31 def web_push @web_push end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 36 def self.attribute_map { :'email' => :'EMAIL', :'inapp_web' => :'INAPP_WEB', :'sms' => :'SMS', :'call' => :'CALL', :'voice' => :'VOICE', :'push' => :'PUSH', :'web_push' => :'WEB_PUSH', :'slack' => :'SLACK' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 60 def self.openapi_types { :'email' => :'Float', :'inapp_web' => :'Float', :'sms' => :'Float', :'call' => :'Float', :'voice' => :'Float', :'push' => :'Float', :'web_push' => :'Float', :'slack' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && email == o.email && inapp_web == o.inapp_web && sms == o.sms && call == o.call && voice == o.voice && push == o.push && web_push == o.web_push && slack == o.slack end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 302 def hash [email, inapp_web, sms, call, voice, push, web_push, slack].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @inapp_web.nil? invalid_properties.push('invalid value for "inapp_web", inapp_web cannot be nil.') end if @sms.nil? invalid_properties.push('invalid value for "sms", sms cannot be nil.') end if @call.nil? invalid_properties.push('invalid value for "call", call cannot be nil.') end if @voice.nil? invalid_properties.push('invalid value for "voice", voice cannot be nil.') end if @push.nil? invalid_properties.push('invalid value for "push", push cannot be nil.') end if @web_push.nil? invalid_properties.push('invalid value for "web_push", web_push cannot be nil.') end if @slack.nil? invalid_properties.push('invalid value for "slack", slack cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pingram/models/organization_usage_counts.rb', line 186 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @email.nil? return false if @inapp_web.nil? return false if @sms.nil? return false if @call.nil? return false if @voice.nil? return false if @push.nil? return false if @web_push.nil? return false if @slack.nil? true end |