Class: Pingram::PostUserRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/post_user_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostUserRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/pingram/models/post_user_request.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::PostUserRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::PostUserRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'push_tokens')
    if (value = attributes[:'push_tokens']).is_a?(Array)
      self.push_tokens = value
    end
  end

  if attributes.key?(:'web_push_tokens')
    if (value = attributes[:'web_push_tokens']).is_a?(Array)
      self.web_push_tokens = value
    end
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end

  if attributes.key?(:'slack_channel')
    self.slack_channel = attributes[:'slack_channel']
  end

  if attributes.key?(:'slack_token')
    self.slack_token = attributes[:'slack_token']
  end
end

Instance Attribute Details

#emailObject

Returns the value of attribute email.



20
21
22
# File 'lib/pingram/models/post_user_request.rb', line 20

def email
  @email
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pingram/models/post_user_request.rb', line 18

def id
  @id
end

#numberObject

Returns the value of attribute number.



22
23
24
# File 'lib/pingram/models/post_user_request.rb', line 22

def number
  @number
end

#push_tokensObject

Returns the value of attribute push_tokens.



24
25
26
# File 'lib/pingram/models/post_user_request.rb', line 24

def push_tokens
  @push_tokens
end

#slack_channelObject

The destination channel of slack notifications sent to this user. Can be either of the following: - Channel name, e.g. "test" - Channel name with # prefix, e.g. "#test" - Channel ID, e.g. "C1234567890" - User ID for DM, e.g. "U1234567890" - Username with @ prefix, e.g. "@test"



31
32
33
# File 'lib/pingram/models/post_user_request.rb', line 31

def slack_channel
  @slack_channel
end

#slack_tokenObject

Returns the value of attribute slack_token.



33
34
35
# File 'lib/pingram/models/post_user_request.rb', line 33

def slack_token
  @slack_token
end

#timezoneObject

Returns the value of attribute timezone.



28
29
30
# File 'lib/pingram/models/post_user_request.rb', line 28

def timezone
  @timezone
end

#web_push_tokensObject

Returns the value of attribute web_push_tokens.



26
27
28
# File 'lib/pingram/models/post_user_request.rb', line 26

def web_push_tokens
  @web_push_tokens
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/pingram/models/post_user_request.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/pingram/models/post_user_request.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/pingram/models/post_user_request.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'email' => :'email',
    :'number' => :'number',
    :'push_tokens' => :'pushTokens',
    :'web_push_tokens' => :'webPushTokens',
    :'timezone' => :'timezone',
    :'slack_channel' => :'slackChannel',
    :'slack_token' => :'slackToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/pingram/models/post_user_request.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/pingram/models/post_user_request.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/pingram/models/post_user_request.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'email' => :'String',
    :'number' => :'String',
    :'push_tokens' => :'Array<GetUsersResponseUsersInnerPushTokensInner>',
    :'web_push_tokens' => :'Array<GetUsersResponseUsersInnerWebPushTokensInner>',
    :'timezone' => :'String',
    :'slack_channel' => :'String',
    :'slack_token' => :'GetUsersResponseUsersInnerSlackToken'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pingram/models/post_user_request.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      email == o.email &&
      number == o.number &&
      push_tokens == o.push_tokens &&
      web_push_tokens == o.web_push_tokens &&
      timezone == o.timezone &&
      slack_channel == o.slack_channel &&
      slack_token == o.slack_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/pingram/models/post_user_request.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/pingram/models/post_user_request.rb', line 170

def hash
  [id, email, number, push_tokens, web_push_tokens, timezone, slack_channel, slack_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
# File 'lib/pingram/models/post_user_request.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/pingram/models/post_user_request.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
# File 'lib/pingram/models/post_user_request.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end