Class: Pingram::SendSmsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::SendSmsRequest
- Defined in:
- lib/pingram/models/send_sms_request.rb
Overview
Request body for ‘POST /sms` (send SMS without a template).
Instance Attribute Summary collapse
-
#auto_reply ⇒ Object
Returns the value of attribute auto_reply.
-
#from ⇒ Object
Override the sender phone number.
-
#message ⇒ Object
The message of the SMS notification.
-
#schedule ⇒ Object
The ISO 8601 datetime to schedule the SMS notification.
-
#to ⇒ Object
The phone number of the recipient.
-
#type ⇒ Object
The notification type to send.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendSmsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendSmsRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/pingram/models/send_sms_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::SendSmsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::SendSmsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'to') self.to = attributes[:'to'] else self.to = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'auto_reply') self.auto_reply = attributes[:'auto_reply'] end end |
Instance Attribute Details
#auto_reply ⇒ Object
Returns the value of attribute auto_reply.
34 35 36 |
# File 'lib/pingram/models/send_sms_request.rb', line 34 def auto_reply @auto_reply end |
#from ⇒ Object
Override the sender phone number. Must be a verified number in your Telnyx account.
32 33 34 |
# File 'lib/pingram/models/send_sms_request.rb', line 32 def from @from end |
#message ⇒ Object
The message of the SMS notification.
26 27 28 |
# File 'lib/pingram/models/send_sms_request.rb', line 26 def @message end |
#schedule ⇒ Object
The ISO 8601 datetime to schedule the SMS notification.
29 30 31 |
# File 'lib/pingram/models/send_sms_request.rb', line 29 def schedule @schedule end |
#to ⇒ Object
The phone number of the recipient.
23 24 25 |
# File 'lib/pingram/models/send_sms_request.rb', line 23 def to @to end |
#type ⇒ Object
The notification type to send.
20 21 22 |
# File 'lib/pingram/models/send_sms_request.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/pingram/models/send_sms_request.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/pingram/models/send_sms_request.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/pingram/models/send_sms_request.rb', line 37 def self.attribute_map { :'type' => :'type', :'to' => :'to', :'message' => :'message', :'schedule' => :'schedule', :'from' => :'from', :'auto_reply' => :'autoReply' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/pingram/models/send_sms_request.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/pingram/models/send_sms_request.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pingram/models/send_sms_request.rb', line 59 def self.openapi_types { :'type' => :'String', :'to' => :'String', :'message' => :'String', :'schedule' => :'String', :'from' => :'String', :'auto_reply' => :'SenderPostBodySmsAutoReply' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/pingram/models/send_sms_request.rb', line 185 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && to == o.to && == o. && schedule == o.schedule && from == o.from && auto_reply == o.auto_reply end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/pingram/models/send_sms_request.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/pingram/models/send_sms_request.rb', line 204 def hash [type, to, , schedule, from, auto_reply].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/pingram/models/send_sms_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @to.nil? invalid_properties.push('invalid value for "to", to cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/pingram/models/send_sms_request.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 |
# File 'lib/pingram/models/send_sms_request.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? return false if @to.nil? return false if @message.nil? true end |