Class: Pingram::SenderPostBodyOptionsEmail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::SenderPostBodyOptionsEmail
- Defined in:
- lib/pingram/models/sender_post_body_options_email.rb
Overview
Email-specific overrides.
Instance Attribute Summary collapse
-
#attachments ⇒ Object
File attachments (by URL or inline base64 content).
-
#bcc_addresses ⇒ Object
BCC recipients.
-
#cc_addresses ⇒ Object
CC recipients.
-
#from_address ⇒ Object
Override sender email address.
-
#from_name ⇒ Object
Override sender display name.
-
#reply_to_addresses ⇒ Object
Reply-to addresses for the email.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SenderPostBodyOptionsEmail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SenderPostBodyOptionsEmail
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::SenderPostBodyOptionsEmail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::SenderPostBodyOptionsEmail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'reply_to_addresses') if (value = attributes[:'reply_to_addresses']).is_a?(Array) self.reply_to_addresses = value end end if attributes.key?(:'cc_addresses') if (value = attributes[:'cc_addresses']).is_a?(Array) self.cc_addresses = value end end if attributes.key?(:'bcc_addresses') if (value = attributes[:'bcc_addresses']).is_a?(Array) self.bcc_addresses = value end end if attributes.key?(:'from_address') self.from_address = attributes[:'from_address'] end if attributes.key?(:'from_name') self.from_name = attributes[:'from_name'] end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#attachments ⇒ Object
File attachments (by URL or inline base64 content). Inline content: ~4 MB raw per file (413 if exceeded). URL url: up to 20 MB per file.
35 36 37 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 35 def @attachments end |
#bcc_addresses ⇒ Object
BCC recipients.
26 27 28 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 26 def bcc_addresses @bcc_addresses end |
#cc_addresses ⇒ Object
CC recipients.
23 24 25 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 23 def cc_addresses @cc_addresses end |
#from_address ⇒ Object
Override sender email address.
29 30 31 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 29 def from_address @from_address end |
#from_name ⇒ Object
Override sender display name.
32 33 34 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 32 def from_name @from_name end |
#reply_to_addresses ⇒ Object
Reply-to addresses for the email.
20 21 22 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 20 def reply_to_addresses @reply_to_addresses end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 38 def self.attribute_map { :'reply_to_addresses' => :'replyToAddresses', :'cc_addresses' => :'ccAddresses', :'bcc_addresses' => :'bccAddresses', :'from_address' => :'fromAddress', :'from_name' => :'fromName', :'attachments' => :'attachments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 60 def self.openapi_types { :'reply_to_addresses' => :'Array<String>', :'cc_addresses' => :'Array<String>', :'bcc_addresses' => :'Array<String>', :'from_address' => :'String', :'from_name' => :'String', :'attachments' => :'Array<SenderPostBodyOptionsEmailAttachmentsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && reply_to_addresses == o.reply_to_addresses && cc_addresses == o.cc_addresses && bcc_addresses == o.bcc_addresses && from_address == o.from_address && from_name == o.from_name && == o. end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 162 def hash [reply_to_addresses, cc_addresses, bcc_addresses, from_address, from_name, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |