Class: Pingram::SenderPostBodyOptionsEmail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::SenderPostBodyOptionsEmail
- Defined in:
- lib/pingram/models/sender_post_body_options_email.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#bcc_addresses ⇒ Object
Returns the value of attribute bcc_addresses.
-
#cc_addresses ⇒ Object
Returns the value of attribute cc_addresses.
-
#condition ⇒ Object
Returns the value of attribute condition.
-
#from_address ⇒ Object
Returns the value of attribute from_address.
-
#from_name ⇒ Object
Returns the value of attribute from_name.
-
#reply_to_addresses ⇒ Object
Returns the value of attribute reply_to_addresses.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SenderPostBodyOptionsEmail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SenderPostBodyOptionsEmail
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::SenderPostBodyOptionsEmail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::SenderPostBodyOptionsEmail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'reply_to_addresses') if (value = attributes[:'reply_to_addresses']).is_a?(Array) self.reply_to_addresses = value end end if attributes.key?(:'cc_addresses') if (value = attributes[:'cc_addresses']).is_a?(Array) self.cc_addresses = value end end if attributes.key?(:'bcc_addresses') if (value = attributes[:'bcc_addresses']).is_a?(Array) self.bcc_addresses = value end end if attributes.key?(:'from_address') self.from_address = attributes[:'from_address'] end if attributes.key?(:'from_name') self.from_name = attributes[:'from_name'] end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end if attributes.key?(:'condition') self.condition = attributes[:'condition'] end end |
Instance Attribute Details
#attachments ⇒ Object
Returns the value of attribute attachments.
28 29 30 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 28 def @attachments end |
#bcc_addresses ⇒ Object
Returns the value of attribute bcc_addresses.
22 23 24 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 22 def bcc_addresses @bcc_addresses end |
#cc_addresses ⇒ Object
Returns the value of attribute cc_addresses.
20 21 22 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 20 def cc_addresses @cc_addresses end |
#condition ⇒ Object
Returns the value of attribute condition.
30 31 32 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 30 def condition @condition end |
#from_address ⇒ Object
Returns the value of attribute from_address.
24 25 26 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 24 def from_address @from_address end |
#from_name ⇒ Object
Returns the value of attribute from_name.
26 27 28 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 26 def from_name @from_name end |
#reply_to_addresses ⇒ Object
Returns the value of attribute reply_to_addresses.
18 19 20 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 18 def reply_to_addresses @reply_to_addresses end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 33 def self.attribute_map { :'reply_to_addresses' => :'replyToAddresses', :'cc_addresses' => :'ccAddresses', :'bcc_addresses' => :'bccAddresses', :'from_address' => :'fromAddress', :'from_name' => :'fromName', :'attachments' => :'attachments', :'condition' => :'condition' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 56 def self.openapi_types { :'reply_to_addresses' => :'Array<String>', :'cc_addresses' => :'Array<String>', :'bcc_addresses' => :'Array<String>', :'from_address' => :'String', :'from_name' => :'String', :'attachments' => :'Array<SenderPostBodyOptionsEmailAttachmentsInner>', :'condition' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && reply_to_addresses == o.reply_to_addresses && cc_addresses == o.cc_addresses && bcc_addresses == o.bcc_addresses && from_address == o.from_address && from_name == o.from_name && == o. && condition == o.condition end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 164 def hash [reply_to_addresses, cc_addresses, bcc_addresses, from_address, from_name, , condition].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/pingram/models/sender_post_body_options_email.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |