Class: Pingram::SenderPostBodySlack
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pingram::SenderPostBodySlack
- Defined in:
- lib/pingram/models/sender_post_body_slack.rb
Overview
Inline Slack content (text, blocks, etc.).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#blocks ⇒ Object
Slack Block Kit blocks.
-
#icon ⇒ Object
Icon: emoji (e.g. \“:smile:\”) or URL.
-
#link_names ⇒ Object
Convert channel and username refs to Slack links.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#mrkdwn ⇒ Object
Enable Slack markup (bold, italic,
code). -
#parse ⇒ Object
URL parsing: \“full\” (clickable links) or \“none\”.
-
#reply_broadcast ⇒ Object
When true with thread_ts, broadcasts reply to channel.
-
#text ⇒ Object
Fallback plain text (required when using blocks).
-
#thread_ts ⇒ Object
Parent message
tsto post in a thread. -
#unfurl_links ⇒ Object
Unfurl link previews.
-
#unfurl_media ⇒ Object
Unfurl media previews.
-
#username ⇒ Object
Override bot username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SenderPostBodySlack
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SenderPostBodySlack
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::SenderPostBodySlack` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::SenderPostBodySlack`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'blocks') if (value = attributes[:'blocks']).is_a?(Array) self.blocks = value end end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'thread_ts') self.thread_ts = attributes[:'thread_ts'] end if attributes.key?(:'reply_broadcast') self.reply_broadcast = attributes[:'reply_broadcast'] end if attributes.key?(:'parse') self.parse = attributes[:'parse'] end if attributes.key?(:'link_names') self.link_names = attributes[:'link_names'] end if attributes.key?(:'mrkdwn') self.mrkdwn = attributes[:'mrkdwn'] end if attributes.key?(:'unfurl_links') self.unfurl_links = attributes[:'unfurl_links'] end if attributes.key?(:'unfurl_media') self.unfurl_media = attributes[:'unfurl_media'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#blocks ⇒ Object
Slack Block Kit blocks.
23 24 25 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 23 def blocks @blocks end |
#icon ⇒ Object
Icon: emoji (e.g. \“:smile:\”) or URL. Default: bot’s icon.
29 30 31 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 29 def icon @icon end |
#link_names ⇒ Object
Convert channel and username refs to Slack links. Default: false.
41 42 43 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 41 def link_names @link_names end |
#metadata ⇒ Object
Returns the value of attribute metadata.
52 53 54 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 52 def end |
#mrkdwn ⇒ Object
Enable Slack markup (bold, italic, code). Default: true.
44 45 46 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 44 def mrkdwn @mrkdwn end |
#parse ⇒ Object
URL parsing: \“full\” (clickable links) or \“none\”. Default: \“none\”.
38 39 40 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 38 def parse @parse end |
#reply_broadcast ⇒ Object
When true with thread_ts, broadcasts reply to channel. Default: false.
35 36 37 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 35 def reply_broadcast @reply_broadcast end |
#text ⇒ Object
Fallback plain text (required when using blocks).
20 21 22 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 20 def text @text end |
#thread_ts ⇒ Object
Parent message ts to post in a thread.
32 33 34 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 32 def thread_ts @thread_ts end |
#unfurl_links ⇒ Object
Unfurl link previews. Default: true.
47 48 49 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 47 def unfurl_links @unfurl_links end |
#unfurl_media ⇒ Object
Unfurl media previews. Default: true.
50 51 52 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 50 def unfurl_media @unfurl_media end |
#username ⇒ Object
Override bot username.
26 27 28 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 26 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
95 96 97 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 95 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 100 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 77 def self.attribute_map { :'text' => :'text', :'blocks' => :'blocks', :'username' => :'username', :'icon' => :'icon', :'thread_ts' => :'thread_ts', :'reply_broadcast' => :'reply_broadcast', :'parse' => :'parse', :'link_names' => :'link_names', :'mrkdwn' => :'mrkdwn', :'unfurl_links' => :'unfurl_links', :'unfurl_media' => :'unfurl_media', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 273 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 105 def self.openapi_types { :'text' => :'String', :'blocks' => :'Array<Hash<String, Object>>', :'username' => :'String', :'icon' => :'String', :'thread_ts' => :'String', :'reply_broadcast' => :'Boolean', :'parse' => :'String', :'link_names' => :'Boolean', :'mrkdwn' => :'Boolean', :'unfurl_links' => :'Boolean', :'unfurl_media' => :'Boolean', :'metadata' => :'GetTemplatesListResponseInnerAnyOf5Metadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && text == o.text && blocks == o.blocks && username == o.username && icon == o.icon && thread_ts == o.thread_ts && reply_broadcast == o.reply_broadcast && parse == o.parse && link_names == o.link_names && mrkdwn == o.mrkdwn && unfurl_links == o.unfurl_links && unfurl_media == o.unfurl_media && == o. end |
#eql?(o) ⇒ Boolean
260 261 262 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 260 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 266 def hash [text, blocks, username, icon, thread_ts, reply_broadcast, parse, link_names, mrkdwn, unfurl_links, unfurl_media, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 203 204 205 206 207 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 199 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @text.nil? invalid_properties.push('invalid value for "text", text cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
211 212 213 214 215 216 217 |
# File 'lib/pingram/models/sender_post_body_slack.rb', line 211 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @text.nil? parse_validator = EnumAttributeValidator.new('String', ["full", "none"]) return false unless parse_validator.valid?(@parse) true end |