Class: Pingram::TenDlcBrandCreateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/ten_dlc_brand_create_request.rb

Overview

Request body for POST /registrations/us/10dlc/brand

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TenDlcBrandCreateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::TenDlcBrandCreateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::TenDlcBrandCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  else
    self.scenario_id = nil
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  else
    self.business_type = nil
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  else
    self.legal_name = nil
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  else
    self.website = nil
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  else
    self.compliance_contact_email = nil
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  else
    self.compliance_contact_phone = nil
  end
end

Instance Attribute Details

#business_typeObject

Returns the value of attribute business_type.



21
22
23
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 21

def business_type
  @business_type
end

#cityObject

Returns the value of attribute city.



33
34
35
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 33

def city
  @city
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



39
40
41
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 39

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



41
42
43
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 41

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



29
30
31
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 29

def country
  @country
end

Returns the value of attribute legal_name.



23
24
25
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 23

def legal_name
  @legal_name
end

#postal_codeObject

Returns the value of attribute postal_code.



37
38
39
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 37

def postal_code
  @postal_code
end

#scenario_idObject

Returns the value of attribute scenario_id.



19
20
21
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 19

def scenario_id
  @scenario_id
end

#stateObject

Returns the value of attribute state.



35
36
37
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 35

def state
  @state
end

#streetObject

Returns the value of attribute street.



31
32
33
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 31

def street
  @street
end

#tax_idObject

Returns the value of attribute tax_id.



25
26
27
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 25

def tax_id
  @tax_id
end

#websiteObject

Returns the value of attribute website.



27
28
29
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 27

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 44

def self.attribute_map
  {
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'street' => :'street',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postalCode',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 72

def self.openapi_types
  {
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'street' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 296

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      street == o.street &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 321

def hash
  [scenario_id, business_type, legal_name, tax_id, website, country, street, city, state, postal_code, compliance_contact_email, compliance_contact_phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @scenario_id.nil?
    invalid_properties.push('invalid value for "scenario_id", scenario_id cannot be nil.')
  end

  if @business_type.nil?
    invalid_properties.push('invalid value for "business_type", business_type cannot be nil.')
  end

  if @legal_name.nil?
    invalid_properties.push('invalid value for "legal_name", legal_name cannot be nil.')
  end

  if @website.nil?
    invalid_properties.push('invalid value for "website", website cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @compliance_contact_email.nil?
    invalid_properties.push('invalid value for "compliance_contact_email", compliance_contact_email cannot be nil.')
  end

  if @compliance_contact_phone.nil?
    invalid_properties.push('invalid value for "compliance_contact_phone", compliance_contact_phone cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
# File 'lib/pingram/models/ten_dlc_brand_create_request.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @scenario_id.nil?
  return false if @business_type.nil?
  return false if @legal_name.nil?
  return false if @website.nil?
  return false if @country.nil?
  return false if @compliance_contact_email.nil?
  return false if @compliance_contact_phone.nil?
  true
end