Class: Pingram::TenDlcBrandUpdateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/ten_dlc_brand_update_request.rb

Overview

Request body for PATCH /registrations/us/10dlc/brand

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TenDlcBrandUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::TenDlcBrandUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::TenDlcBrandUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  end
end

Instance Attribute Details

#business_typeObject

Legal entity type for a 10DLC brand. - PRIVATE_PROFIT: private for-profit (LLC, corp, etc.) - SOLE_PROPRIETOR: sole proprietorship - PUBLIC_PROFIT: publicly traded for-profit - NON_PROFIT: non-profit - GOVERNMENT: government



23
24
25
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 23

def business_type
  @business_type
end

#cityObject

Returns the value of attribute city.



43
44
45
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 43

def city
  @city
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



49
50
51
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 49

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



51
52
53
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 51

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



39
40
41
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 39

def country
  @country
end

#display_nameObject

Brand display name (marketing/DBA); defaults to legalName when omitted on legalName-only updates.



28
29
30
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 28

def display_name
  @display_name
end

#first_nameObject

Returns the value of attribute first_name.



30
31
32
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 30

def first_name
  @first_name
end

#last_nameObject

Returns the value of attribute last_name.



32
33
34
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 32

def last_name
  @last_name
end

Returns the value of attribute legal_name.



25
26
27
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 25

def legal_name
  @legal_name
end

#postal_codeObject

Returns the value of attribute postal_code.



47
48
49
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 47

def postal_code
  @postal_code
end

#scenario_idObject

Who the 10DLC brand is registered for. - own_brand: personal or company project - client_brand: agency or contractor



20
21
22
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 20

def scenario_id
  @scenario_id
end

#stateObject

Returns the value of attribute state.



45
46
47
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 45

def state
  @state
end

#streetObject

Returns the value of attribute street.



41
42
43
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 41

def street
  @street
end

#tax_idObject

For US companies (country US): 9-digit EIN (Employer Identification Number). For Canada (country CA): 9-digit BN (Business Number). For other countries: national business tax identifier.



35
36
37
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 35

def tax_id
  @tax_id
end

#websiteObject

Returns the value of attribute website.



37
38
39
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 37

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



97
98
99
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 97

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 102

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 76

def self.attribute_map
  {
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'display_name' => :'displayName',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'street' => :'street',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postalCode',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 107

def self.openapi_types
  {
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'display_name' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'street' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 251

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      display_name == o.display_name &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      street == o.street &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 279

def hash
  [scenario_id, business_type, legal_name, display_name, first_name, last_name, tax_id, website, country, street, city, state, postal_code, compliance_contact_email, compliance_contact_phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



212
213
214
215
216
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 212

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 220

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  scenario_id_validator = EnumAttributeValidator.new('String', ["own_brand", "client_brand"])
  return false unless scenario_id_validator.valid?(@scenario_id)
  business_type_validator = EnumAttributeValidator.new('String', ["PRIVATE_PROFIT", "SOLE_PROPRIETOR", "PUBLIC_PROFIT", "NON_PROFIT", "GOVERNMENT"])
  return false unless business_type_validator.valid?(@business_type)
  true
end