Class: Pingram::TenDlcBrandUpdateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/pingram/models/ten_dlc_brand_update_request.rb

Overview

Request body for PATCH /registrations/us/10dlc/brand

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TenDlcBrandUpdateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pingram::TenDlcBrandUpdateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pingram::TenDlcBrandUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scenario_id')
    self.scenario_id = attributes[:'scenario_id']
  end

  if attributes.key?(:'business_type')
    self.business_type = attributes[:'business_type']
  end

  if attributes.key?(:'legal_name')
    self.legal_name = attributes[:'legal_name']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'vertical')
    self.vertical = attributes[:'vertical']
  end

  if attributes.key?(:'entity_type')
    self.entity_type = attributes[:'entity_type']
  end

  if attributes.key?(:'brand_status')
    self.brand_status = attributes[:'brand_status']
  end

  if attributes.key?(:'tax_id')
    self.tax_id = attributes[:'tax_id']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'compliance_contact_email')
    self.compliance_contact_email = attributes[:'compliance_contact_email']
  end

  if attributes.key?(:'compliance_contact_phone')
    self.compliance_contact_phone = attributes[:'compliance_contact_phone']
  end
end

Instance Attribute Details

#brand_statusObject

Pingram-side brand registration workflow status. - not_started: no customer submission yet - pending_review: customer submitted; Pingram has not submitted to carriers - in_progress: submitted for carrier review - approved | rejected | info_needed: review outcome



38
39
40
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 38

def brand_status
  @brand_status
end

#business_typeObject

Returns the value of attribute business_type.



21
22
23
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 21

def business_type
  @business_type
end

#cityObject

Returns the value of attribute city.



48
49
50
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 48

def city
  @city
end

#compliance_contact_emailObject

Returns the value of attribute compliance_contact_email.



54
55
56
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 54

def compliance_contact_email
  @compliance_contact_email
end

#compliance_contact_phoneObject

Returns the value of attribute compliance_contact_phone.



56
57
58
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 56

def compliance_contact_phone
  @compliance_contact_phone
end

#countryObject

Returns the value of attribute country.



44
45
46
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 44

def country
  @country
end

#display_nameObject

Brand display name (marketing/DBA); defaults to legalName when omitted on legalName-only updates.



26
27
28
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 26

def display_name
  @display_name
end

#entity_typeObject

Admin-only; legacy Other records. Ignored on customer PATCH.



35
36
37
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 35

def entity_type
  @entity_type
end

#first_nameObject

Returns the value of attribute first_name.



28
29
30
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 28

def first_name
  @first_name
end

#last_nameObject

Returns the value of attribute last_name.



30
31
32
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 30

def last_name
  @last_name
end

Returns the value of attribute legal_name.



23
24
25
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 23

def legal_name
  @legal_name
end

#postal_codeObject

Returns the value of attribute postal_code.



52
53
54
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 52

def postal_code
  @postal_code
end

#scenario_idObject

Returns the value of attribute scenario_id.



19
20
21
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 19

def scenario_id
  @scenario_id
end

#stateObject

Returns the value of attribute state.



50
51
52
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 50

def state
  @state
end

#streetObject

Returns the value of attribute street.



46
47
48
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 46

def street
  @street
end

#tax_idObject

Returns the value of attribute tax_id.



40
41
42
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 40

def tax_id
  @tax_id
end

#verticalObject

Returns the value of attribute vertical.



32
33
34
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 32

def vertical
  @vertical
end

#websiteObject

Returns the value of attribute website.



42
43
44
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 42

def website
  @website
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



105
106
107
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 81

def self.attribute_map
  {
    :'scenario_id' => :'scenarioId',
    :'business_type' => :'businessType',
    :'legal_name' => :'legalName',
    :'display_name' => :'displayName',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'vertical' => :'vertical',
    :'entity_type' => :'entityType',
    :'brand_status' => :'brandStatus',
    :'tax_id' => :'taxId',
    :'website' => :'website',
    :'country' => :'country',
    :'street' => :'street',
    :'city' => :'city',
    :'state' => :'state',
    :'postal_code' => :'postalCode',
    :'compliance_contact_email' => :'complianceContactEmail',
    :'compliance_contact_phone' => :'complianceContactPhone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 300

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



139
140
141
142
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 139

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 115

def self.openapi_types
  {
    :'scenario_id' => :'String',
    :'business_type' => :'String',
    :'legal_name' => :'String',
    :'display_name' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'vertical' => :'String',
    :'entity_type' => :'String',
    :'brand_status' => :'String',
    :'tax_id' => :'String',
    :'website' => :'String',
    :'country' => :'String',
    :'street' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'compliance_contact_email' => :'String',
    :'compliance_contact_phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scenario_id == o.scenario_id &&
      business_type == o.business_type &&
      legal_name == o.legal_name &&
      display_name == o.display_name &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      vertical == o.vertical &&
      entity_type == o.entity_type &&
      brand_status == o.brand_status &&
      tax_id == o.tax_id &&
      website == o.website &&
      country == o.country &&
      street == o.street &&
      city == o.city &&
      state == o.state &&
      postal_code == o.postal_code &&
      compliance_contact_email == o.compliance_contact_email &&
      compliance_contact_phone == o.compliance_contact_phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


287
288
289
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 287

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



293
294
295
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 293

def hash
  [scenario_id, business_type, legal_name, display_name, first_name, last_name, vertical, entity_type, brand_status, tax_id, website, country, street, city, state, postal_code, compliance_contact_email, compliance_contact_phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



235
236
237
238
239
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 235

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 322

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



243
244
245
246
247
248
# File 'lib/pingram/models/ten_dlc_brand_update_request.rb', line 243

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  brand_status_validator = EnumAttributeValidator.new('String', ["not_started", "in_progress", "pending_review", "approved", "rejected", "info_needed"])
  return false unless brand_status_validator.valid?(@brand_status)
  true
end