Class: Pingram::TypesApi
- Inherits:
-
Object
- Object
- Pingram::TypesApi
- Defined in:
- lib/pingram/api/types_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ TypesApi
constructor
A new instance of TypesApi.
-
#types_create_notification_type(notification_create_request, opts = {}) ⇒ Notification
Create a new notification.
-
#types_create_notification_type_with_http_info(notification_create_request, opts = {}) ⇒ Array<(Notification, Integer, Hash)>
Create a new notification.
-
#types_delete_notification_type(notification_id, opts = {}) ⇒ nil
Delete a notification.
-
#types_delete_notification_type_with_http_info(notification_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a notification.
-
#types_get_notification_type(notification_id, opts = {}) ⇒ Array<GetNotificationsResponseInner>
Get a specific notification by ID.
-
#types_get_notification_type_with_http_info(notification_id, opts = {}) ⇒ Array<(Array<GetNotificationsResponseInner>, Integer, Hash)>
Get a specific notification by ID.
-
#types_list_notification_types(opts = {}) ⇒ Array<GetNotificationsResponseInner>
Get all notifications for an account with their templates.
-
#types_list_notification_types_with_http_info(opts = {}) ⇒ Array<(Array<GetNotificationsResponseInner>, Integer, Hash)>
Get all notifications for an account with their templates.
-
#types_update_notification_type(notification_id, notification_patch_request, opts = {}) ⇒ Notification
Update a notification’s settings.
-
#types_update_notification_type_with_http_info(notification_id, notification_patch_request, opts = {}) ⇒ Array<(Notification, Integer, Hash)>
Update a notification's settings.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/types_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#types_create_notification_type(notification_create_request, opts = {}) ⇒ Notification
Create a new notification
26 27 28 29 |
# File 'lib/pingram/api/types_api.rb', line 26 def types_create_notification_type(notification_create_request, opts = {}) data, _status_code, _headers = types_create_notification_type_with_http_info(notification_create_request, opts) data end |
#types_create_notification_type_with_http_info(notification_create_request, opts = {}) ⇒ Array<(Notification, Integer, Hash)>
Create a new notification
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pingram/api/types_api.rb', line 35 def types_create_notification_type_with_http_info(notification_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TypesApi.types_create_notification_type ...' end # verify the required parameter 'notification_create_request' is set if @api_client.config.client_side_validation && notification_create_request.nil? fail ArgumentError, "Missing the required parameter 'notification_create_request' when calling TypesApi.types_create_notification_type" end # resource path local_var_path = '/types' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(notification_create_request) # return_type return_type = opts[:debug_return_type] || 'Notification' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"TypesApi.types_create_notification_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TypesApi#types_create_notification_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#types_delete_notification_type(notification_id, opts = {}) ⇒ nil
Delete a notification
92 93 94 95 |
# File 'lib/pingram/api/types_api.rb', line 92 def types_delete_notification_type(notification_id, opts = {}) types_delete_notification_type_with_http_info(notification_id, opts) nil end |
#types_delete_notification_type_with_http_info(notification_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a notification
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/pingram/api/types_api.rb', line 101 def types_delete_notification_type_with_http_info(notification_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TypesApi.types_delete_notification_type ...' end # verify the required parameter 'notification_id' is set if @api_client.config.client_side_validation && notification_id.nil? fail ArgumentError, "Missing the required parameter 'notification_id' when calling TypesApi.types_delete_notification_type" end # resource path local_var_path = '/types/{notificationId}'.sub('{' + 'notificationId' + '}', CGI.escape(notification_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"TypesApi.types_delete_notification_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TypesApi#types_delete_notification_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#types_get_notification_type(notification_id, opts = {}) ⇒ Array<GetNotificationsResponseInner>
Get a specific notification by ID
151 152 153 154 |
# File 'lib/pingram/api/types_api.rb', line 151 def types_get_notification_type(notification_id, opts = {}) data, _status_code, _headers = types_get_notification_type_with_http_info(notification_id, opts) data end |
#types_get_notification_type_with_http_info(notification_id, opts = {}) ⇒ Array<(Array<GetNotificationsResponseInner>, Integer, Hash)>
Get a specific notification by ID
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/pingram/api/types_api.rb', line 160 def types_get_notification_type_with_http_info(notification_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TypesApi.types_get_notification_type ...' end # verify the required parameter 'notification_id' is set if @api_client.config.client_side_validation && notification_id.nil? fail ArgumentError, "Missing the required parameter 'notification_id' when calling TypesApi.types_get_notification_type" end # resource path local_var_path = '/types/{notificationId}'.sub('{' + 'notificationId' + '}', CGI.escape(notification_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<GetNotificationsResponseInner>' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"TypesApi.types_get_notification_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TypesApi#types_get_notification_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#types_list_notification_types(opts = {}) ⇒ Array<GetNotificationsResponseInner>
Get all notifications for an account with their templates
211 212 213 214 |
# File 'lib/pingram/api/types_api.rb', line 211 def types_list_notification_types(opts = {}) data, _status_code, _headers = types_list_notification_types_with_http_info(opts) data end |
#types_list_notification_types_with_http_info(opts = {}) ⇒ Array<(Array<GetNotificationsResponseInner>, Integer, Hash)>
Get all notifications for an account with their templates
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/pingram/api/types_api.rb', line 219 def types_list_notification_types_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TypesApi.types_list_notification_types ...' end # resource path local_var_path = '/types' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<GetNotificationsResponseInner>' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"TypesApi.types_list_notification_types", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TypesApi#types_list_notification_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#types_update_notification_type(notification_id, notification_patch_request, opts = {}) ⇒ Notification
Update a notification’s settings
268 269 270 271 |
# File 'lib/pingram/api/types_api.rb', line 268 def types_update_notification_type(notification_id, notification_patch_request, opts = {}) data, _status_code, _headers = types_update_notification_type_with_http_info(notification_id, notification_patch_request, opts) data end |
#types_update_notification_type_with_http_info(notification_id, notification_patch_request, opts = {}) ⇒ Array<(Notification, Integer, Hash)>
Update a notification's settings
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/pingram/api/types_api.rb', line 278 def types_update_notification_type_with_http_info(notification_id, notification_patch_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TypesApi.types_update_notification_type ...' end # verify the required parameter 'notification_id' is set if @api_client.config.client_side_validation && notification_id.nil? fail ArgumentError, "Missing the required parameter 'notification_id' when calling TypesApi.types_update_notification_type" end # verify the required parameter 'notification_patch_request' is set if @api_client.config.client_side_validation && notification_patch_request.nil? fail ArgumentError, "Missing the required parameter 'notification_patch_request' when calling TypesApi.types_update_notification_type" end # resource path local_var_path = '/types/{notificationId}'.sub('{' + 'notificationId' + '}', CGI.escape(notification_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(notification_patch_request) # return_type return_type = opts[:debug_return_type] || 'Notification' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"TypesApi.types_update_notification_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TypesApi#types_update_notification_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |