Class: Pingram::WebhooksApi
- Inherits:
-
Object
- Object
- Pingram::WebhooksApi
- Defined in:
- lib/pingram/api/webhooks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
constructor
A new instance of WebhooksApi.
-
#webhooks_delete_events_webhook(opts = {}) ⇒ nil
Delete the events webhook configuration for the current account/environment.
-
#webhooks_delete_events_webhook_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete the events webhook configuration for the current account/environment.
-
#webhooks_get_events_webhook(opts = {}) ⇒ EventsWebhookResponse
Get the events webhook configuration for the current account/environment.
-
#webhooks_get_events_webhook_with_http_info(opts = {}) ⇒ Array<(EventsWebhookResponse, Integer, Hash)>
Get the events webhook configuration for the current account/environment.
-
#webhooks_upsert_events_webhook(events_webhook_upsert_request, opts = {}) ⇒ EventsWebhookResponse
Create or update the events webhook configuration for the current account/environment.
-
#webhooks_upsert_events_webhook_with_http_info(events_webhook_upsert_request, opts = {}) ⇒ Array<(EventsWebhookResponse, Integer, Hash)>
Create or update the events webhook configuration for the current account/environment.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
Returns a new instance of WebhooksApi.
19 20 21 |
# File 'lib/pingram/api/webhooks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pingram/api/webhooks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#webhooks_delete_events_webhook(opts = {}) ⇒ nil
Delete the events webhook configuration for the current account/environment.
25 26 27 28 |
# File 'lib/pingram/api/webhooks_api.rb', line 25 def webhooks_delete_events_webhook(opts = {}) webhooks_delete_events_webhook_with_http_info(opts) nil end |
#webhooks_delete_events_webhook_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete the events webhook configuration for the current account/environment.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/pingram/api/webhooks_api.rb', line 33 def webhooks_delete_events_webhook_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_delete_events_webhook ...' end # resource path local_var_path = '/webhooks/events' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"WebhooksApi.webhooks_delete_events_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#webhooks_delete_events_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhooks_get_events_webhook(opts = {}) ⇒ EventsWebhookResponse
Get the events webhook configuration for the current account/environment.
78 79 80 81 |
# File 'lib/pingram/api/webhooks_api.rb', line 78 def webhooks_get_events_webhook(opts = {}) data, _status_code, _headers = webhooks_get_events_webhook_with_http_info(opts) data end |
#webhooks_get_events_webhook_with_http_info(opts = {}) ⇒ Array<(EventsWebhookResponse, Integer, Hash)>
Get the events webhook configuration for the current account/environment.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/pingram/api/webhooks_api.rb', line 86 def webhooks_get_events_webhook_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_get_events_webhook ...' end # resource path local_var_path = '/webhooks/events' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventsWebhookResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"WebhooksApi.webhooks_get_events_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#webhooks_get_events_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#webhooks_upsert_events_webhook(events_webhook_upsert_request, opts = {}) ⇒ EventsWebhookResponse
Create or update the events webhook configuration for the current account/environment.
134 135 136 137 |
# File 'lib/pingram/api/webhooks_api.rb', line 134 def webhooks_upsert_events_webhook(events_webhook_upsert_request, opts = {}) data, _status_code, _headers = webhooks_upsert_events_webhook_with_http_info(events_webhook_upsert_request, opts) data end |
#webhooks_upsert_events_webhook_with_http_info(events_webhook_upsert_request, opts = {}) ⇒ Array<(EventsWebhookResponse, Integer, Hash)>
Create or update the events webhook configuration for the current account/environment.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/pingram/api/webhooks_api.rb', line 143 def webhooks_upsert_events_webhook_with_http_info(events_webhook_upsert_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.webhooks_upsert_events_webhook ...' end # verify the required parameter 'events_webhook_upsert_request' is set if @api_client.config.client_side_validation && events_webhook_upsert_request.nil? fail ArgumentError, "Missing the required parameter 'events_webhook_upsert_request' when calling WebhooksApi.webhooks_upsert_events_webhook" end # resource path local_var_path = '/webhooks/events' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(events_webhook_upsert_request) # return_type return_type = opts[:debug_return_type] || 'EventsWebhookResponse' # auth_names (apiKey last so Bearer wins when multiple schemes set Authorization) auth_names = opts[:debug_auth_names] || ['endUserHashed', 'endUser', 'clientCredentials', 'apiKey'] = opts.merge( :operation => :"WebhooksApi.webhooks_upsert_events_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#webhooks_upsert_events_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |